@@ -229,10 +229,11 @@ Fl_Wheel_Value_Slider *sldr_nb_level = (Fl_Wheel_Value_Slider *)0;
 //Fl_ComboBox *cbo_agc_level = (Fl_ComboBox *)0;
 Hspinner *spnr_bpf_center = (Hspinner *)0;
 
-Fl_Button *btnALC_SWR = (Fl_Button *)0;
+Fl_Button *btnALC_IDD_SWR = (Fl_Button *)0;
 
 Fl_SigBar *sldrRcvSignal = (Fl_SigBar *)0;
 Fl_SigBar *sldrALC = (Fl_SigBar *)0;
+Fl_SigBar *sldrIDD = (Fl_SigBar *)0;
 Fl_SigBar *sldrSWR = (Fl_SigBar *)0;
 
 Fl_SigBar *sldrFwdPwr = (Fl_SigBar *)0;
@@ -256,9 +257,11 @@ Fl_Group *grp_row1 = (Fl_Group *)0;
 Fl_Group *grp_row1a = (Fl_Group *)0;
 Fl_ComboBox *opBW = (Fl_ComboBox *)0;
 Fl_ComboBox *opDSP_lo = (Fl_ComboBox *)0;
+Fl_ComboBox *opCENTER = (Fl_ComboBox *)0;
 Fl_Button *btnDSP = (Fl_Button *)0;
 Fl_ComboBox *opDSP_hi = (Fl_ComboBox *)0;
 Fl_Button *btnFILT= (Fl_Button*)0;
+Fl_Button *btnCENTER = (Fl_Button*)0;
 Fl_ComboBox *opMODE = (Fl_ComboBox *)0;
 Fl_Group *grp_row1b = (Fl_Group *)0;
 Fl_Group *grp_row1b1 = (Fl_Group *)0;
@@ -409,6 +412,10 @@ static void cb_mnuExit(Fl_Menu_*, void*) {
 
 static void cb_mnuTooltips(Fl_Menu_*, void*) {
 	progStatus.tooltips = ! progStatus.tooltips;
+	if (progStatus.tooltips)
+		Fl_Tooltip::enable();
+	else
+		Fl_Tooltip::disable();
 }
 
 static void cb_mnuVoltmeter(Fl_Menu_*, void*) {
@@ -452,7 +459,7 @@ static void cb_mnuColorConfig(Fl_Menu_*, void*) {
 }
 
 static void cb_mnu_show_meters(Fl_Menu_ *, void *) {
-	if (meters_dialog)
+	if (!meters_dialog)
 		meters_dialog = win_meters();
 	meters_dialog->show();
 }
@@ -513,7 +520,7 @@ static void cb_mnuTMATE2(Fl_Menu_*, void*) {
 
 static void cb_CWkeyer(Fl_Menu_*, void*) {
 	if (cwio_keyer_dialog == 0)
-		cwio_keyer_dialog = cwio_window();
+		cwio_keyer_dialog = new_cwio_dialog();
 	for (int n = 0; n < 12; n++) {
 		btn_msg[n]->label(progStatus.cwio_labels[n].c_str());
 		btn_msg[n]->redraw_label();
@@ -543,8 +550,8 @@ static void cb_mnuGPIO(Fl_Menu_*, void*) {
 	open_gpio_tab();
 }
 
-static void cb_mnuAUX(Fl_Menu_*, void *) {
-	open_aux_tab();
+static void cb_mnuOTHER(Fl_Menu_*, void *) {
+	open_other_tab();
 }
 
 static void cb_mnuSERVER(Fl_Menu_*, void*) {
@@ -559,8 +566,8 @@ static void cb_mnuAbout(Fl_Menu_*, void*) {
 	about();
 }
 
-static void cb_btnALC_SWR(Fl_Button*, void*) {
-	cbALC_SWR();
+static void cb_btnALC_IDD_SWR(Fl_Button*, void*) {
+	cbALC_IDD_SWR();
 }
 
 static void cb_btnAGC(Fl_Button*, void*) {
@@ -663,6 +670,17 @@ static void cb_btnFILT(Fl_Button *, void *) {
 	selectFILT();
 }
 
+static void cb_btnCENTER(Fl_Button *, void *) {
+	selectCENTER();
+}
+
+static void cb_opCENTER(Fl_ComboBox*, void*) {
+	progStatus.tci_center = tci_center = opCENTER->index();
+	tci_adjust_widths();
+	if (onA) selrig->set_bwA(vfoA.iBW);
+	else     selrig->set_bwB(vfoB.iBW);
+}
+
 static void cb_opBW(Fl_ComboBox*, void*) {
 	setBW();
 }
