@@ -18,42 +18,48 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
-Fl_Radio_Light_Button *btn_wide_ui=(Fl_Radio_Light_Button *)0;
-Fl_Radio_Light_Button *btn_narrow_ui=(Fl_Radio_Light_Button *)0;
-Fl_Radio_Light_Button *btn_touch_ui=(Fl_Radio_Light_Button *)0;
+Fl_Radio_Light_Button *btn_wide_ui = (Fl_Radio_Light_Button *)0;
+Fl_Radio_Light_Button *btn_narrow_ui = (Fl_Radio_Light_Button *)0;
+Fl_Radio_Light_Button *btn_touch_ui = (Fl_Radio_Light_Button *)0;
 
-Fl_Box *lblTest=(Fl_Box *)0;
-Fl_Button *prefFont=(Fl_Button *)0;
-Fl_Button *prefForeground=(Fl_Button *)0;
-Fl_Button *btnBacklight=(Fl_Button *)0;
-Fl_Group *grpMeterColor=(Fl_Group *)0;
-Fl_Box *scaleSmeterColor=(Fl_Box *)0;
-Fl_SigBar *sldrRcvSignalColor=(Fl_SigBar *)0;
-Fl_SigBar *sldrSWRcolor=(Fl_SigBar *)0;
-Fl_Box *scaleSWRcolor=(Fl_Box *)0;
-Fl_SigBar *sldrPWRcolor=(Fl_SigBar *)0;
-Fl_Box *scalePWRcolor=(Fl_Box *)0;
-Fl_Button *btMeterColor=(Fl_Button *)0;
-Fl_Button *btnSWRColor=(Fl_Button *)0;
-Fl_Button *btnPwrColor=(Fl_Button *)0;
-Fl_Button *btnPeakColor=(Fl_Button *)0;
-Fl_Choice *mnuScheme=(Fl_Choice *)0;
-Fl_Button *pref_sys_foreground=(Fl_Button *)0;
-Fl_Button *pref_sys_background=(Fl_Button *)0;
-Fl_Button *prefsys_background2=(Fl_Button *)0;
-Fl_Button *prefsys_defaults=(Fl_Button *)0;
-Fl_Wheel_Value_Slider *sldrColors=(Fl_Wheel_Value_Slider *)0;
-Fl_Button *pref_slider_background=(Fl_Button *)0;
-Fl_Button *pref_slider_select=(Fl_Button *)0;
-Fl_Button *prefslider_defaults=(Fl_Button *)0;
-Fl_Button *btnReset=(Fl_Button *)0;
-Fl_Button *btnCancel=(Fl_Button *)0;
-Fl_Return_Button *btnOkDisplayDialog=(Fl_Return_Button *)0;
-Fl_Light_Button *btn_lighted=(Fl_Light_Button *)0;
-Fl_Button *btn_lighted_default=(Fl_Button *)0;
+Fl_Box *lblTest = (Fl_Box *)0;
+Fl_Button *prefFont = (Fl_Button *)0;
+Fl_Button *prefForeground = (Fl_Button *)0;
+Fl_Button *btnBacklight = (Fl_Button *)0;
+Fl_Group *grpMeterColor = (Fl_Group *)0;
+Fl_Box *scaleSmeterColor = (Fl_Box *)0;
+Fl_SigBar *sldrRcvSignalColor = (Fl_SigBar *)0;
+Fl_SigBar *sldrSWRcolor = (Fl_SigBar *)0;
+Fl_Box *scaleSWRcolor = (Fl_Box *)0;
+Fl_SigBar *sldrPWRcolor = (Fl_SigBar *)0;
+Fl_Box *scalePWRcolor = (Fl_Box *)0;
+Fl_SigBar *sldrVoltcolor = (Fl_SigBar *)0;
+Fl_Box *scaleVoltcolor = (Fl_Box *)0;
+Fl_Button *btMeterColor = (Fl_Button *)0;
+Fl_Button *btnSWRColor = (Fl_Button *)0;
+Fl_Button *btnPwrColor = (Fl_Button *)0;
+Fl_Button *btnPeakColor = (Fl_Button *)0;
+Fl_Button *btnVoltsColor = (Fl_Button *)0;
+Fl_Choice *mnuScheme = (Fl_Choice *)0;
+Fl_Button *pref_sys_foreground = (Fl_Button *)0;
+Fl_Button *pref_sys_background = (Fl_Button *)0;
+Fl_Button *prefsys_background2 = (Fl_Button *)0;
+Fl_Button *prefsys_defaults = (Fl_Button *)0;
+Fl_Wheel_Value_Slider *sldrColors = (Fl_Wheel_Value_Slider *)0;
+Fl_Button *pref_slider_background = (Fl_Button *)0;
+Fl_Button *pref_slider_select = (Fl_Button *)0;
+Fl_Button *prefslider_defaults = (Fl_Button *)0;
+Fl_Button *btnReset = (Fl_Button *)0;
+Fl_Button *btnCancel = (Fl_Button *)0;
+Fl_Return_Button *btnOkDisplayDialog = (Fl_Return_Button *)0;
+Fl_Light_Button *btn_lighted = (Fl_Light_Button *)0;
+Fl_Button *btn_lighted_default = (Fl_Button *)0;
 Fl_Check_Button *chk_hrd_button = (Fl_Check_Button *)0;
 Fl_Check_Button *chk_sliders_button = (Fl_Check_Button *)0;
 
+Fl_Button *btn_tab_color = (Fl_Button *)0;
+Fl_Button *btn_tab_defcolor = (Fl_Button *)0;
+
 static void cb_btn_ui(Fl_Radio_Light_Button* o, void*) {
 	if (o == btn_wide_ui) progStatus.UIsize = wide_ui;
 	else if (o == btn_narrow_ui) progStatus.UIsize = small_ui;
@@ -89,6 +95,10 @@ static void cb_btnPeakColor(Fl_Button*, void*) {
 	cbPeakMeterColor();
 }
 
+static void cb_btnVoltColor(Fl_Button*, void*) {
+	cbVoltMeterColor();
+}
+
 static void cb_mnuScheme(Fl_Choice* o, void*) {
 	progStatus.ui_scheme = o->text();
 	Fl::scheme(progStatus.ui_scheme.c_str());
@@ -150,6 +160,15 @@ static void cb_sliders_button(Fl_Check_Button*, void*) {
 	cb_change_sliders_button();
 }
 
+static void cb_btn_tab_color(Fl_Button *, void*) {
+	cb_tab_colors();
+}
+
+static void cb_btn_tab_defcolor(Fl_Button *, void*) {
+	cb_tab_defaults();
+}
+
+
 Fl_Double_Window* DisplayDialog() {
 	Fl_Double_Window* w = new Fl_Double_Window(424, 280, _("Flrig User Interface"));
 
@@ -230,75 +249,110 @@ Fl_Double_Window* DisplayDialog() {
 	su_grp2->end();
 
 	Fl_Group* su_grp3 = new Fl_Group(
-		2, su_grp2->y() + su_grp2->h(), 284, 107);
+		0, su_grp2->y() + su_grp2->h(), 284, 135);
 
-		Fl_Group* su_grp3a = new Fl_Group(
-			5, su_grp3->y() + 5, 210, 100);
-			su_grp3a->box(FL_DOWN_BOX);
+		grpMeterColor = new Fl_Group(
+			4, su_grp3->y() + 2, 210, 110);
+			grpMeterColor->box(FL_DOWN_BOX);
+			grpMeterColor->color(scaleSmeter->color());
 
-			grpMeterColor = new Fl_Group(
-				7, su_grp3a->y() + 2, 206, 96);
-				grpMeterColor->box(FL_FLAT_BOX);
+			scaleSmeterColor = new Fl_Box(
+				grpMeterColor->x() + 2, grpMeterColor->y(),
+				205, 20);
+			scaleSmeterColor->box(FL_FLAT_BOX);
+			scaleSmeterColor->image(image_S60);
+			scaleSmeterColor->color(scaleSmeter->color());
 
-				scaleSmeterColor = new Fl_Box(
-					8, grpMeterColor->y(), 205, 20);
-				scaleSmeterColor->box(FL_FLAT_BOX);
-				scaleSmeterColor->image(image_S60);
-				scaleSmeterColor->color(scaleSmeter->color());
+			sldrRcvSignalColor = new Fl_SigBar(
+				grpMeterColor->x() + 4, scaleSmeterColor->y() + 20,
+				200, 4);
+			sldrRcvSignalColor->box(FL_FLAT_BOX);
+			sldrRcvSignalColor->color(FL_BACKGROUND_COLOR);
+			sldrRcvSignalColor->selection_color(FL_BACKGROUND_COLOR);
+			sldrRcvSignalColor->labeltype(FL_NORMAL_LABEL);
+			sldrRcvSignalColor->labelfont(0);
+			sldrRcvSignalColor->labelsize(14);
+			sldrRcvSignalColor->labelcolor(FL_FOREGROUND_COLOR);
+			sldrRcvSignalColor->align(Fl_Align(FL_ALIGN_CENTER));
+			sldrRcvSignalColor->when(FL_WHEN_RELEASE);
+			sldrRcvSignalColor->minimum(0);
+			sldrRcvSignalColor->maximum(100);
+			sldrRcvSignalColor->avg(1);
+			sldrRcvSignalColor->value(25);
 
-				sldrRcvSignalColor = new Fl_SigBar(
-					10, grpMeterColor->y() + 20, 200, 6);
-				sldrRcvSignalColor->box(FL_FLAT_BOX);
-				sldrRcvSignalColor->color(FL_BACKGROUND_COLOR);
-				sldrRcvSignalColor->selection_color(FL_BACKGROUND_COLOR);
-				sldrRcvSignalColor->labeltype(FL_NORMAL_LABEL);
-				sldrRcvSignalColor->labelfont(0);
-				sldrRcvSignalColor->labelsize(14);
-				sldrRcvSignalColor->labelcolor(FL_FOREGROUND_COLOR);
-				sldrRcvSignalColor->align(Fl_Align(FL_ALIGN_CENTER));
-				sldrRcvSignalColor->when(FL_WHEN_RELEASE);
+			scaleSWRcolor = new Fl_Box(
+				grpMeterColor->x() + 2, sldrRcvSignalColor->y() + 6,
+				205, 20);
+			scaleSWRcolor->box(FL_FLAT_BOX);
+			scaleSWRcolor->image(image_SWR);
+			scaleSWRcolor->color(scaleSmeter->color());
 
-				sldrSWRcolor = new Fl_SigBar(
-					10, grpMeterColor->y() + 51, 200, 6);
-				sldrSWRcolor->box(FL_FLAT_BOX);
-				sldrSWRcolor->color(FL_BACKGROUND_COLOR);
-				sldrSWRcolor->selection_color(FL_BACKGROUND_COLOR);
-				sldrSWRcolor->labeltype(FL_NORMAL_LABEL);
-				sldrSWRcolor->labelfont(0);
-				sldrSWRcolor->labelsize(14);
-				sldrSWRcolor->labelcolor(FL_FOREGROUND_COLOR);
-				sldrSWRcolor->align(Fl_Align(FL_ALIGN_CENTER));
-				sldrSWRcolor->when(FL_WHEN_RELEASE);
-				sldrSWRcolor->minimum(0);
-				sldrSWRcolor->maximum(100);
+			sldrSWRcolor = new Fl_SigBar(
+				grpMeterColor->x() + 4, scaleSWRcolor->y() + 20,
+				200, 4);
+			sldrSWRcolor->box(FL_FLAT_BOX);
+			sldrSWRcolor->color(FL_BACKGROUND_COLOR);
+			sldrSWRcolor->selection_color(FL_BACKGROUND_COLOR);
+			sldrSWRcolor->labeltype(FL_NORMAL_LABEL);
+			sldrSWRcolor->labelfont(0);
+			sldrSWRcolor->labelsize(14);
+			sldrSWRcolor->labelcolor(FL_FOREGROUND_COLOR);
+			sldrSWRcolor->align(Fl_Align(FL_ALIGN_CENTER));
+			sldrSWRcolor->when(FL_WHEN_RELEASE);
+			sldrSWRcolor->minimum(0);
+			sldrSWRcolor->maximum(100);
+			sldrSWRcolor->avg(1);
+			sldrSWRcolor->value(30);
 
-				scaleSWRcolor = new Fl_Box(
-					8, grpMeterColor->y() + 31, 205, 20);
-				scaleSWRcolor->box(FL_FLAT_BOX);
-				scaleSWRcolor->image(image_SWR);
+			sldrPWRcolor = new Fl_SigBar(
+				grpMeterColor->x() + 4, sldrSWRcolor->y() + 6,
+				200, 4);
+			sldrPWRcolor->box(FL_FLAT_BOX);
+			sldrPWRcolor->color(FL_BACKGROUND_COLOR);
+			sldrPWRcolor->selection_color(FL_BACKGROUND_COLOR);
+			sldrPWRcolor->labeltype(FL_NORMAL_LABEL);
+			sldrPWRcolor->labelfont(0);
+			sldrPWRcolor->labelsize(14);
+			sldrPWRcolor->labelcolor(FL_FOREGROUND_COLOR);
+			sldrPWRcolor->align(Fl_Align(FL_ALIGN_CENTER));
+			sldrPWRcolor->when(FL_WHEN_RELEASE);
+			sldrPWRcolor->minimum(0);
+			sldrPWRcolor->maximum(100);
+			sldrPWRcolor->avg(1);
+			sldrPWRcolor->value(40);
 
-				sldrPWRcolor = new Fl_SigBar(
-					8, grpMeterColor->y() + 68, 200, 6);
-				sldrPWRcolor->box(FL_FLAT_BOX);
-				sldrPWRcolor->color(FL_BACKGROUND_COLOR);
-				sldrPWRcolor->selection_color(FL_BACKGROUND_COLOR);
-				sldrPWRcolor->labeltype(FL_NORMAL_LABEL);
-				sldrPWRcolor->labelfont(0);
-				sldrPWRcolor->labelsize(14);
-				sldrPWRcolor->labelcolor(FL_FOREGROUND_COLOR);
-				sldrPWRcolor->align(Fl_Align(FL_ALIGN_CENTER));
-				sldrPWRcolor->when(FL_WHEN_RELEASE);
-				sldrPWRcolor->minimum(0);
-				sldrPWRcolor->maximum(100);
+			scalePWRcolor = new Fl_Box(
+				grpMeterColor->x() + 2, sldrPWRcolor->y() + 6,
+				205, 20);
+			scalePWRcolor->box(FL_FLAT_BOX);
+			scalePWRcolor->image(image_P100);
+			scalePWRcolor->color(scaleSmeter->color());
 
-				scalePWRcolor = new Fl_Box(
-					8, grpMeterColor->y() + 74, 205, 20);
-				scalePWRcolor->box(FL_FLAT_BOX);
-				scalePWRcolor->image(image_P100);
+			sldrVoltcolor = new Fl_SigBar(
+				grpMeterColor->x() + 4, scalePWRcolor->y() + 20,
+				200, 4);
+			sldrVoltcolor->box(FL_FLAT_BOX);
+			sldrVoltcolor->color(FL_BACKGROUND_COLOR);
+			sldrVoltcolor->selection_color(FL_BACKGROUND_COLOR);
+			sldrVoltcolor->labeltype(FL_NORMAL_LABEL);
+			sldrVoltcolor->labelfont(0);
+			sldrVoltcolor->labelsize(14);
+			sldrVoltcolor->labelcolor(FL_FOREGROUND_COLOR);
+			sldrVoltcolor->align(Fl_Align(FL_ALIGN_CENTER));
+			sldrVoltcolor->when(FL_WHEN_RELEASE);
+			sldrVoltcolor->minimum(0);
+			sldrVoltcolor->maximum(100);
+			sldrVoltcolor->avg(1);
+			sldrVoltcolor->value(55);
 
-			grpMeterColor->end();
+			scaleVoltcolor = new Fl_Box(
+				grpMeterColor->x() + 2, sldrVoltcolor->y() + 6,
+				205, 20);
+			scaleVoltcolor->box(FL_FLAT_BOX);
+			scaleVoltcolor->image(image_voltmeter);
+			scaleVoltcolor->color(scaleSmeter->color());
 
-		su_grp3a->end();
+		grpMeterColor->end();
 
 		btMeterColor = new Fl_Button(
 			grpMeterColor->x() + grpMeterColor->w() + 5, grpMeterColor->y(), 
@@ -320,6 +374,11 @@ Fl_Double_Window* DisplayDialog() {
 			60, 22, _("Peak"));
 		btnPeakColor->callback((Fl_Callback*)cb_btnPeakColor);
 
+		btnVoltsColor = new Fl_Button(
+			btnPwrColor->x(), btnPeakColor->y() + btnPwrColor->h() + 4,
+			60, 22, _("Volts"));
+		btnVoltsColor->callback((Fl_Callback*)cb_btnVoltColor);
+
 	su_grp3->end();
 
 	Fl_Group* su_grp4 = new Fl_Group(
@@ -371,7 +430,7 @@ Fl_Double_Window* DisplayDialog() {
 
 	Fl_Group* su_grp5 = new Fl_Group(
 		su_grp3->x() + su_grp3->w() + 2, su_grp3->y(),
-		134, 88);
+		134, 80);
 		su_grp5->box(FL_ENGRAVED_FRAME);
 
 		sldrColors = new Fl_Wheel_Value_Slider(
@@ -395,62 +454,78 @@ Fl_Double_Window* DisplayDialog() {
         sldrColors->reverse(true);
 
 		pref_slider_background = new Fl_Button(
-			sldrColors->x(), sldrColors->y() + sldrColors->h() + 5,
-			60, 22, _("Bngd"));
+			sldrColors->x(), sldrColors->y() + sldrColors->h() + 4,
+			60, 20, _("Bngd"));
 		pref_slider_background->tooltip(_("Background - normal"));
 		pref_slider_background->callback((Fl_Callback*)cb_pref_slider_background);
 
 		pref_slider_select = new Fl_Button(
 			pref_slider_background->x() + pref_slider_background->w() + 3, 
 			pref_slider_background->y(),
-			60, 22, _("Button"));
+			60, 20, _("Button"));
 		pref_slider_select->tooltip(_("Background - normal"));
 		pref_slider_select->callback((Fl_Callback*)cb_pref_slider_select);
 
 		prefslider_defaults = new Fl_Button(
 			pref_slider_background->x() + pref_slider_background->w()/2, 
 			pref_slider_select->y() + pref_slider_select->h() + 4,
-			60, 22, _("Default"));
+			60, 20, _("Default"));
 		prefslider_defaults->tooltip(_("Background - selected"));
 		prefslider_defaults->callback((Fl_Callback*)cb_prefslider_defaults);
 
 	su_grp5->end();
 
 	btnReset = new Fl_Button(
-		25, su_grp3a->y() + su_grp3a->h() + 5,
-		60, 22, _("Reset"));
+		grpMeterColor->x() + 2, grpMeterColor->y() + grpMeterColor->h() + 3,
+		60, 20, _("Reset"));
 	btnReset->tooltip(_("Restore all flrig defaults"));
 	btnReset->callback((Fl_Callback*)cb_btnReset);
 
 	btnCancel = new Fl_Button(
-		113, btnReset->y(), 
-		60, 22, _("Cancel"));
+		btnReset->x() + btnReset->w() + 4, btnReset->y(), 
+		60, 20, _("Cancel"));
 	btnCancel->tooltip(_("Discard current changes"));
 	btnCancel->callback((Fl_Callback*)cb_btnCancel);
 
 	btnOkDisplayDialog = new Fl_Return_Button(
-		201, btnReset->y(), 
-		60, 22, _("OK"));
+		btnCancel->x() + btnCancel->w() + 4, btnReset->y(), 
+		60, 20, _("OK"));
 	btnOkDisplayDialog->tooltip(_("Save Current Changes"));
 	btnOkDisplayDialog->callback((Fl_Callback*)cb_btnOkDisplayDialog);
 
 	Fl_Group* su_grp6 = new Fl_Group(
-		su_grp5->x(), su_grp5->y() + su_grp5->h(), 134, 45);
+		su_grp5->x(), su_grp5->y() + su_grp5->h(), 134, 28);
 		su_grp6->box(FL_ENGRAVED_FRAME);
 
 		btn_lighted = new Fl_Light_Button(
-			su_grp6->x() + 5, su_grp6->y() + 10, 
-			60, 22, _("Lt Btn"));
+			su_grp6->x() + 5, su_grp6->y() + 4, 
+			60, 20, _("Lt Btn"));
 		btn_lighted->callback((Fl_Callback*)cb_btn_lighted);
 
 		btn_lighted_default = new Fl_Button(
 			btn_lighted->x() + btn_lighted->w() + 2, btn_lighted->y(), 
-			60, 22, _("Default"));
+			60, 20, _("Default"));
 		btn_lighted_default->tooltip(_("Background - selected"));
 		btn_lighted_default->callback((Fl_Callback*)cb_btn_lighted_default);
 
 	su_grp6->end();
 
+	Fl_Group* su_grp7 = new Fl_Group(
+		su_grp6->x(), su_grp6->y() + su_grp6->h(), su_grp6->w(), 28);
+		su_grp7->box(FL_ENGRAVED_FRAME);
+
+		btn_tab_color = new Fl_Button(
+			su_grp7->x() + 5, su_grp7->y() + 4, 60, 20, _("Tab Clr"));
+		btn_tab_color->color(
+			fl_rgb_color(progStatus.tab_red, progStatus.tab_green, progStatus.tab_blue));
+		btn_tab_color->callback((Fl_Callback *)cb_btn_tab_color);
+
+		btn_tab_defcolor = new Fl_Button(
+			btn_tab_color->x() + btn_tab_color->w() + 5, btn_tab_color->y(), 60, 20, _("Def Clr"));
+		btn_tab_defcolor->callback((Fl_Callback *)cb_btn_tab_defcolor);
+
+	su_grp7->end();
+
 	w->end();
 
 	w->position( progStatus.ddX, progStatus.ddY );
