@@ -27,11 +27,11 @@ Fl_Menu_Item menu_small_menu[] = {
  {_("&Config"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Setup"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Transceiver"), 0,  (Fl_Callback*)cb_mnuConfigXcvr, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
- {_("tcpip"), 0, (Fl_Callback*)cb_mnuTCPIP, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("TCPIP - TCI"), 0, (Fl_Callback*)cb_mnuTCPIP, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-CMedia"), 0, (Fl_Callback*)cb_mnuCMEDIA, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-Generic"), 0, (Fl_Callback*)cb_mnuPTT, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-GPIO"), 0, (Fl_Callback*)cb_mnuGPIO, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
- {_("AUX"), 0, (Fl_Callback*)cb_mnuAUX, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Other"), 0, (Fl_Callback*)cb_mnuOTHER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("TMATE-2"), 0, (Fl_Callback*)cb_mnuTMATE2, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Server"), 0, (Fl_Callback*)cb_mnuSERVER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
@@ -406,6 +406,11 @@ CTRL  click: FreqB -> FreqA\
 	btnSplit->callback((Fl_Callback*)cb_btnSplit);
 	btnSplit->value(progStatus.split);
 
+	btnCENTER = new Fl_Button(212, 84, 18, 18, _("W"));
+	btnCENTER->callback((Fl_Callback*)cb_btnCENTER);
+	btnCENTER->tooltip(_("Center/Wid"));
+	btnCENTER->hide();
+
 	opBW = new Fl_ComboBox(212, 84, 105, 18, _("Bandwidth"));
 	opBW->tooltip(_("Select Transceiver Bandwidth"));
 	opBW->box(FL_NO_BOX);
@@ -421,6 +426,22 @@ CTRL  click: FreqB -> FreqA\
 	opBW->readonly();
 	opBW->end();
 
+	opCENTER = new Fl_ComboBox(231, 84, 86, 18, "");
+	opCENTER->tooltip(_("Center Frequency"));
+	opCENTER->box(FL_FLAT_BOX);
+	opCENTER->color(FL_BACKGROUND2_COLOR);
+	opCENTER->selection_color(FL_BACKGROUND_COLOR);
+	opCENTER->labeltype(FL_NORMAL_LABEL);
+	opCENTER->labelfont(0);
+	opCENTER->labelsize(12);
+	opCENTER->labelcolor(FL_FOREGROUND_COLOR);
+	opCENTER->callback((Fl_Callback*)cb_opCENTER);
+	opCENTER->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
+	opCENTER->when(FL_WHEN_RELEASE);
+	opCENTER->readonly();
+	opCENTER->hide();
+	opCENTER->end();
+
 	btnDSP = new Fl_Button(212, 84, 18, 18, _("L"));
 	btnDSP->callback((Fl_Callback*)cb_btnDSP);
 	btnDSP->hide();
@@ -533,13 +554,13 @@ CTRL  click: FreqB -> FreqA\
 			scaleSmeter->image(image_S60);
 			scaleSmeter->tooltip(_("S units meter"));
 
-			btnALC_SWR = new Fl_Button(3, 63, 206, 20);
-			btnALC_SWR->tooltip(_("Press SWR / ALC"));
-			btnALC_SWR->box(FL_FLAT_BOX);
-			btnALC_SWR->down_box(FL_FLAT_BOX);
-			btnALC_SWR->image(image_SWR);
-			btnALC_SWR->callback((Fl_Callback*)cb_btnALC_SWR);
-			btnALC_SWR->hide();
+			btnALC_IDD_SWR = new Fl_Button(3, 63, 206, 20);
+			btnALC_IDD_SWR->tooltip(_("Press SWR / ALC"));
+			btnALC_IDD_SWR->box(FL_FLAT_BOX);
+			btnALC_IDD_SWR->down_box(FL_FLAT_BOX);
+			btnALC_IDD_SWR->image(image_SWR);
+			btnALC_IDD_SWR->callback((Fl_Callback*)cb_btnALC_IDD_SWR);
+			btnALC_IDD_SWR->hide();
 
 			sldrRcvSignal = new Fl_SigBar(5, 85, 200, 6);
 			sldrRcvSignal->box(FL_FLAT_BOX);
@@ -569,6 +590,20 @@ CTRL  click: FreqB -> FreqA\
 			sldrALC->minimum(0);
 			sldrALC->maximum(100);
 
+			sldrIDD = new Fl_SigBar(5, 85, 200, 6);
+			sldrIDD->box(FL_FLAT_BOX);
+			sldrIDD->color(FL_BACKGROUND_COLOR);
+			sldrIDD->selection_color(FL_BACKGROUND_COLOR);
+			sldrIDD->labeltype(FL_NORMAL_LABEL);
+			sldrIDD->labelfont(0);
+			sldrIDD->labelsize(12);
+			sldrIDD->labelcolor(FL_FOREGROUND_COLOR);
+			sldrIDD->align(Fl_Align(FL_ALIGN_CENTER));
+			sldrIDD->when(FL_WHEN_CHANGED);
+			sldrIDD->hide();
+			sldrIDD->minimum(0);
+			sldrIDD->maximum(25);;
+
 			sldrSWR = new Fl_SigBar(5, 85, 200, 6);
 			sldrSWR->box(FL_FLAT_BOX);
 			sldrSWR->color(FL_BACKGROUND_COLOR);
