@@ -36,11 +36,11 @@ Fl_Menu_Item touch_menu[] = {
  {_("&Config"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Setup"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Transceiver"), 0,  (Fl_Callback*)cb_mnuConfigXcvr, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
- {_("tcpip"), 0, (Fl_Callback*)cb_mnuTCPIP, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("TCPIP - TCI"), 0, (Fl_Callback*)cb_mnuTCPIP, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-CMedia"), 0, (Fl_Callback*)cb_mnuCMEDIA, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-Generic"), 0, (Fl_Callback*)cb_mnuPTT, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-GPIO"), 0, (Fl_Callback*)cb_mnuGPIO, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
- {_("AUX"), 0, (Fl_Callback*)cb_mnuAUX, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Other"), 0, (Fl_Callback*)cb_mnuOTHER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("TMATE-2"), 0, (Fl_Callback*)cb_mnuTMATE2, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Server"), 0, (Fl_Callback*)cb_mnuSERVER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
@@ -180,14 +180,14 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		scaleSmeter->image(image_S60);
 		scaleSmeter->tooltip(_("S units meter"));
 
-		btnALC_SWR = new Fl_Button(xpos, ypos, 206, 20);
-		btnALC_SWR->tooltip(_("Press SWR / ALC"));
-		btnALC_SWR->box(FL_FLAT_BOX);
-		btnALC_SWR->down_box(FL_FLAT_BOX);
-		btnALC_SWR->color((Fl_Color)246);
-		btnALC_SWR->image(image_SWR);
-		btnALC_SWR->callback((Fl_Callback*)cb_btnALC_SWR);
-		btnALC_SWR->hide();
+		btnALC_IDD_SWR = new Fl_Button(xpos, ypos, 206, 20);
+		btnALC_IDD_SWR->tooltip(_("Press SWR / ALC"));
+		btnALC_IDD_SWR->box(FL_FLAT_BOX);
+		btnALC_IDD_SWR->down_box(FL_FLAT_BOX);
+		btnALC_IDD_SWR->color((Fl_Color)246);
+		btnALC_IDD_SWR->image(image_SWR);
+		btnALC_IDD_SWR->callback((Fl_Callback*)cb_btnALC_IDD_SWR);
+		btnALC_IDD_SWR->hide();
 
 		sldrRcvSignal = new Fl_SigBar(xpos, ypos+22, 200, 6);
 		sldrRcvSignal->box(FL_FLAT_BOX);
@@ -217,6 +217,20 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		sldrALC->minimum(0);
 		sldrALC->maximum(100);
 
+		sldrIDD = new Fl_SigBar(xpos+2, ypos+22, 200, 6);
+		sldrIDD->box(FL_FLAT_BOX);
+		sldrIDD->color(FL_BACKGROUND_COLOR);
+		sldrIDD->selection_color(FL_BACKGROUND_COLOR);
+		sldrIDD->labeltype(FL_NORMAL_LABEL);
+		sldrIDD->labelfont(0);
+		sldrIDD->labelsize(14);
+		sldrIDD->labelcolor(FL_FOREGROUND_COLOR);
+		sldrIDD->align(Fl_Align(FL_ALIGN_CENTER));
+		sldrIDD->when(FL_WHEN_CHANGED);
+		sldrIDD->hide();
+		sldrIDD->minimum(0);
+		sldrIDD->maximum(25);;
+
 		sldrSWR = new Fl_SigBar(xpos+2, ypos+22, 200, 6);
 		sldrSWR->box(FL_FLAT_BOX);
 		sldrSWR->color(FL_BACKGROUND_COLOR);
@@ -287,6 +301,11 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		ypos += 62;
 		Fl_Group *grpcombos = new Fl_Group(xpos, ypos, 208, 35);
 
+		btnCENTER = new Fl_Button(xpos, ypos, 30, 35, _("W"));
+		btnCENTER->callback((Fl_Callback*)cb_btnCENTER);
+		btnCENTER->tooltip(_("Center/Width"));
+		btnCENTER->hide();
+
 		opBW = new Fl_ComboBox(xpos, ypos, 115, 35, "");
 		opBW->tooltip(_("Select Transceiver Bandwidth"));
 		opBW->box(FL_FLAT_BOX);
@@ -304,6 +323,24 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		opBW->readonly();
 		opBW->end();
 
+		opCENTER = new Fl_ComboBox(xpos+30, ypos, opBW->w() - 30, 35, "");
+		opCENTER->tooltip(_("Center frequency"));
+		opCENTER->box(FL_FLAT_BOX);
+		opCENTER->color(FL_BACKGROUND2_COLOR);
+		opCENTER->selection_color(FL_BACKGROUND_COLOR);
+		opCENTER->labeltype(FL_NORMAL_LABEL);
+		opCENTER->labelfont(0);
+		opCENTER->labelsize(12);
+		opCENTER->textfont(0);
+		opCENTER->textsize(14);;
+		opCENTER->labelcolor(FL_FOREGROUND_COLOR);
+		opCENTER->callback((Fl_Callback*)cb_opCENTER);
+		opCENTER->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
+		opCENTER->when(FL_WHEN_RELEASE);
+		opCENTER->readonly();
+		opCENTER->hide();
+		opCENTER->end();
+
 		opMODE = new Fl_ComboBox(xpos + opBW->w() + 2, ypos, 208 - opBW->w() - 2, 35, "");
 		opMODE->tooltip(_("Select transceiver operating mode"));
 		opMODE->box(FL_FLAT_BOX);
