@@ -30,11 +30,11 @@ Fl_Menu_Item menu_wide_menu[] = {
  {_("&Config"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Setup"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Transceiver"), 0,  (Fl_Callback*)cb_mnuConfigXcvr, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
- {_("tcpip"), 0, (Fl_Callback*)cb_mnuTCPIP, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("TCPIP - TCI"), 0, (Fl_Callback*)cb_mnuTCPIP, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-CMedia"), 0, (Fl_Callback*)cb_mnuCMEDIA, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-Generic"), 0, (Fl_Callback*)cb_mnuPTT, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-GPIO"), 0, (Fl_Callback*)cb_mnuGPIO, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
- {_("AUX"), 0, (Fl_Callback*)cb_mnuAUX, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("AUX"), 0, (Fl_Callback*)cb_mnuOTHER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("TMATE-2"), 0, (Fl_Callback*)cb_mnuTMATE2, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Server"), 0, (Fl_Callback*)cb_mnuSERVER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
@@ -102,14 +102,14 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 			scaleSmeter->image(image_S60);
 			scaleSmeter->tooltip(_("S units meter"));
 
-			btnALC_SWR = new Fl_Button(xpos+1, ypos+1, 206, 20);
-			btnALC_SWR->tooltip(_("Press SWR / ALC"));
-			btnALC_SWR->box(FL_FLAT_BOX);
-			btnALC_SWR->down_box(FL_FLAT_BOX);
-			btnALC_SWR->color((Fl_Color)246);
-			btnALC_SWR->image(image_SWR);
-			btnALC_SWR->callback((Fl_Callback*)cb_btnALC_SWR);
-			btnALC_SWR->hide();
+			btnALC_IDD_SWR = new Fl_Button(xpos+1, ypos+1, 206, 20);
+			btnALC_IDD_SWR->tooltip(_("Press SWR / ALC"));
+			btnALC_IDD_SWR->box(FL_FLAT_BOX);
+			btnALC_IDD_SWR->down_box(FL_FLAT_BOX);
+			btnALC_IDD_SWR->color((Fl_Color)246);
+			btnALC_IDD_SWR->image(image_SWR);
+			btnALC_IDD_SWR->callback((Fl_Callback*)cb_btnALC_IDD_SWR);
+			btnALC_IDD_SWR->hide();
 
 			sldrRcvSignal = new Fl_SigBar(xpos+2, ypos+22, 200, 6);
 			sldrRcvSignal->box(FL_FLAT_BOX);
@@ -139,6 +139,20 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 			sldrALC->minimum(0);
 			sldrALC->maximum(100);
 
+			sldrIDD = new Fl_SigBar(xpos+3, ypos+22, 200, 6);
+			sldrIDD->box(FL_FLAT_BOX);
+			sldrIDD->color(FL_BACKGROUND_COLOR);
+			sldrIDD->selection_color(FL_BACKGROUND_COLOR);
+			sldrIDD->labeltype(FL_NORMAL_LABEL);
+			sldrIDD->labelfont(0);
+			sldrIDD->labelsize(12);
+			sldrIDD->labelcolor(FL_FOREGROUND_COLOR);
+			sldrIDD->align(Fl_Align(FL_ALIGN_CENTER));
+			sldrIDD->when(FL_WHEN_CHANGED);
+			sldrIDD->hide();
+			sldrIDD->minimum(0);
+			sldrIDD->maximum(25);;
+
 			sldrSWR = new Fl_SigBar(xpos+2, ypos+22, 200, 6);
 			sldrSWR->box(FL_FLAT_BOX);
 			sldrSWR->color(FL_BACKGROUND_COLOR);
@@ -317,7 +331,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				int w1a = (grpMeters->w() - 2) / 2;
 
 				opBW = new Fl_ComboBox(
-					xpos, ypos, w1a, 20, _("Bandwidth"));
+					xpos, ypos, w1a, 20, "");
 				opBW->tooltip(_("Select Transceiver Bandwidth"));
 				opBW->box(FL_FLAT_BOX);
 				opBW->color(FL_BACKGROUND2_COLOR);
@@ -332,6 +346,32 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				opBW->readonly();
 				opBW->end();
 
+				btnFILT = new Fl_Button(xpos, ypos, 20, 20, _("1"));
+				btnFILT->callback((Fl_Callback*)cb_btnFILT);
+				btnFILT->tooltip(_("Select filter"));
+				btnFILT->hide();
+
+				btnCENTER = new Fl_Button(xpos, ypos, 20, 20, _("W"));
+				btnCENTER->callback((Fl_Callback*)cb_btnCENTER);
+				btnCENTER->tooltip(_("Center/Wid"));
+				btnCENTER->hide();
+
+				opCENTER = new Fl_ComboBox(xpos + 20, ypos, w1a - 20, 20, "");
+				opCENTER->tooltip(_("Center frequency"));
+				opCENTER->box(FL_FLAT_BOX);
+				opCENTER->color(FL_BACKGROUND2_COLOR);
+				opCENTER->selection_color(FL_BACKGROUND_COLOR);
+				opCENTER->labeltype(FL_NORMAL_LABEL);
+				opCENTER->labelfont(0);
+				opCENTER->labelsize(12);
+				opCENTER->labelcolor(FL_FOREGROUND_COLOR);
+				opCENTER->callback((Fl_Callback*)cb_opCENTER);
+				opCENTER->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
+				opCENTER->when(FL_WHEN_RELEASE);
+				opCENTER->hide();
+				opCENTER->readonly();
+				opCENTER->end();
+
 				btnDSP = new Fl_Button(xpos, ypos, 20, 20, _("L"));
 				btnDSP->callback((Fl_Callback*)cb_btnDSP);
 				btnDSP->hide();
@@ -368,11 +408,6 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				opDSP_hi->readonly();
 				opDSP_hi->end();
 
-				btnFILT = new Fl_Button(btnDSP->x(), btnDSP->y(), 20, 20, _("1"));
-				btnFILT->callback((Fl_Callback*)cb_btnFILT);
-				btnFILT->tooltip(_("Select filter"));
-				btnFILT->hide();
-
 				opMODE = new Fl_ComboBox(
 					opBW->x() + opBW->w() + 2, ypos, 
 					w1a, 20, _("Mode"));
