@@ -55,7 +55,7 @@ public:
 	void set_split(bool);
 	int  get_split();
 
-	bool canswap() { return true; }
+	bool canswap();
 	void swapAB();
 
 	void set_bwA(int val);
@@ -135,6 +135,7 @@ public:
 	int  get_power_out(void);
 	int  get_swr(void);
 	int  get_alc(void);
+	double get_idd(void);
 	double get_voltmeter(void);
 
 	void set_power_control(double val);
