@@ -103,6 +103,8 @@ public:
 	void sync_date(char *dt);
 	void sync_clock(char *tm);
 
+	double get_voltmeter();
+	double get_idd();
 };
 
 #endif
