@@ -108,7 +108,7 @@ public:
 	int  get_mic_gain();
 	void get_mic_min_max_step(int &min, int &max, int &step);
 
-	bool sendTScommand(string, int, bool);
+	bool sendTScommand(std::string, int, bool);
 
 	const char **bwtable(int);
 	const char **lotable(int);
