@@ -36,6 +36,7 @@
 enum {onNIL, onA, onB};
 enum {UI, XML, SRVR, RIG};
 enum {DT_BINARY, DT_STRING};
+enum {SERIAL, TCPIP, TCI};
 
 struct XCVR_STATE {
 	unsigned long int freq;
@@ -156,6 +157,7 @@ public:
 
 	GUI *widgets;
 
+	int  io_class;
 	int  comm_baudrate;
 	int  stopbits;
 	int  comm_retries;
@@ -242,6 +244,7 @@ public:
 	bool has_tune_control;
 	bool has_swr_control;
 	bool has_alc_control;
+	bool has_idd_control;
 	bool has_agc_control;
 	bool has_rf_control;
 	bool has_sql_control;
@@ -398,8 +401,11 @@ public:
 	virtual int  get_smeter(void) {return -1;}
 	virtual int  get_swr(void) {return -1;}
 	virtual int  get_alc(void) {return -1;}
+	virtual double get_idd(void) {return 0;}
+
 	virtual void select_swr() {}
 	virtual void select_alc() {}
+	virtual void select_idd() {}
 	virtual int  get_power_out(void) {return -1;}
 
 	virtual double  get_voltmeter(void) { return -1; }
@@ -683,6 +689,9 @@ double vfo_;
 	virtual void sync_clock(char *tm) {
 		printf("Sychronize time to: %s\n", tm);
 	}
+
+// QCX+ menu system
+	virtual std::string read_menu(int, int);
 };
 
 extern rigbase *rigs[];
