@@ -79,9 +79,10 @@ extern Fl_Output *txt_encA;
 extern Fl_Group *grpMeters;
 extern Fl_Box *scaleSmeter;
 
-extern Fl_Button *btnALC_SWR;
+extern Fl_Button *btnALC_IDD_SWR;
 
 extern Fl_SigBar *sldrRcvSignal;
+extern Fl_SigBar *sldrIDD;
 extern Fl_SigBar *sldrALC;
 extern Fl_SigBar *sldrSWR;
 extern Fl_SigBar *sldrFwdPwr;
@@ -109,11 +110,13 @@ extern Fl_Button *btn_show_controls;
 extern Fl_Group *grp_row1;
 extern Fl_Group *grp_row1a;
 
+extern Fl_ComboBox *opCENTER;
 extern Fl_ComboBox *opBW;
 extern Fl_Button *btnDSP;
 extern Fl_ComboBox *opDSP_lo;
 extern Fl_ComboBox *opDSP_hi;
 extern Fl_Button *btnFILT;
+extern Fl_Button *btnCENTER;
 extern Fl_ComboBox *opMODE;
 extern Fl_Group *grp_row1b;
 extern Fl_Group *grp_row1b1;
