@@ -135,6 +135,8 @@ struct status {
 	bool	spkr_on;
 	int		volume;
 	double	power_level;
+	double	power_limit;
+	bool	enable_power_limit;
 	int		mic_gain;
 	bool	notch;
 	int		notch_val;
@@ -461,6 +463,11 @@ struct status {
 	int		tcpip_drops_allowed;
 	bool	use_tcpip;
 
+	std::string	tci_port;
+	std::string	tci_addr;
+
+	int		tci_center;
+
 	bool	xcvr_auto_on;
 	bool	xcvr_auto_off;
 
@@ -474,6 +481,7 @@ struct status {
 	bool	xmltrace;
 	bool	rpctrace;
 	bool	serialtrace;
+	bool	tcitrace;
 	bool	start_stop_trace;
 	int		rpc_level;
 
@@ -538,10 +546,25 @@ struct status {
 	int		FSK_CONNECTED;
 	int		FSK_INVERTED;
 	int		FSK_STOPBITS;
+	int		fsk_idles;
 	std::string	FSK_PORT;
 	std::string	FSK_msgs[12];
 	std::string	FSK_labels[12];
 
+// CW logbook parameters
+	std::string cw_log_name;
+	int  cw_log_cut_numbers;
+	int  cw_log_leading_zeros;
+	int  cw_log_dupcheck;
+	int  cw_log_nbr;
+
+// FSK logbook parameters
+	std::string fsk_log_name;
+	int  fsk_log_cut_numbers;
+	int  fsk_log_leading_zeros;
+	int  fsk_log_dupcheck;
+	int  fsk_log_nbr;
+
 	void saveLastState();
 	void loadLastState();
 	bool loadXcvrState(std::string);
