@@ -87,6 +87,9 @@
 #define LISTSIZE 200
 #define ATAGSIZE 128 //21
 
+enum { SWR_IMAGE, ALC_IMAGE, IDD_IMAGE };
+extern int meter_image;
+
 extern bool flrig_abort;
 
 extern XCVR_STATE *vfo, vfoA, vfoB, xcvr_vfoA, xcvr_vfoB;
@@ -104,15 +107,14 @@ extern bool modes_changed;
 extern bool bandwidths_changed;
 
 extern std::vector<std::string> rigmodes_;
-extern std::vector<std::string> rigbws_;
 
 extern rigbase *selrig;
 
 extern const char **old_bws;
 
-extern std::string printXCVR_STATE(XCVR_STATE &data);
+extern std::string printXCVR_STATE(XCVR_STATE data);
 extern std::string print_ab();
-extern const char *print(XCVR_STATE &data);
+extern const char *print(XCVR_STATE data);
 
 extern void yaesu891UpdateA(XCVR_STATE * newVfo);
 extern void yaesu891UpdateB(XCVR_STATE * newVfo);
@@ -141,12 +143,14 @@ extern void setMicGainControl(void *);
 extern void setAGC(void *);
 extern void setRFGAINControl(void *);
 extern void update_power_control(void *);
+extern void update_compression(void *);
 
 extern void setMode();
 extern void setBW();
 extern void setDSP();
 extern void selectDSP();
 extern void selectFILT();
+extern void selectCENTER();
 
 extern void addFreq();
 extern void delFreq();
@@ -251,6 +255,7 @@ extern void setCLRPBT();
 extern void setVolume();
 extern void setMicGain();
 extern void cbbtnMicLine();
+extern void execute_setPower();
 extern void setPower();
 extern void setRFGAIN();
 extern void setSQUELCH();
@@ -259,7 +264,7 @@ extern void cbTune();
 extern void cb_tune_on_off();
 extern void doPTT(int);
 //extern void cbSmeter();
-extern void cbALC_SWR();
+extern void cbALC_IDD_SWR();
 //extern void cbPWR();
 extern void cbMute();
 extern void cbAGC();
@@ -285,7 +290,7 @@ extern void open_tcpip_tab();
 extern void open_cmedia_tab();
 extern void open_ptt_tab();
 extern void open_gpio_tab();
-extern void open_aux_tab();
+extern void open_other_tab();
 extern void open_server_tab();
 extern void open_tmate2_tab();
 
@@ -378,6 +383,7 @@ extern void updateSmeter(void *d = 0);
 extern void updateFwdPwr(void *d = 0);
 extern void updateALC(void *d = 0);
 extern void updateSWR(void *d = 0);
+extern void updateIDD(void *d = 0);
 extern void updateVmeter(void *d = 0);
 extern void updateSquelch(void *d = 0);
 extern void updateRFgain(void *d = 0);
@@ -402,13 +408,11 @@ extern std::queue<VFOQUEUE> srvc_reqs;
 extern void trace(int n, ...); // all args of type const char *
 extern void trace1(int n, ...); // all args of type const char *
 
-extern std::string printXCVR_STATE(XCVR_STATE &data);
-
 extern Fl_Group *tabXCVR;
 extern Fl_Group *tabTRACE;
 extern Fl_Group *tabTCPIP;
 extern Fl_Group *tabPTT;
-extern Fl_Group *tabAUX;
+extern Fl_Group *tabOTHER;
 extern Fl_Group *tabPOLLING;
 extern Fl_Group *tabSNDCMD;
 extern Fl_Group *tabCOMMANDS;
@@ -426,12 +430,14 @@ extern Fl_Box *mtr_SMETER;
 extern Fl_Box *mtr_PWR;
 extern Fl_Box *mtr_SWR;
 extern Fl_Box *mtr_ALC;
+extern Fl_Box *mtr_IDD;
 extern Fl_Box *mtr_VOLTS;
 
 extern Fl_SigBar *sigbar_SMETER;
 extern Fl_SigBar *sigbar_PWR;
 extern Fl_SigBar *sigbar_SWR;
 extern Fl_SigBar *sigbar_ALC;
+extern Fl_SigBar *sigbar_IDD;
 extern Fl_SigBar *sigbar_VOLTS;
 
 // user interface support functions
