@@ -18,11 +18,14 @@
 // aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
-#include "icom/IC7000.h"
-#include "debug.h"
 #include <stdio.h>
 #include <iostream>
 
+#include "icom/IC7000.h"
+#include "debug.h"
+
+#include "support.h"
+
 //=============================================================================
 // IC-7000
 
@@ -214,6 +217,7 @@ void RIG_IC7000::selectA()
 	cmd += '\x00';
 	cmd.append(post);
 	waitFB("sel A");
+	inuse = onA;
 }
 
 void RIG_IC7000::selectB()
@@ -223,11 +227,12 @@ void RIG_IC7000::selectB()
 	cmd += '\x01';
 	cmd.append(post);
 	waitFB("sel B");
+	inuse = onB;
 }
 
 bool RIG_IC7000::check ()
 {
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -240,8 +245,8 @@ bool RIG_IC7000::check ()
 
 unsigned long int RIG_IC7000::get_vfoA ()
 {
-	if (useB) return A.freq;
-	string resp = pre_fm;
+	if (inuse == onB) return A.freq;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -251,7 +256,7 @@ unsigned long int RIG_IC7000::get_vfoA ()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -274,8 +279,8 @@ void RIG_IC7000::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC7000::get_vfoB ()
 {
-	if (!useB) return B.freq;
-	string resp = pre_fm;
+	if (inuse == onA) return B.freq;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -285,7 +290,7 @@ unsigned long int RIG_IC7000::get_vfoB ()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -325,7 +330,7 @@ void RIG_IC7000::set_modeA(int val)
 int RIG_IC7000::get_modeA()
 {
 	int md;
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 	cmd = pre_to;
 	cmd += '\x04';
@@ -335,7 +340,7 @@ int RIG_IC7000::get_modeA()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			md = replystr[p+5];
 			if (md == -1) { md = filA = 0; }
 			else {
@@ -366,7 +371,7 @@ void RIG_IC7000::set_modeB(int val)
 int RIG_IC7000::get_modeB()
 {
 	int md;
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 	cmd = pre_to;
 	cmd += '\x04';
@@ -376,7 +381,7 @@ int RIG_IC7000::get_modeB()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			md = replystr[p+5];
 			if (md == -1) { md = filB = 0; }
 			else {
@@ -391,8 +396,8 @@ int RIG_IC7000::get_modeB()
 
 int  RIG_IC7000::get_bwA()
 {
-	string cstr = "\x1A\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x1A\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -402,7 +407,7 @@ int  RIG_IC7000::get_bwA()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			A.iBW = (fm_bcd(replystr.substr(p+6),2));
 	}
 	return A.iBW;
@@ -410,15 +415,15 @@ int  RIG_IC7000::get_bwA()
 
 int  RIG_IC7000::get_bwB()
 {
-	string cstr = "\x1A\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x1A\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get bw B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			B.iBW = (fm_bcd(replystr.substr(p+6),2));
 	}
 	return B.iBW;
@@ -481,8 +486,8 @@ int RIG_IC7000::def_bandwidth(int m)
 
 int RIG_IC7000::get_attenuator()
 {
-	string cstr = "\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -492,7 +497,7 @@ int RIG_IC7000::get_attenuator()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+5] ? 1 : 0);
 	}
 	return progStatus.attenuator;
@@ -523,8 +528,8 @@ void RIG_IC7000::set_preamp(int val)
 
 int RIG_IC7000::get_preamp()
 {
-	string cstr = "\x16\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -534,7 +539,7 @@ int RIG_IC7000::get_preamp()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			preamp_level = replystr[p+6] ? 1 : 0;
 	}
 	return preamp_level;
@@ -553,8 +558,8 @@ void RIG_IC7000::set_auto_notch(int val)
 
 int RIG_IC7000::get_auto_notch()
 {
-	string cstr = "\x16\x41";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x41";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -564,7 +569,7 @@ int RIG_IC7000::get_auto_notch()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				auto_notch_label("AN", true);
 				return true;
@@ -598,10 +603,10 @@ int  RIG_IC7000::get_split()
 	ret = waitFOR(7, "get split");
 	igett("");
 	if (ret) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x0F");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			read_split = replystr[p+5];
 		if (read_split != 0xFA) // fail byte
 			split = read_split;
@@ -623,8 +628,8 @@ void RIG_IC7000::set_volume_control(int val)
 
 int RIG_IC7000::get_volume_control()
 {
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -634,7 +639,7 @@ int RIG_IC7000::get_volume_control()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p + 6),3) * 100 / 255);
 	}
 	return progStatus.volume;
@@ -658,8 +663,8 @@ void RIG_IC7000::set_rf_gain(int val)
 
 int RIG_IC7000::get_rf_gain()
 {
-	string cstr = "\x14\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x02";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
@@ -668,7 +673,7 @@ int RIG_IC7000::get_rf_gain()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p + 6),3) * 100 / 255);
 	}
 	return progStatus.rfgain;
@@ -687,8 +692,8 @@ void RIG_IC7000::set_squelch(int val)
 
 int  RIG_IC7000::get_squelch()
 {
-	string cstr = "\x14\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -698,7 +703,7 @@ int  RIG_IC7000::get_squelch()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6), 3) * 100 / 255);
 	}
 	return progStatus.squelch;
@@ -716,8 +721,8 @@ void RIG_IC7000::set_power_control(double val)
 
 double RIG_IC7000::get_power_control()
 {
-	string cstr = "\x14\x0A";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0A";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
@@ -726,7 +731,7 @@ double RIG_IC7000::get_power_control()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p + 6),3) * 100 / 255);
 	}
 	return progStatus.power_level;
@@ -734,8 +739,8 @@ double RIG_IC7000::get_power_control()
 
 int RIG_IC7000::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -743,7 +748,7 @@ int RIG_IC7000::get_smeter()
 	int mtr= -1;
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
@@ -754,8 +759,8 @@ int RIG_IC7000::get_smeter()
 
 int RIG_IC7000::get_power_out()
 {
-	string cstr = "\x15\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -763,7 +768,7 @@ int RIG_IC7000::get_power_out()
 	int mtr= -1;
 	if (waitFOR(9, "get pout")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
@@ -774,8 +779,8 @@ int RIG_IC7000::get_power_out()
 
 int RIG_IC7000::get_alc()
 {
-	string cstr = "\x15\x13";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x13";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -783,7 +788,7 @@ int RIG_IC7000::get_alc()
 	int mtr= -1;
 	if (waitFOR(9, "get alc")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
@@ -794,8 +799,8 @@ int RIG_IC7000::get_alc()
 
 int RIG_IC7000::get_mic_gain()
 {
-	string cstr = "\x14\x0B";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0B";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -805,7 +810,7 @@ int RIG_IC7000::get_mic_gain()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6),3) / 2.55);
 	}
 	return 0;
@@ -854,8 +859,8 @@ bool RIG_IC7000::get_notch(int &val)
 	bool on = false;
 	val = 0;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -865,7 +870,7 @@ bool RIG_IC7000::get_notch(int &val)
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = replystr[p + 6];
 		cmd = pre_to;
 		resp = pre_fm;
@@ -878,7 +883,7 @@ bool RIG_IC7000::get_notch(int &val)
 		igett("");
 		if (ret) {
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos)
+			if (p != std::string::npos)
 				val = (int)ceil(fm_bcd(replystr.substr(p+6),3) * 3000.0 / 255.0);
 		}
 	}
@@ -904,15 +909,15 @@ void RIG_IC7000::set_noise(bool val)
 
 int RIG_IC7000::get_noise()
 {
-	string cstr = "\x16\x22";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x22";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get noise")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return 0;
@@ -930,8 +935,8 @@ void RIG_IC7000::set_noise_reduction(int val)
 
 int RIG_IC7000::get_noise_reduction()
 {
-	string cstr = "\x16\x40";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x40";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -941,7 +946,7 @@ int RIG_IC7000::get_noise_reduction()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] == 0x01 ? 1 : 0);
 	}
 	return 0;
@@ -960,8 +965,8 @@ void RIG_IC7000::set_noise_reduction_val(int val)
 
 int RIG_IC7000::get_noise_reduction_val()
 {
-	string cstr = "\x14\x06";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x06";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -971,7 +976,7 @@ int RIG_IC7000::get_noise_reduction_val()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6),3) / 2.55);
 	}
 	return 0;
@@ -1019,7 +1024,7 @@ int RIG_IC7000::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 	get_trace(1, "get PTT");
@@ -1027,7 +1032,7 @@ int RIG_IC7000::get_PTT()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	return ptt_;
@@ -1064,8 +1069,8 @@ void RIG_IC7000::set_pbt_outer(int val)
 int RIG_IC7000::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1075,7 +1080,7 @@ int RIG_IC7000::get_pbt_inner()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -1086,8 +1091,8 @@ int RIG_IC7000::get_pbt_inner()
 int RIG_IC7000::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1097,7 +1102,7 @@ int RIG_IC7000::get_pbt_outer()
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -1141,11 +1146,11 @@ void RIG_IC7000::get_band_selection(int v)
 	igett("");
 	if (ret) {
 		size_t p = replystr.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
-			if (useB) {
+			if (inuse == onB) {
 				set_vfoB(bandfreq);
 				set_modeB(bandmode);
 				set_FILT(bandfilter);
@@ -1160,9 +1165,9 @@ void RIG_IC7000::get_band_selection(int v)
 
 void RIG_IC7000::set_band_selection(int v)
 {
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int fil = (useB ? filB : filA);
-	int mode = (useB ? B.imode : A.imode);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int fil = (inuse == onB ? filB : filA);
+	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
