@@ -27,10 +27,12 @@
 #include <iostream>
 
 #include "icom/IC705.h"
-#include "support.h"
+#include "status.h"
 #include "trace.h"
 #include "tod_clock.h"
 
+#include "support.h"
+
 //=============================================================================
 // IC-705
 
@@ -270,8 +272,8 @@ void RIG_IC705::selectA()
 	cmd += '\x00';
 	cmd.append(post);
 	waitFB("select A");
-
 	isett("selectA");
+	inuse = onA;
 }
 
 void RIG_IC705::selectB()
@@ -280,8 +282,8 @@ void RIG_IC705::selectB()
 	cmd += '\x01';
 	cmd.append(post);
 	waitFB("select B");
-
 	isett("selectB");
+	inuse = onB;
 }
 
 //======================================================================
@@ -357,7 +359,7 @@ void RIG_IC705::set_xcvr_auto_off()
 
 bool RIG_IC705::check ()
 {
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -369,12 +371,12 @@ bool RIG_IC705::check ()
 
 unsigned long int RIG_IC705::get_vfoA ()
 {
-	string resp;
+	std::string resp;
 
 	cmd.assign(pre_to).append("\x25");
 	resp.assign(pre_fm).append("\x25");
 
-	if (useB) {
+	if (inuse == onB) {
 		cmd  += '\x01';
 		resp += '\x01';
 	} else {
@@ -385,7 +387,7 @@ unsigned long int RIG_IC705::get_vfoA ()
 	cmd.append(post);
 	if (waitFOR(12, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == -1)
 				A.freq = 0;
 			else
@@ -403,7 +405,7 @@ void RIG_IC705::set_vfoA (unsigned long int freq)
 	A.freq = freq;
 
 	cmd.assign(pre_to).append("\x25");
-	if (useB) cmd += '\x01';
+	if (inuse == onB) cmd += '\x01';
 	else      cmd += '\x00';
 
 	cmd.append( to_bcd_be( freq, 10) );
@@ -416,12 +418,12 @@ void RIG_IC705::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC705::get_vfoB ()
 {
-	string resp;
+	std::string resp;
 
 	cmd.assign(pre_to).append("\x25");
 	resp.assign(pre_fm).append("\x25");
 
-	if (useB) {
+	if (inuse == onB) {
 		cmd  += '\x00';
 		resp += '\x00';
 	} else {
@@ -432,7 +434,7 @@ unsigned long int RIG_IC705::get_vfoB ()
 	cmd.append(post);
 	if (waitFOR(12, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == -1)
 				A.freq = 0;
 			else
@@ -450,7 +452,7 @@ void RIG_IC705::set_vfoB (unsigned long int freq)
 	B.freq = freq;
 
 	cmd.assign(pre_to).append("\x25");
-	if (useB) cmd += '\x00';
+	if (inuse == onB) cmd += '\x00';
 	else      cmd += '\x01';
 
 	cmd.append( to_bcd_be( freq, 10 ) );
@@ -482,11 +484,11 @@ int RIG_IC705::get_modeA()
 	int md = 0;
 	size_t p;
 
-	string resp;
+	std::string resp;
 	cmd.assign(pre_to).append("\x26");
 	resp.assign(pre_fm).append("\x26");
 
-	if (useB)
+	if (inuse == onB)
 		cmd += '\x01';
 	else
 		cmd += '\x00';
@@ -495,7 +497,7 @@ int RIG_IC705::get_modeA()
 
 	if (waitFOR(10, "get mode A")) {
 		p = replystr.rfind(resp);
-		if (p == string::npos)
+		if (p == std::string::npos)
 			goto end_wait_modeA;
 
 		if (replystr[p+6] == -1) { md = A.imode = 0; }
@@ -551,7 +553,7 @@ void RIG_IC705::set_modeA(int val)
 	A.imode = val;
 	cmd.assign(pre_to);
 	cmd += '\x26';
-	if (useB)
+	if (inuse == onB)
 		cmd += '\x01';					// unselected vfo
 	else
 		cmd += '\x00';					// selected vfo
@@ -572,11 +574,11 @@ int RIG_IC705::get_modeB()
 	int md = 0;
 	size_t p;
 
-	string resp;
+	std::string resp;
 	cmd.assign(pre_to).append("\x26");
 	resp.assign(pre_fm).append("\x26");
 
-	if (useB)
+	if (inuse == onB)
 		cmd += '\x00';   // active vfo
 	else
 		cmd += '\x01';   // inactive vfo
@@ -584,7 +586,7 @@ int RIG_IC705::get_modeB()
 
 	if (waitFOR(10, "get mode B")) {
 		p = replystr.rfind(resp);
-		if (p == string::npos)
+		if (p == std::string::npos)
 			goto end_wait_modeB;
 
 		if (replystr[p+6] == -1) { md = filA = 0; }
@@ -639,7 +641,7 @@ void RIG_IC705::set_modeB(int val)
 	B.imode = val;
 	cmd.assign(pre_to);
 	cmd += '\x26';
-	if (useB)
+	if (inuse == onB)
 		cmd += '\x00';					// selected vfo
 	else
 		cmd += '\x01';					// unselected vfo
@@ -657,7 +659,7 @@ void RIG_IC705::set_modeB(int val)
 
 int RIG_IC705::get_FILT(int mode)
 {
-	if (useB) return mode_filterB[mode];
+	if (inuse == onB) return mode_filterB[mode];
 	return mode_filterA[mode];
 }
 
@@ -666,7 +668,7 @@ void RIG_IC705::set_FILT(int filter)
 	if (filter < 1 || filter > 3)
 		return;
 
-	if (useB) {
+	if (inuse == onB) {
 		B.filter = filter;
 		mode_filterB[B.imode] = filter;
 		cmd.assign(pre_to);
@@ -707,7 +709,7 @@ const char *RIG_IC705::FILT(int val)
 const char * RIG_IC705::nextFILT()
 {
 	int val = A.filter;
-	if (useB) val = B.filter;
+	if (inuse == onB) val = B.filter;
 	val++;
 	if (val > 3) val = 1;
 	set_FILT(val);
@@ -716,7 +718,7 @@ const char * RIG_IC705::nextFILT()
 
 void RIG_IC705::set_FILTERS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_filterA[i];
@@ -732,7 +734,7 @@ void RIG_IC705::set_FILTERS(std::string s)
 
 std::string RIG_IC705::get_FILTERS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++) {
 		if (mode_filterA[i] < 1) mode_filterA[i] = 1;
 		if (mode_filterA[i] > 3) mode_filterA[i] = 3;
@@ -748,7 +750,7 @@ std::string RIG_IC705::get_FILTERS()
 
 std::string RIG_IC705::get_BANDWIDTHS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_bwA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -758,7 +760,7 @@ std::string RIG_IC705::get_BANDWIDTHS()
 
 void RIG_IC705::set_BANDWIDTHS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_bwA[i];
@@ -790,10 +792,10 @@ int RIG_IC705::get_split()
 	cmd.append("\x0F");
 	cmd.append( post );
 	if (waitFOR(7, "get split")) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x0F");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			read_split = replystr[p+5];
 		if (read_split != 0xFA) // fail byte
 			split = read_split;
@@ -808,17 +810,18 @@ int RIG_IC705::get_bwA()
 {
 	if (A.imode == 3 || A.imode == 11) return 0; // FM, FM-D
 
-	if (useB) selectA();
+	int current_vfo = inuse;
+	if (current_vfo == onB) selectA();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
 	int bwval = A.iBW;
 	if (waitFOR(8, "get_bwA")) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x1A\x03");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			bwval = fm_bcd(replystr.substr(p+6), 2);
 	}
 	if (bwval != A.iBW) {
@@ -826,7 +829,7 @@ int RIG_IC705::get_bwA()
 		mode_bwA[A.imode] = bwval;
 	}
 
-	if (useB) selectB();
+	if (current_vfo == onB) selectB();
 
 	igett("get_bwA");
 
@@ -839,7 +842,9 @@ void RIG_IC705::set_bwA(int val)
 	if (A.imode == 3 || A.imode == 11) return; // FM, FM-D
 
 	A.iBW = val;
-	if (useB) selectA();
+
+	int current_vfo = inuse;
+	if (current_vfo == onB) selectA();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
@@ -850,24 +855,25 @@ void RIG_IC705::set_bwA(int val)
 	mode_bwA[A.imode] = val;
 	isett("set_bwA");
 
-	if (useB) selectB();
+	if (current_vfo == onB) selectB();
 }
 
 int RIG_IC705::get_bwB()
 {
 	if (B.imode == 3 || B.imode == 11) return 0; // FM, FM-D
 
-	if (!useB) selectB();
+	int current_vfo = inuse;
+	if (current_vfo == onA) selectB();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
 	int bwval = B.iBW;
 	if (waitFOR(8, "get_bwB")) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x1A\x03");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			bwval = fm_bcd(replystr.substr(p+6), 2);
 	}
 	if (bwval != B.iBW) {
@@ -875,7 +881,7 @@ int RIG_IC705::get_bwB()
 		mode_bwB[B.imode] = bwval;
 	}
 
-	if (!useB) selectA();
+	if (current_vfo == onA) selectA();
 
 	igett("get_bwB");
 
@@ -887,7 +893,8 @@ void RIG_IC705::set_bwB(int val)
 	if (B.imode == 3 || B.imode == 11) return; // FM, FM-D
 	B.iBW = val;
 
-	if (!useB) selectB();
+	int current_vfo = inuse;
+	if (current_vfo == onA) selectB();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
@@ -898,7 +905,7 @@ void RIG_IC705::set_bwB(int val)
 	mode_bwB[B.imode] = val;
 	isett("set_bwB");
 
-	if (!useB) selectA();
+	if (current_vfo == onA) selectA();
 }
 
 // LSB  USB  AM   FM   CW  CW-R  RTTY  RTTY-R  LSB-D  USB-D  AM-D  FM-D
@@ -963,7 +970,7 @@ const char ** RIG_IC705::bwtable(int m)
 int RIG_IC705::def_bandwidth(int m)
 {
 	int bw = adjust_bandwidth(m);
-	if (useB) {
+	if (inuse == onB) {
 		if (mode_bwB[m] == -1)
 			mode_bwB[m] = bw;
 		return mode_bwB[m];
@@ -976,15 +983,15 @@ int RIG_IC705::def_bandwidth(int m)
 int RIG_IC705::get_mic_gain()
 {
 	int val = 0;
-	string cstr = "\x14\x0B";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0B";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get mic")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	return val;
@@ -1035,7 +1042,7 @@ void RIG_IC705::get_compression(int &on, int &val)
 
 	if (waitFOR(8, "get comp on/off")) {
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = (replystr[p+6] == 0x01);
 	}
 
@@ -1045,7 +1052,7 @@ void RIG_IC705::get_compression(int &on, int &val)
 	if (waitFOR(9, "get comp level")) {
 		size_t p = replystr.find(resp);
 		int level = 0;
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			level = fm_bcd(replystr.substr(p+6), 3);
 			for (val = 0; val < 11; val++)
 				if (level <= comp_level[val]) break;
@@ -1158,7 +1165,7 @@ int RIG_IC705::get_break_in()
 	resp.assign(pre_fm);
 	if (waitFOR(8, "get break in")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			progStatus.break_in = replystr[p+6];
 			if (progStatus.break_in == 0) break_in_label("qsk");
 			else  if (progStatus.break_in == 1) break_in_label("SEMI");
@@ -1227,12 +1234,12 @@ int RIG_IC705::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 	if (waitFOR(8, "get PTT")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	return ptt_;
@@ -1259,15 +1266,15 @@ FE FE E0 7A 14 01 00 65 FD
 int RIG_IC705::get_volume_control()
 {
 	int val = 0;
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get vol")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	return (val);
@@ -1282,7 +1289,7 @@ void RIG_IC705::set_power_control(double val)
 {
 	cmd = pre_to;
 	cmd.append("\x14\x0A");
-	cmd.append(bcd255(val));
+	cmd.append(bcd255(val * 10));
 	cmd.append( post );
 	set_trace(2, "set_power_control()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set power");
@@ -1291,15 +1298,15 @@ void RIG_IC705::set_power_control(double val)
 double RIG_IC705::get_power_control()
 {
 	int val = progStatus.power_level;
-	string cstr = "\x14\x0A";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0A";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	if (waitFOR(9, "get power")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			val = num100(replystr.substr(p+6));
+		if (p != std::string::npos)
+			val = num100(replystr.substr(p+6)) / 10;
 	}
 	get_trace(2, "get_power_control()", str2hex(replystr.c_str(), replystr.length()));
 	return val;
@@ -1307,13 +1314,13 @@ double RIG_IC705::get_power_control()
 
 void RIG_IC705::get_pc_min_max_step(double &min, double &max, double &step)
 {
-	min = 0; max = 100; step = 1.0;
+	min = 0; max = 10.0; step = 0.1;
 }
 
 int RIG_IC705::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1321,7 +1328,7 @@ int RIG_IC705::get_smeter()
 	int mtr= -1;
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.41);
 			if (mtr > 100) mtr = 100;
@@ -1332,8 +1339,8 @@ int RIG_IC705::get_smeter()
 
 double RIG_IC705::get_voltmeter()
 {
-	string cstr = "\x15\x15";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x15";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1348,7 +1355,7 @@ double RIG_IC705::get_voltmeter()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			val = 16.0 * mtr / 241.0;
 			return val;
@@ -1361,31 +1368,37 @@ struct pwrpair {int mtr; float pwr;};
 
 static pwrpair pwrtbl[] = {
 	{0,   0.0},
-	{21,  0.4},
-	{43,  0.8},
-	{65,  1.3},
-	{83,  1.7},
-	{95,  2.1},
-	{105, 2.5},
-	{114, 2.9},
-	{124, 3.3},
-	{143, 4.2},
-	{183, 6.3},
-	{213, 8.3},
-	{255, 10.0 } };
+	{26,  0.5},
+	{52,  1.0},
+	{80,  2.0},
+	{104, 3.0},
+	{122, 4.0},
+	{143, 5.0},
+	{158, 6.0},
+	{174, 7.0},
+	{191, 8.0},
+	{210, 9.0},
+	{228, 10.0},
+	{245, 11.0},
+	{255, 11.6}
+};
 
 int RIG_IC705::get_power_out(void)
 {
-	string cstr = "\x15\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	int mtr= 0;
-	if (waitFOR(9, "get power out")) {
+
+	int ret = waitFOR(9, "get power out");
+	igett("get power out");
+
+	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
 			for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
@@ -1420,8 +1433,8 @@ static swrpair swrtbl[] = {
 
 int RIG_IC705::get_swr(void)
 {
-	string cstr = "\x15\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1429,7 +1442,7 @@ int RIG_IC705::get_swr(void)
 	int mtr= -1;
 	if (waitFOR(9, "get swr")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
 			for (i = 0; i < sizeof(swrtbl) / sizeof(swrpair) - 1; i++)
@@ -1448,8 +1461,8 @@ int RIG_IC705::get_swr(void)
 
 int RIG_IC705::get_alc(void)
 {
-	string cstr = "\x15\x13";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x13";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1457,7 +1470,7 @@ int RIG_IC705::get_alc(void)
 	int mtr= -1;
 	if (waitFOR(9, "get alc")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /1.2);
 			if (mtr > 100) mtr = 100;
@@ -1478,14 +1491,14 @@ void RIG_IC705::set_rf_gain(int val)
 int RIG_IC705::get_rf_gain()
 {
 	int val = progStatus.rfgain;
-	string cstr = "\x14\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x02";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	if (waitFOR(9, "get RF")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	return val;
@@ -1541,15 +1554,15 @@ void RIG_IC705::set_preamp(int val)
 
 int RIG_IC705::get_preamp()
 {
-	string cstr = "\x16\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get Preamp Level")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			preamp_level = replystr[p+6];
 			if (preamp_level == 1) {
 				preamp_label("Amp 1", true);
@@ -1593,11 +1606,11 @@ int RIG_IC705::get_attenuator()
 	cmd = pre_to;
 	cmd += '\x11';
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x11';
 	if (waitFOR(7, "get ATT")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == 0x20) {
 				atten_label("20 dB", true);
 				atten_level = 1;
@@ -1624,15 +1637,15 @@ void RIG_IC705::set_noise(bool val)
 int RIG_IC705::get_noise()
 {
 	int val = progStatus.noise;
-	string cstr = "\x16\x22";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x22";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get noise")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = replystr[p+6];
 		}
 	}
@@ -1651,15 +1664,15 @@ void RIG_IC705::set_nb_level(int val)
 int  RIG_IC705::get_nb_level()
 {
 	int val = progStatus.nb_level;
-	string cstr = "\x14\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get NB level")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	return val;
@@ -1676,15 +1689,15 @@ void RIG_IC705::set_noise_reduction(int val)
 
 int RIG_IC705::get_noise_reduction()
 {
-	string cstr = "\x16\x40";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x40";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get NR")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return progStatus.noise_reduction;
@@ -1720,15 +1733,15 @@ void RIG_IC705::set_noise_reduction_val(int val)
 int RIG_IC705::get_noise_reduction_val()
 {
 	int val = progStatus.noise_reduction_val;
-	string cstr = "\x14\x06";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x06";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get NRval")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = fm_bcd(replystr.substr(p+6),3);
 			val -= 8;
 			val /= 16;
@@ -1749,15 +1762,15 @@ void RIG_IC705::set_squelch(int val)
 int  RIG_IC705::get_squelch()
 {
 	int val = progStatus.squelch;
-	string cstr = "\x14\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get squelch")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	return val;
@@ -1775,15 +1788,15 @@ void RIG_IC705::set_auto_notch(int val)
 
 int RIG_IC705::get_auto_notch()
 {
-	string cstr = "\x16\x41";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x41";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get AN")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				auto_notch_label("AN", true);
 				return true;
@@ -1847,8 +1860,8 @@ bool RIG_IC705::get_notch(int &val)
 	bool on = false;
 	val = 1500;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1856,7 +1869,7 @@ bool RIG_IC705::get_notch(int &val)
 	if (waitFOR(8, "get notch")) {
 		get_trace(2, "get_notch()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = replystr[p + 6];
 		cmd = pre_to;
 		resp = pre_fm;
@@ -1866,7 +1879,7 @@ bool RIG_IC705::get_notch(int &val)
 		cmd.append(post);
 		if (waitFOR(9, "notch val")) {
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				val = (int)ceil(fm_bcd(replystr.substr(p+6),3));
 				val -= 128;
 				val *= 20;
@@ -1922,7 +1935,7 @@ int  RIG_IC705::get_agc()
 	cmd.append(post);
 	if (waitFOR(8, "get AGC")) {
 		size_t p = replystr.find(pre_fm);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			agcval = replystr[p+6]; // 1 == off, 2 = FAST, 3 = MED, 4 = SLOW
 	}
 	return agcval;
@@ -2019,15 +2032,15 @@ void RIG_IC705::set_pbt_outer(int val)
 int RIG_IC705::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt inner")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -2039,15 +2052,15 @@ int RIG_IC705::get_pbt_inner()
 int RIG_IC705::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -2078,7 +2091,7 @@ double RIG_IC705::getVfoAdj()
 
 	if (waitFOR(11, "get vfo adj")) {
 		size_t p = replystr.find(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			vfo_ = num100(replystr.substr(p+8));
 		}
 	}
@@ -2107,7 +2120,7 @@ Rx 56 bytes
 39 | 20 20 20 20 20 20 20 20 20 20 20 20 20 20 20 20  register description 16 chars
 55 | FD
 */
-// test string
+// test std::string
 const char bstack[] = "\
 \xFE\xFE\xE0\xA4\x1A\
 \x01\x03\x01\
@@ -2161,7 +2174,7 @@ void RIG_IC705::get_band_selection(int v)
 	if (waitFOR(56, "get band stack")) {
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			int bandfreq = fm_bcd_be(replystr.substr(p + 8, 5), 10);
 //			int bandmode = fm_bcd(replystr.substr(p + 13, 1) ,2);
 			int mode = 0;
@@ -2191,7 +2204,7 @@ void RIG_IC705::get_band_selection(int v)
 					break;
 				}
 			}
-			if (useB) {
+			if (inuse == onB) {
 				set_vfoB(bandfreq);
 				set_modeB(mode);
 				set_FILT(bandfilter);
@@ -2212,9 +2225,9 @@ void RIG_IC705::set_band_selection(int v)
 		case 12: v = 14; break;
 		default: break;
 	}
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int fil = (useB ? B.filter : A.filter);
-	int mode = (useB ? B.imode : A.imode);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int fil = (inuse == onB ? B.filter : A.filter);
+	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd += '\x1A'; cmd += '\x01';
