@@ -20,6 +20,8 @@
 
 #include "icom/IC718.h"
 
+#include "support.h"
+
 bool DEBUG_718 = true;
 
 //=============================================================================
@@ -130,7 +132,7 @@ void RIG_IC718::selectB()
 
 bool RIG_IC718::check ()
 {
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -142,15 +144,15 @@ bool RIG_IC718::check ()
 
 unsigned long int RIG_IC718::get_vfoA ()
 {
-	if (useB) return A.freq;
+	if (inuse == onB) return A.freq;
 	cmd = pre_to;
 	cmd += '\x03';
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -172,15 +174,15 @@ void RIG_IC718::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC718::get_vfoB ()
 {
-	if (!useB) return B.freq;
-	string resp = pre_fm;
+	if (inuse == onA) return B.freq;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
 	cmd.append( post );
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -217,11 +219,11 @@ int RIG_IC718::get_volume_control()
 	cmd = pre_to;
 	cmd.append("\x14\x01");
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp.append("\x14\x01");
 	if (waitFOR(9, "get vol")) {
 		size_t p = replystr.rfind(resp);
-		if ( p != string::npos)
+		if ( p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6),3) * 100 / 255);
 	}
 	return 0;
@@ -237,12 +239,12 @@ int RIG_IC718::get_smeter()
 	cmd = pre_to;
 	cmd.append("\x15\x02");
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp.append("\x15\x02");
 	int mtr = 0;
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(1.3 * mtr - 36.0);
 			if (mtr < 0) mtr = 0;
@@ -276,11 +278,11 @@ int RIG_IC718::get_noise()
 	cmd = pre_to;
 	cmd.append("\x16\x22");
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp.append("\x16\x22");
 	if (waitFOR(8, "get noise")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return 0;
@@ -309,11 +311,11 @@ int RIG_IC718::get_noise_reduction()
 	cmd = pre_to;
 	cmd.append("\x16\x40");
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp.append("\x16\x40");
 	if (waitFOR(8, "get nr")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return 0;
@@ -332,15 +334,15 @@ void RIG_IC718::set_noise_reduction_val(int val)
 int RIG_IC718::get_noise_reduction_val()
 {
 	int val = 0;
-	string cstr = "\x14\x06";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x06";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get NRval")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = fm_bcd(replystr.substr(p+6), 3);
 		val = (val - 8) / 16;
 	}
@@ -363,12 +365,12 @@ int RIG_IC718::get_preamp()
 	cmd += '\x16';
 	cmd += '\x02';
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x16';
 	resp += '\x02';
 	if (waitFOR(8, "get pre")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				preamp_label("Pre", true);
 				return 1;
@@ -395,11 +397,11 @@ int RIG_IC718::get_rf_gain()
 {
 	cmd = pre_to;
 	cmd.append("\x14\x02").append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	cmd.append("\x14\x02");
 	if (waitFOR(9, "get rfg")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6),3) * 100 / 255);
 	}
 	return 0;
@@ -426,14 +428,14 @@ void RIG_IC718::set_power_control(double val)
 
 double RIG_IC718::get_power_control()
 {
-	string cstr = "\x14\x0A";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0A";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	if (waitFOR(9, "get power")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p + 6),3) * 100 / 255);
 	}
 	return progStatus.power_level;
@@ -451,15 +453,15 @@ void RIG_IC718::set_mic_gain(int val)
 
 int RIG_IC718::get_mic_gain()
 {
-	string cstr = "\x14\x0B";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0B";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get mic")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6),3) / 2.55);
 	}
 	return 0;
@@ -488,11 +490,11 @@ int RIG_IC718::get_modeA()
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 	if (waitFOR(8, "get modeA")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1) { modeA = filA = 0; return modeA; }
 			modeA = replystr[p+5];
 			if (modeA > 6) modeA -= 2;
@@ -518,11 +520,11 @@ int RIG_IC718::get_modeB()
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 	if (waitFOR(8, "get modeB")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1) { modeB = filB = 0; return modeB; }
 			modeB = replystr[p+5];
 			if (modeB > 6) modeB -= 2;
@@ -576,12 +578,12 @@ int RIG_IC718::get_auto_notch()
 	cmd += '\x16';
 	cmd += '\x41';
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x16';
 	resp += '\x41';
 	if (waitFOR(8, "get AN")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[6] == 0x01) {
 				auto_notch_label("AN", true);
 				return 1;
@@ -645,10 +647,10 @@ int RIG_IC718::get_split()
 	cmd.append("\x0F");
 	cmd.append( post );
 	if (waitFOR(7, "get split")) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x0F");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			read_split = replystr[p+5];
 		if (read_split != 0xFA) // fail byte
 			split = read_split;
