@@ -21,9 +21,11 @@
 #include <sstream>
 
 #include "icom/IC7200.h"
-#include "support.h"
+#include "status.h"
 #include "trace.h"
 
+#include "support.h"
+
 //=============================================================================
 // IC-7200
 
@@ -275,7 +277,7 @@ void RIG_IC7200::selectB()
 
 bool RIG_IC7200::check ()
 {
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -297,8 +299,8 @@ bool RIG_IC7200::check ()
 
 unsigned long int RIG_IC7200::get_vfoA ()
 {
-	if (useB) return A.freq;
-	string resp = pre_fm;
+	if (inuse == onB) return A.freq;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -307,7 +309,7 @@ unsigned long int RIG_IC7200::get_vfoA ()
 	get_trace(1, "get vfo A");
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -333,8 +335,8 @@ void RIG_IC7200::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC7200::get_vfoB ()
 {
-	if (!useB) return B.freq;
-	string resp = pre_fm;
+	if (inuse == onA) return B.freq;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -343,7 +345,7 @@ unsigned long int RIG_IC7200::get_vfoB ()
 	get_trace(1, "get vfo B");
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -411,14 +413,14 @@ int RIG_IC7200::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 
 	get_trace(1, "get PTT");
 	if (waitFOR(8, "get PTT")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	geth();
@@ -441,8 +443,8 @@ void RIG_IC7200::set_volume_control(int val)
 int RIG_IC7200::get_volume_control()
 {
 	int val = progStatus.volume;
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -451,7 +453,7 @@ int RIG_IC7200::get_volume_control()
 	get_trace(1, "get volume control");
 	if (waitFOR(9, "get vol")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	geth();
@@ -466,8 +468,8 @@ void RIG_IC7200::get_vol_min_max_step(int &min, int &max, int &step)
 
 int RIG_IC7200::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -477,7 +479,7 @@ int RIG_IC7200::get_smeter()
 	get_trace(1, "get smeter");
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
@@ -504,8 +506,8 @@ static pwrpair pwrtbl[] = {
 
 int RIG_IC7200::get_power_out(void)
 {
-	string cstr = "\x15\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -515,7 +517,7 @@ int RIG_IC7200::get_power_out(void)
 	get_trace(1, "get power out");
 	if (waitFOR(9, "get power out")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
 			for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
@@ -536,8 +538,8 @@ int RIG_IC7200::get_power_out(void)
 
 int RIG_IC7200::get_swr(void) 
 {
-	string cstr = "\x15\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -547,7 +549,7 @@ int RIG_IC7200::get_swr(void)
 	get_trace(1, "get swr");
 	if (waitFOR(9, "get swr")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
@@ -560,8 +562,8 @@ int RIG_IC7200::get_swr(void)
 
 int RIG_IC7200::get_alc(void)
 {
-	string cstr = "\x15\x13";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x13";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -571,7 +573,7 @@ int RIG_IC7200::get_alc(void)
 	get_trace(1, "get alc");
 	if (waitFOR(9, "get alc")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
@@ -596,8 +598,8 @@ void RIG_IC7200::set_noise(bool val)
 int RIG_IC7200::get_noise()
 {
 	int val = progStatus.noise;
-	string cstr = "\x16\x22";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x22";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -606,7 +608,7 @@ int RIG_IC7200::get_noise()
 	get_trace(1, "get noise");
 	if (waitFOR(8, "get noise")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = replystr[p+6];
 		}
 	}
@@ -629,8 +631,8 @@ void RIG_IC7200::set_nb_level(int val)
 int  RIG_IC7200::get_nb_level()
 {
 	int val = progStatus.nb_level;
-	string cstr = "\x14\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -639,7 +641,7 @@ int  RIG_IC7200::get_nb_level()
 	get_trace(1, "get nb level");
 	if (waitFOR(9, "get NB level")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	geth();
@@ -660,8 +662,8 @@ void RIG_IC7200::set_noise_reduction(int val)
 
 int RIG_IC7200::get_noise_reduction()
 {
-	string cstr = "\x16\x40";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x40";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -670,7 +672,7 @@ int RIG_IC7200::get_noise_reduction()
 	get_trace(1, "get noise reduction");
 	if (waitFOR(8, "get NR")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	geth();
@@ -694,8 +696,8 @@ void RIG_IC7200::set_noise_reduction_val(int val)
 int RIG_IC7200::get_noise_reduction_val()
 {
 	int val = progStatus.noise_reduction_val;
-	string cstr = "\x14\x06";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x06";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -704,7 +706,7 @@ int RIG_IC7200::get_noise_reduction_val()
 	get_trace(1, "get noise reduction val");
 	if (waitFOR(9, "get NRval")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = fm_bcd(replystr.substr(p+6), 3);
 			val = (val - 8) / 16;
 		}
@@ -745,14 +747,14 @@ int RIG_IC7200::get_attenuator()
 	cmd = pre_to;
 	cmd += '\x11';
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x11';
 
 	get_trace(1, "get attenuator");
 	if (waitFOR(7, "get ATT")) {
 		get_trace(1, str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (!replystr[p+5]) {
 				atten_label("ATT", false);
 				atten_level = 0;
@@ -803,8 +805,8 @@ void RIG_IC7200::set_preamp(int val)
 
 int RIG_IC7200::get_preamp()
 {
-	string cstr = "\x16\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -813,7 +815,7 @@ int RIG_IC7200::get_preamp()
 	get_trace(1, "get preamp");
 	if (waitFOR(8, "get Pre")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				preamp_label("Pre ON", true);
 				preamp_level = 1;
@@ -841,8 +843,8 @@ void RIG_IC7200::set_rf_gain(int val)
 int RIG_IC7200::get_rf_gain()
 {
 	int val = progStatus.rfgain;
-	string cstr = "\x14\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x02";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
@@ -850,7 +852,7 @@ int RIG_IC7200::get_rf_gain()
 	get_trace(1, "get rf gain");
 	if (waitFOR(9, "get RF")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	geth();
@@ -872,8 +874,8 @@ void RIG_IC7200::set_squelch(int val)
 int  RIG_IC7200::get_squelch()
 {
 	int val = progStatus.squelch;
-	string cstr = "\x14\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -882,7 +884,7 @@ int  RIG_IC7200::get_squelch()
 	get_trace(1, "get squelch");
 	if (waitFOR(9, "get squelch")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	geth();
@@ -903,18 +905,18 @@ void RIG_IC7200::set_power_control(double val)
 
 double RIG_IC7200::get_power_control()
 {
-	string cstr = "\x14\x0A";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0A";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	int val = progStatus.power_level;
-	string retstr = "ret str";
+	std::string retstr = "ret str";
 
 	get_trace(1, "get power control");
 	if (waitFOR(9, "get power")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			retstr = str2hex(replystr.substr(p).c_str(), 9);
 		}
@@ -933,8 +935,8 @@ void RIG_IC7200::get_mic_gain_min_max_step(int &min, int &max, int &step)
 
 int RIG_IC7200::get_mic_gain()
 {
-	string cstr = "\x14\x0B";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0B";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -944,7 +946,7 @@ int RIG_IC7200::get_mic_gain()
 	if (waitFOR(9, "get mic")) {
 		get_trace(1, str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			return num100(replystr.substr(p + 6));
 		}
 	}
@@ -969,7 +971,7 @@ int RIG_IC7200::get_modeA()
 	int md = A.imode;
 	size_t p = 0;
 
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 	cmd = pre_to;
 	cmd += '\x04';
@@ -978,7 +980,7 @@ int RIG_IC7200::get_modeA()
 	get_trace(1, "get mode A");
 	if (waitFOR(8, "get mode A")) {
 		p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1) { md = A.filter = 0; }
 			else {
 				md = replystr[p + 5];
@@ -998,7 +1000,7 @@ int RIG_IC7200::get_modeA()
 	get_trace(1, "get data modeA");
 	if (waitFOR(9, "data mode?")) {
 		p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if ((replystr[p+6] & 0x01) == 0x01) {
 				if (md == 0) md = 7;
 				if (md == 1) md = 8;
@@ -1064,13 +1066,13 @@ int RIG_IC7200::get_modeB()
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 
 	get_trace(1, "get mode B");
 	if (waitFOR(8, "get mode B")) {
 		p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1) { md = B.filter = 0; }
 			else {
 				md = replystr[p+5];
@@ -1090,7 +1092,7 @@ int RIG_IC7200::get_modeB()
 	get_trace(1, "get data B");
 	if (waitFOR(9, "get data B")) {
 		p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if ((replystr[p+6] & 0x01) == 0x01) {
 				if (md == 0) md = 7;
 				if (md == 1) md = 8;
@@ -1156,7 +1158,7 @@ int RIG_IC7200::get_modetype(int n)
 
 int RIG_IC7200::get_FILT(int mode)
 {
-	if (useB) return mode_filterB[mode];
+	if (inuse == onB) return mode_filterB[mode];
 	return mode_filterA[mode];
 }
 
@@ -1165,7 +1167,7 @@ void RIG_IC7200::set_FILT(int filter)
 	if (filter < 1 || filter > 3)
 		return;
 
-	if (useB) {
+	if (inuse == onB) {
 		B.filter = filter;
 		mode_filterB[B.imode] = filter;
 
@@ -1227,7 +1229,7 @@ const char *RIG_IC7200::FILT(int val)
 const char *RIG_IC7200::nextFILT()
 {
 	int val = A.filter;
-	if (useB) val = B.filter;
+	if (inuse == onB) val = B.filter;
 	val++;
 	if (val > 3) val = 1;
 	set_FILT(val);
@@ -1236,7 +1238,7 @@ const char *RIG_IC7200::nextFILT()
 
 void RIG_IC7200::set_FILTERS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_filterA[i];
@@ -1258,7 +1260,7 @@ std::string RIG_IC7200::get_FILTERS()
 		if (mode_filterB[i] < 1) mode_filterB[i] = 1;
 		if (mode_filterB[i] > 3) mode_filterB[i] = 3;
 	}
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_filterA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -1268,7 +1270,7 @@ std::string RIG_IC7200::get_FILTERS()
 
 std::string RIG_IC7200::get_BANDWIDTHS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_bwA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -1278,7 +1280,7 @@ std::string RIG_IC7200::get_BANDWIDTHS()
 
 void RIG_IC7200::set_BANDWIDTHS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_bwA[i];
@@ -1321,7 +1323,7 @@ int RIG_IC7200::adjust_bandwidth(int m)
 int RIG_IC7200::def_bandwidth(int m)
 {
 	int bw = adjust_bandwidth(m);
-	if (useB) {
+	if (inuse == onB) {
 		if (mode_bwB[m] == -1)
 			mode_bwB[m] = bw;
 		return mode_bwB[m];
@@ -1373,14 +1375,14 @@ int  RIG_IC7200::get_bwA()
 	cmd = pre_to;
 	cmd += "\x1A\x02";
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += "\x1A\x02";
 	int bwval = A.iBW;
 
 	get_trace(1, "get BW A");
 	if (waitFOR(8, "get BW A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			bwval = (fm_bcd(replystr.substr(p+6),2));
 	}
 	if (bwval != A.iBW) {
@@ -1411,14 +1413,14 @@ int  RIG_IC7200::get_bwB()
 	cmd = pre_to;
 	cmd += "\x1A\x02";
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += "\x1A\x02";
 	int bwval = B.iBW;
 
 	get_trace(1, "get BW B");
 	if (waitFOR(8, "get BW B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			bwval = (fm_bcd(replystr.substr(p+6),2));
 	}
 	if (bwval != B.iBW) {
@@ -1444,8 +1446,8 @@ void RIG_IC7200::set_auto_notch(int val)
 
 int RIG_IC7200::get_auto_notch()
 {
-	string cstr = "\x16\x41";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x41";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1454,7 +1456,7 @@ int RIG_IC7200::get_auto_notch()
 	get_trace(1, "get AN");
 	if (waitFOR(8, "get AN")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				auto_notch_label("AN", true);
 				geth();
@@ -1504,7 +1506,7 @@ void RIG_IC7200::get_compression(int &on, int &val)
 	get_trace(1, "get comp on/off");
 	if (waitFOR(8, "get comp on/off")) {
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = (replystr[p+6] == 0x01);
 	}
 	geth();
@@ -1516,7 +1518,7 @@ void RIG_IC7200::get_compression(int &on, int &val)
 	if (waitFOR(9, "get comp level")) {
 		size_t p = replystr.find(resp);
 		int level = 0;
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			level = fm_bcd(replystr.substr(p+6), 3);
 			for (val = 0; val < 11; val++)
 				if (level <= comp_level[val]) break;
@@ -1597,15 +1599,15 @@ bool RIG_IC7200::get_notch(int &val)
 	bool on = false;
 	val = 1500;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get notch")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = replystr[p + 6];
 		cmd = pre_to;
 		resp = pre_fm;
@@ -1616,7 +1618,7 @@ bool RIG_IC7200::get_notch(int &val)
 		get_trace(1, "notch val");
 		if (waitFOR(9, "notch val")) {
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				val = (int)ceil(fm_bcd(replystr.substr(p+6),3));
 				val -= 128;
 				val *= 20;
@@ -1672,7 +1674,7 @@ int  RIG_IC7200::get_agc()
 	get_trace(1, "get AGC");
 	if (waitFOR(8, "get AGC")) {
 		size_t p = replystr.find(pre_fm);
-		if (p == string::npos) return agcval;
+		if (p == std::string::npos) return agcval;
 		return (agcval = replystr[p+6]); // 1 = off, 2 = FAST, 3 = SLOW
 	}
 	geth();
@@ -1778,8 +1780,8 @@ void RIG_IC7200::set_pbt_outer(int val)
 int RIG_IC7200::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1788,7 +1790,7 @@ int RIG_IC7200::get_pbt_inner()
 	get_trace(1, "get pbt inner");
 	if (waitFOR(9, "get pbt inner")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -1800,8 +1802,8 @@ int RIG_IC7200::get_pbt_inner()
 int RIG_IC7200::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1810,7 +1812,7 @@ int RIG_IC7200::get_pbt_outer()
 	get_trace(1, "get pbt outer");
 	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -1926,7 +1928,7 @@ double RIG_IC7200::getVfoAdj()
 	get_trace(1, "get vfo adj");
 	if (waitFOR(10, "get vfo adj")) {
 		size_t p = replystr.find(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			vfo_ = num100(replystr.substr(p+7));
 		}
 	}
@@ -1946,13 +1948,13 @@ void RIG_IC7200::get_band_selection(int v)
 	if (waitFOR(17, "get band")) {
 		std::string ans = replystr;
 		size_t p = ans.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(ans.substr(p+8, 5), 10);
 			int bandmode = ans[p+13];
 			int bandfilter = ans[p+14];
 			int banddata = ans[p+15] & 0x10;
 			if ((bandmode == 0 || bandmode == 1) && banddata) bandmode += 7;
-			if (useB) {
+			if (inuse == onB) {
 				set_vfoB(bandfreq);
 				set_modeB(bandmode);
 				set_FILT(bandfilter);
@@ -1968,9 +1970,9 @@ void RIG_IC7200::get_band_selection(int v)
 
 void RIG_IC7200::set_band_selection(int v)
 {
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int mode = (useB ? B.imode : A.imode);
-	int fil = (useB ? B.filter : A.filter);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int mode = (inuse == onB ? B.imode : A.imode);
+	int fil = (inuse == onB ? B.filter : A.filter);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
