@@ -25,12 +25,14 @@
 //
 const char IC728name_[] = "IC-728";
 const char *IC728modes_[] = { "LSB", "USB", "AM", "CW", "RTTY", "FM", NULL};
+const char IC728_mode_type[] = { 'L', 'U', 'U', 'L', 'L', 'U' };
 const char *IC728_widths[] = { "NARR", "WIDE", NULL};
 static int IC728_bw_vals[] = {1,2, WVALS_LIMIT};
 
 RIG_IC728::RIG_IC728() {
 	name_ = IC728name_;
 	modes_ = IC728modes_;
+	_mode_type = IC728_mode_type;
 	bandwidths_ = IC728_widths;
 	bw_vals_ = IC728_bw_vals;
 	comm_baudrate = BR1200;
