@@ -22,6 +22,8 @@
 #include <sstream>
 
 #include "debug.h"
+#include "status.h"
+
 #include "support.h"
 
 //======================================================================
@@ -171,15 +173,15 @@ void RIG_IC756::set_pbt_outer(int val)
 int RIG_IC756::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt inner")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -191,15 +193,15 @@ int RIG_IC756::get_pbt_inner()
 int RIG_IC756::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -345,13 +347,23 @@ void RIG_IC756PRO::swapAB()
 	cmd.append(post);
 	waitFB("Exchange main/sub");
 
-	selectA();
-	get_modeA();
-	get_bwA();
-	selectB();
-	get_modeB();
-	get_bwB();
-	if (!useB) selectA();
+	int current_vfo = inuse;
+
+	if (current_vfo == onA) {
+		selectB();
+		get_modeB();
+		get_bwB();
+		selectA();
+		get_modeA();
+		get_bwA();
+	} else {
+		selectA();
+		get_modeA();
+		get_bwA();
+		selectB();
+		get_modeB();
+		get_bwB();
+	}
 }
 
 void RIG_IC756PRO::A2B()
@@ -361,10 +373,11 @@ void RIG_IC756PRO::A2B()
 	cmd.append(post);
 	waitFB("Equalize main/sub");
 
+	int current_vfo = inuse;
 	selectB();
 	get_modeB();
 	get_bwB();
-	if (!useB) selectA();
+	if (current_vfo == onA) selectA();
 }
 
 void RIG_IC756PRO::selectA()
@@ -374,6 +387,7 @@ void RIG_IC756PRO::selectA()
 	cmd += '\xD0';
 	cmd.append(post);
 	waitFB("sel A");
+	inuse = onA;
 }
 
 void RIG_IC756PRO::selectB()
@@ -383,11 +397,12 @@ void RIG_IC756PRO::selectB()
 	cmd += '\xD1';
 	cmd.append(post);
 	waitFB("sel B");
+	inuse = onB;
 }
 
 bool RIG_IC756PRO::check ()
 {
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -399,16 +414,16 @@ bool RIG_IC756PRO::check ()
 
 unsigned long int RIG_IC756PRO::get_vfoA ()
 {
-	if (useB) return A.freq;
-	string cstr = "\x03";
-	string resp = pre_fm;
+	if (inuse == onB) return A.freq;
+	std::string cstr = "\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -430,16 +445,16 @@ void RIG_IC756PRO::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC756PRO::get_vfoB ()
 {
-	if (!useB) return B.freq;
-	string cstr = "\x03";
-	string resp = pre_fm;
+	if (inuse == onA) return B.freq;
+	std::string cstr = "\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -461,15 +476,15 @@ void RIG_IC756PRO::set_vfoB (unsigned long int freq)
 
 int RIG_IC756PRO::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6), 3) / 2.55);
 	}
 	return 0;
@@ -489,15 +504,15 @@ void RIG_IC756PRO::set_volume_control(int val)
 
 int RIG_IC756PRO::get_volume_control()
 {
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get vol")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return ((int)ceil(fm_bcd(replystr.substr(p+6),3) * 100 / 255));
 	}
 	return progStatus.volume;
@@ -526,12 +541,12 @@ int RIG_IC756PRO::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 	if (waitFOR(8, "get PTT")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	return ptt_;
@@ -549,15 +564,15 @@ void RIG_IC756PRO::set_noise(bool val)
 
 int RIG_IC756PRO::get_noise()
 {
-	string cstr = "\x16\x22";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x22";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get noise")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return 0;
@@ -574,15 +589,15 @@ void RIG_IC756PRO::set_noise_reduction(int val)
 
 int RIG_IC756PRO::get_noise_reduction()
 {
-	string cstr = "\x16\x40";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x40";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get NR")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return progStatus.noise_reduction;
@@ -603,15 +618,15 @@ void RIG_IC756PRO::set_noise_reduction_val(int val)
 int RIG_IC756PRO::get_noise_reduction_val()
 {
 	int val = progStatus.noise_reduction_val;
-	string cstr = "\x14\x06";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x06";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get NRval")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = fm_bcd(replystr.substr(p+6), 3);
 			if (val == 255) val = 16;
 			else val = val/ 16;
@@ -702,15 +717,15 @@ void RIG_IC756PRO::set_pbt_outer(int val)
 int RIG_IC756PRO::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt inner")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -722,15 +737,15 @@ int RIG_IC756PRO::get_pbt_inner()
 int RIG_IC756PRO::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -761,16 +776,16 @@ void RIG_IC756PRO::set_power_control(double val)
 
 double RIG_IC756PRO::get_power_control()
 {
-	string cstr = "\x14\x0A";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0A";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	int val = progStatus.power_level;
-	string retstr = "ret str";
+	std::string retstr = "ret str";
 	if (waitFOR(9, "get power")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			retstr = str2hex(replystr.substr(p).c_str(), 9);
 		}
@@ -790,14 +805,14 @@ void RIG_IC756PRO::set_rf_gain(int val)
 int RIG_IC756PRO::get_rf_gain()
 {
 	int val = progStatus.rfgain;
-	string cstr = "\x14\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x02";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	if (waitFOR(9, "get RF")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	return val;
@@ -839,15 +854,15 @@ int RIG_IC756PRO::get_modeA()
 	int md = A.imode;
 	int mf = mode_filterA[A.imode];
 
-	string cstr = "\x04";
-	string resp = pre_fm;
+	std::string cstr = "\x04";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get mode A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1) { A.imode = mf = 0; }
 			else {
 				md = replystr[p+5];
@@ -883,15 +898,15 @@ int RIG_IC756PRO::get_modeB()
 	int md = B.imode;
 	int mf = mode_filterB[B.imode];
 
-	string cstr = "\x04";
-	string resp = pre_fm;
+	std::string cstr = "\x04";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get mode B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1) { B.imode = mf = 0; }
 			else {
 				md = replystr[p+5];
@@ -909,13 +924,13 @@ int RIG_IC756PRO::get_modeB()
 
 int RIG_IC756PRO::adjust_bandwidth(int m)
 {
-	if (useB) return B.iBW;
+	if (inuse == onB) return B.iBW;
 	return A.iBW;
 }
 
 int RIG_IC756PRO::def_bandwidth(int m)
 {
-	if (useB) return B.iBW;
+	if (inuse == onB) return B.iBW;
 	return A.iBW;
 }
 
@@ -997,15 +1012,15 @@ bool RIG_IC756PRO::get_notch(int &val)
 	bool on = false;
 	val = 0;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get notch")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = replystr[p + 6] ? 1 : 0;
 		cmd = pre_to;
 		resp = pre_fm;
@@ -1015,7 +1030,7 @@ bool RIG_IC756PRO::get_notch(int &val)
 		cmd.append(post);
 		if (waitFOR(9, "get notch val")) {
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				val = fm_bcd(replystr.substr(p+6),3);
 				val = (val - 53) * 20;
 				if (val < 0) val = 0;
@@ -1085,15 +1100,15 @@ void RIG_IC756PRO::set_attenuator(int val)
 
 int RIG_IC756PRO::get_attenuator()
 {
-	string cstr = "\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(7, "get att")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == 0x06) {
 				atten_level = 1;
 				atten_label("6 dB", true);
@@ -1142,15 +1157,15 @@ void RIG_IC756PRO::set_preamp(int val)
 
 int RIG_IC756PRO::get_preamp()
 {
-	string cstr = "\x16\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get preamp")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				preamp_label("Pre 1", true);
 				preamp_level = 1;
@@ -1175,7 +1190,7 @@ const char *RIG_IC756PRO::FILT(int val)
 
 int RIG_IC756PRO::get_FILT(int mode)
 {
-	if (useB) return mode_filterB[mode];
+	if (inuse == onB) return mode_filterB[mode];
 	return mode_filterA[mode];
 }
 
@@ -1184,7 +1199,7 @@ void RIG_IC756PRO::set_FILT(int filter)
 	if (filter < 1 || filter > 3)
 		return;
 
-	if (useB) {
+	if (inuse == onB) {
 		B.filter = filter;
 		int val = B.imode;
 		mode_filterB[val - 1] = filter;
@@ -1220,7 +1235,7 @@ void RIG_IC756PRO::set_FILT(int filter)
 
 const char *RIG_IC756PRO::nextFILT()
 {
-	if (useB) {
+	if (inuse == onB) {
 		B.filter++;
 		if (B.filter > 3) B.filter = 1;
 
@@ -1239,7 +1254,7 @@ const char *RIG_IC756PRO::nextFILT()
 
 void RIG_IC756PRO::set_FILTERS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_filterA[i];
@@ -1261,7 +1276,7 @@ std::string RIG_IC756PRO::get_FILTERS()
 		if (mode_filterB[i] < 1) mode_filterB[i] = 1;
 		if (mode_filterB[i] > 3) mode_filterB[i] = 3;
 	}
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_filterA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -1307,7 +1322,7 @@ int RIG_IC756PRO::get_break_in()
 	resp.assign(pre_fm);
 	if (waitFOR(8, "get break in")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			progStatus.break_in = replystr[p+6];
 			if (progStatus.break_in == 0) break_in_label("qsk");
 			else  break_in_label("QSK ON");
@@ -1378,7 +1393,7 @@ void RIG_IC756PRO::get_compression(int &on, int &val)
 
 	if (waitFOR(8, "get comp on/off")) {
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = (replystr[p+6] == 0x01);
 	}
 
@@ -1388,7 +1403,7 @@ void RIG_IC756PRO::get_compression(int &on, int &val)
 	if (waitFOR(9, "get comp level")) {
 		size_t p = replystr.find(resp);
 		int level = 0;
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			level = fm_bcd(replystr.substr(p+6), 3);
 			for (val = 0; val < 11; val++)
 				if (level <= comp_level[val]) break;
@@ -1448,7 +1463,7 @@ void RIG_IC756PRO::get_band_selection(int v)
 	if (waitFOR(23, "get band stack")) {
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
@@ -1461,7 +1476,7 @@ void RIG_IC756PRO::get_band_selection(int v)
 			for (index = 0; index < sizeof(PL_tones) / sizeof(*PL_tones); index++)
 				if (tone == PL_tones[index]) break;
 			rTONE = index;
-			if (useB) {
+			if (inuse == onB) {
 				set_vfoB(bandfreq);
 				set_modeB(bandmode);
 				set_FILT(bandfilter);
@@ -1477,9 +1492,9 @@ void RIG_IC756PRO::get_band_selection(int v)
 
 void RIG_IC756PRO::set_band_selection(int v)
 {
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int fil = (useB ? filB : filA);
-	int mode = (useB ? B.imode : A.imode);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int fil = (inuse == onB ? filB : filA);
+	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
