@@ -20,6 +20,8 @@
 
 #include "icom/IC756PRO2.h"
 #include "debug.h"
+#include "status.h"
+
 #include "support.h"
 
 const char IC756PRO2name_[] = "IC-756PRO-II";
@@ -187,6 +189,7 @@ void RIG_IC756PRO2::selectA()
 	cmd.append(post);
 	waitFB("sel A");
 	set_trace(2, "selectA()", str2hex(cmd.c_str(), cmd.length()));
+	inuse = onA;
 }
 
 void RIG_IC756PRO2::selectB()
@@ -197,11 +200,12 @@ void RIG_IC756PRO2::selectB()
 	cmd.append(post);
 	waitFB("sel B");
 	set_trace(2, "selectB()", str2hex(cmd.c_str(), cmd.length()));
+	inuse = onB;
 }
 
 bool RIG_IC756PRO2::check ()
 {
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -213,16 +217,16 @@ bool RIG_IC756PRO2::check ()
 
 unsigned long int RIG_IC756PRO2::get_vfoA ()
 {
-	if (useB) return A.freq;
-	string cstr = "\x03";
-	string resp = pre_fm;
+	if (inuse == onB) return A.freq;
+	std::string cstr = "\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -246,16 +250,16 @@ void RIG_IC756PRO2::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC756PRO2::get_vfoB ()
 {
-	if (!useB) return B.freq;
-	string cstr = "\x03";
-	string resp = pre_fm;
+	if (inuse == onA) return B.freq;
+	std::string cstr = "\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -279,8 +283,8 @@ void RIG_IC756PRO2::set_vfoB (unsigned long int freq)
 
 int RIG_IC756PRO2::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -288,7 +292,7 @@ int RIG_IC756PRO2::get_smeter()
 	int mtr = -1;
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			mtr = (int)ceil(fm_bcd(replystr.substr(p+6), 3) / 2.55);
 	}
 	get_trace(2, "get_smeter()", str2hex(replystr.c_str(), replystr.length()));
@@ -310,15 +314,15 @@ void RIG_IC756PRO2::set_volume_control(int val)
 
 int RIG_IC756PRO2::get_volume_control()
 {
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get vol")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return ((int)(fm_bcd(replystr.substr(p+6),3)));
 	}
 	get_trace(2, "get_volume_control()", str2hex(replystr.c_str(), replystr.length()));
@@ -347,12 +351,12 @@ int RIG_IC756PRO2::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 	if (waitFOR(8, "get PTT")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	get_trace(2, "get_PTT()", str2hex(replystr.c_str(), replystr.length()));
@@ -373,15 +377,15 @@ void RIG_IC756PRO2::set_noise(bool val)
 int RIG_IC756PRO2::get_noise()
 {
 	int val = progStatus.noise;
-	string cstr = "\x16\x22";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x22";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get noise")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = (replystr[p+6] ? 1 : 0);
 	}
 	get_trace(2, "get_noise()", str2hex(replystr.c_str(), replystr.length()));
@@ -399,15 +403,15 @@ void RIG_IC756PRO2::set_noise_reduction(int val)
 
 int RIG_IC756PRO2::get_noise_reduction()
 {
-	string cstr = "\x16\x40";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x40";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get NR")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return 0;
@@ -425,15 +429,15 @@ void RIG_IC756PRO2::set_noise_reduction_val(int val)
 
 int RIG_IC756PRO2::get_noise_reduction_val()
 {
-	string cstr = "\x14\x06";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x06";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get NR val")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6),3) / 2.55);
 	}
 	return 0;
@@ -522,15 +526,15 @@ void RIG_IC756PRO2::set_pbt_outer(int val)
 int RIG_IC756PRO2::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt inner")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -542,15 +546,15 @@ int RIG_IC756PRO2::get_pbt_inner()
 int RIG_IC756PRO2::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -647,8 +651,8 @@ static const char *szfilter[] = {"1", "2", "3"};
 int RIG_IC756PRO2::get_modeA()
 {
 	int md;
-	string cstr = "\x04";
-	string resp = pre_fm;
+	std::string cstr = "\x04";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -657,7 +661,7 @@ int RIG_IC756PRO2::get_modeA()
 	if (waitFOR(8, "get mode A")) {
 		get_trace(2, "get_modeA()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1) { A.imode = filA = 0; }
 			else {
 				md = replystr[p+5];
@@ -673,7 +677,7 @@ int RIG_IC756PRO2::get_modeA()
 				if (waitFOR(8, "data ?")) {
 					get_trace(2, "get_data_modeA()", str2hex(replystr.c_str(), replystr.length()));
 					p = replystr.rfind(resp);
-					if (p != string::npos) {
+					if (p != std::string::npos) {
 						if (replystr[p+6]) {
 							switch (md) {
 								case 0 : md = 8; break;
@@ -724,8 +728,8 @@ void RIG_IC756PRO2::set_modeB(int val)
 int RIG_IC756PRO2::get_modeB()
 {
 	int md;
-	string cstr = "\x04";
-	string resp = pre_fm;
+	std::string cstr = "\x04";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -733,7 +737,7 @@ int RIG_IC756PRO2::get_modeB()
 	if (waitFOR(8, "get mode B")) {
 		get_trace(2, "get_modeB()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1) { B.imode = filB = 0; }
 			else {
 				md = replystr[p+5];
@@ -748,7 +752,7 @@ int RIG_IC756PRO2::get_modeB()
 				if (waitFOR(8, "data ?")) {
 					get_trace(2, "get_data_modeB()", str2hex(replystr.c_str(), replystr.length()));
 					p = replystr.rfind(resp);
-					if (p != string::npos) {
+					if (p != std::string::npos) {
 						if (replystr[p+6]) {
 							switch (md) {
 								case 0 : md = 8; break;
@@ -816,8 +820,8 @@ const char **RIG_IC756PRO2::bwtable(int m)
 
 int RIG_IC756PRO2::get_swr()
 {
-	string cstr = "\x15\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -825,7 +829,7 @@ int RIG_IC756PRO2::get_swr()
 	int mtr = -1;
 	if (waitFOR(9, "get swr")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			mtr = (int)ceil(fm_bcd(replystr.substr(p + 6),3) / 2.55 );
 	}
 	get_trace(2, "get_swr()", str2hex(replystr.c_str(), replystr.length()));
@@ -834,8 +838,8 @@ int RIG_IC756PRO2::get_swr()
 
 int RIG_IC756PRO2::get_alc()
 {
-	string cstr = "\x15\x13";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x13";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -843,7 +847,7 @@ int RIG_IC756PRO2::get_alc()
 	int mtr = -1;
 	if (waitFOR(9, "get alc")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			mtr = (int)ceil(fm_bcd(replystr.substr(p + 6),3) / 2.55 );
 	}
 	get_trace(2, "get_alc()", str2hex(replystr.c_str(), replystr.length()));
@@ -853,8 +857,8 @@ int RIG_IC756PRO2::get_alc()
 // Transceiver power level return power in watts
 int RIG_IC756PRO2::get_power_out()
 {
-	string cstr = "\x15\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -862,7 +866,7 @@ int RIG_IC756PRO2::get_power_out()
 	int mtr = -1;
 	if (waitFOR(9, "get power")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			mtr = (int)ceil(fm_bcd(replystr.substr(p + 6),3) / 2.55 );
 	}
 	get_trace(2, "get_power_out()", str2hex(replystr.c_str(), replystr.length()));
@@ -888,15 +892,15 @@ void RIG_IC756PRO2::set_bwA(int val)
 
 int  RIG_IC756PRO2::get_bwA()
 {
-	string cstr = "\x1A\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x1A\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get bw A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			A.iBW = (int)(fm_bcd(replystr.substr(p + 6), 2));
 	}
 	get_trace(2, "get_bwA()", str2hex(replystr.c_str(), replystr.length()));
@@ -926,15 +930,15 @@ void RIG_IC756PRO2::set_bwB(int val)
 
 int  RIG_IC756PRO2::get_bwB()
 {
-	string cstr = "\x1A\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x1A\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get bw B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			B.iBW = (int)(fm_bcd(replystr.substr(p + 6), 2));
 	}
 	get_trace(2, "get_bwB()", str2hex(replystr.c_str(), replystr.length()));
@@ -974,15 +978,15 @@ bool RIG_IC756PRO2::get_notch(int &val)
 	bool on = false;
 	val = 0;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get notch")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = replystr[p + 6] ? 1 : 0;
 		cmd = pre_to;
 		resp = pre_fm;
@@ -992,7 +996,7 @@ bool RIG_IC756PRO2::get_notch(int &val)
 		cmd.append(post);
 		if (waitFOR(9, "get notch val")) {
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos)
+			if (p != std::string::npos)
 				val = 20*ceil(fm_bcd(replystr.substr(p + 6),3) - 128);
 		}
 	}
@@ -1043,15 +1047,15 @@ void RIG_IC756PRO2::set_attenuator(int val)
 
 int RIG_IC756PRO2::get_attenuator()
 {
-	string cstr = "\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(7, "get att")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == 0x06) {
 				atten_level = 1;
 				atten_label("6 dB", true);
@@ -1101,15 +1105,15 @@ void RIG_IC756PRO2::set_preamp(int val)
 
 int RIG_IC756PRO2::get_preamp()
 {
-	string cstr = "\x16\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get preamp")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				preamp_label("Pre 1", true);
 				preamp_level = 1;
@@ -1128,7 +1132,7 @@ int RIG_IC756PRO2::get_preamp()
 
 const char *RIG_IC756PRO2::FILT(int &val)
 {
-	if (useB) {
+	if (inuse == onB) {
 		val = filB;
 		return(szfilter[filB - 1]);
 	}
@@ -1140,7 +1144,7 @@ const char *RIG_IC756PRO2::FILT(int &val)
 
 const char *RIG_IC756PRO2::nextFILT()
 {
-	if (useB) {
+	if (inuse == onB) {
 		filB++;
 		if (filB > 3) filB = 1;
 		set_modeB(B.imode);
@@ -1188,7 +1192,7 @@ void RIG_IC756PRO2::get_band_selection(int v)
 	if (waitFOR(23, "get band stack")) {
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
@@ -1203,7 +1207,7 @@ void RIG_IC756PRO2::get_band_selection(int v)
 			for (index = 0; index < sizeof(PL_tones) / sizeof(*PL_tones); index++)
 				if (tone == PL_tones[index]) break;
 			rTONE = index;
-			if (useB) {
+			if (inuse == onB) {
 				set_vfoB(bandfreq);
 				set_modeB(bandmode);
 				set_FILT(bandfilter);
@@ -1219,9 +1223,9 @@ void RIG_IC756PRO2::get_band_selection(int v)
 
 void RIG_IC756PRO2::set_band_selection(int v)
 {
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int fil = (useB ? filB : filA);
-	int mode = (useB ? B.imode : A.imode);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int fil = (inuse == onB ? filB : filA);
+	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
