@@ -20,6 +20,8 @@
 
 #include "icom/IC756PRO3.h"
 #include "debug.h"
+#include "status.h"
+
 #include "support.h"
 
 //=============================================================================
@@ -193,6 +195,7 @@ void RIG_IC756PRO3::selectA()
 	cmd += '\xB0';
 	cmd.append(post);
 	waitFB("sel A");
+	inuse = onA;
 }
 
 void RIG_IC756PRO3::selectB()
@@ -202,11 +205,12 @@ void RIG_IC756PRO3::selectB()
 	cmd += '\xB1';
 	cmd.append(post);
 	waitFB("sel B");
+	inuse = onB;
 }
 
 bool RIG_IC756PRO3::check ()
 {
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -218,16 +222,16 @@ bool RIG_IC756PRO3::check ()
 
 unsigned long int RIG_IC756PRO3::get_vfoA ()
 {
-	if (useB) return A.freq;
-	string cstr = "\x03";
-	string resp = pre_fm;
+	if (inuse == onB) return A.freq;
+	std::string cstr = "\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -249,16 +253,16 @@ void RIG_IC756PRO3::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC756PRO3::get_vfoB ()
 {
-	if (!useB) return B.freq;
-	string cstr = "\x03";
-	string resp = pre_fm;
+	if (inuse == onA) return B.freq;
+	std::string cstr = "\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				B.freq = 0;
 			else
@@ -280,15 +284,15 @@ void RIG_IC756PRO3::set_vfoB (unsigned long int freq)
 
 int RIG_IC756PRO3::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6), 3) / 2.55);
 	}
 	return 0;
@@ -296,15 +300,15 @@ int RIG_IC756PRO3::get_smeter()
 
 int RIG_IC756PRO3::get_power_out()
 {
-	string cstr = "\x15\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get pout")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6), 3) / 2.55);
 	}
 	return 0;
@@ -312,15 +316,15 @@ int RIG_IC756PRO3::get_power_out()
 
 int RIG_IC756PRO3::get_alc()
 {
-	string cstr = "\x15\x13";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x13";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get alc")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6), 3) / 2.55);
 	}
 	return 0;
@@ -328,15 +332,15 @@ int RIG_IC756PRO3::get_alc()
 
 int RIG_IC756PRO3::get_swr()
 {
-	string cstr = "\x15\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get swr")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6), 3) / 2.55);
 	}
 	return 0;
@@ -356,15 +360,15 @@ void RIG_IC756PRO3::set_volume_control(int val)
 
 int RIG_IC756PRO3::get_volume_control()
 {
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get vol")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6),3) / 2.55);
 	}
 	return 0;
@@ -391,12 +395,12 @@ int RIG_IC756PRO3::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 	if (waitFOR(8, "get PTT")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	return ptt_;
@@ -414,15 +418,15 @@ void RIG_IC756PRO3::set_noise(bool val)
 
 int RIG_IC756PRO3::get_noise()
 {
-	string cstr = "\x16\x22";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x22";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get noise")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return progStatus.noise;
@@ -439,15 +443,15 @@ void RIG_IC756PRO3::set_noise_reduction(int val)
 
 int RIG_IC756PRO3::get_noise_reduction()
 {
-	string cstr = "\x16\x40";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x40";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get NR")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return progStatus.noise_reduction;
@@ -465,15 +469,15 @@ void RIG_IC756PRO3::set_noise_reduction_val(int val)
 
 int RIG_IC756PRO3::get_noise_reduction_val()
 {
-	string cstr = "\x14\x06";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x06";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get NR val")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6),3) / 2.55);
 	}
 	return progStatus.noise_reduction_val;
@@ -486,15 +490,15 @@ int RIG_IC756PRO3::get_modetype(int n)
 
 int RIG_IC756PRO3::get_mic_gain()
 {
-	string cstr = "\x14\x0B";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0B";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get mic")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6),3) / 2.55);
 	}
 	return 0;
@@ -577,15 +581,15 @@ void RIG_IC756PRO3::set_pbt_outer(int val)
 int RIG_IC756PRO3::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt inner")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -597,15 +601,15 @@ int RIG_IC756PRO3::get_pbt_inner()
 int RIG_IC756PRO3::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -626,15 +630,15 @@ void RIG_IC756PRO3::set_squelch(int val)
 
 int  RIG_IC756PRO3::get_squelch()
 {
-	string cstr = "\x14\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get sql")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p+6), 3) / 2.55);
 	}
 	return progStatus.squelch;
@@ -652,14 +656,14 @@ void RIG_IC756PRO3::set_rf_gain(int val)
 
 int RIG_IC756PRO3::get_rf_gain()
 {
-	string cstr = "\x14\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x02";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	if (waitFOR(9, "get rfgain")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p + 6),3) / 2.55);
 	}
 	return progStatus.rfgain;
@@ -676,14 +680,14 @@ void RIG_IC756PRO3::set_power_control(double val)
 
 double RIG_IC756PRO3::get_power_control()
 {
-	string cstr = "\x14\x0A";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0A";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	if (waitFOR(9, "get power")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (int)ceil(fm_bcd(replystr.substr(p + 6),3) / 2.55);
 	}
 	return progStatus.power_level;
@@ -773,15 +777,15 @@ int  RIG_IC756PRO3::get_bwA()
 	if (bandwidths_ == IC756PRO3_AMFMwidths) {
 		return A.iBW - 1;
 	}
-	string cstr = "\x1A\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x1A\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get bw A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			A.iBW = (int)(fm_bcd(replystr.substr(p + 6), 2));
 	}
 	return A.iBW;
@@ -808,15 +812,15 @@ int  RIG_IC756PRO3::get_bwB()
 	if (bandwidths_ == IC756PRO3_AMFMwidths) {
 		return B.iBW - 1;
 	}
-	string cstr = "\x1A\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x1A\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get bw B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			B.iBW = (int)(fm_bcd(replystr.substr(p + 6), 2));
 	}
 	return B.iBW;
@@ -851,15 +855,15 @@ bool RIG_IC756PRO3::get_notch(int &val)
 	bool on = false;
 	val = 0;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get notch")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = replystr[p + 6] ? 1 : 0;
 		cmd = pre_to;
 		resp = pre_fm;
@@ -869,7 +873,7 @@ bool RIG_IC756PRO3::get_notch(int &val)
 		cmd.append(post);
 		if (waitFOR(9, "get notch val")) {
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos)
+			if (p != std::string::npos)
 				val = 20*ceil(fm_bcd(replystr.substr(p + 6),3) - 128);
 		}
 	}
@@ -920,15 +924,15 @@ void RIG_IC756PRO3::set_attenuator(int val)
 
 int RIG_IC756PRO3::get_attenuator()
 {
-	string cstr = "\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(7, "get att")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == 0x06) {
 				atten_level = 1;
 				atten_label("6 dB", true);
@@ -977,15 +981,15 @@ void RIG_IC756PRO3::set_preamp(int val)
 
 int RIG_IC756PRO3::get_preamp()
 {
-	string cstr = "\x16\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get preamp")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				preamp_label("Pre 1", true);
 				preamp_level = 1;
@@ -1033,15 +1037,15 @@ static const char *szfilter[] = {"1", "2", "3"};
 int RIG_IC756PRO3::get_modeA()
 {
 	int md = 0;
-	string cstr = "\x04";
-	string resp = pre_fm;
+	std::string cstr = "\x04";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get mode A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			md = replystr[p+5];
 			if (md == -1) { md = filA = 0; }
 			else {
@@ -1055,7 +1059,7 @@ int RIG_IC756PRO3::get_modeA()
 				cmd.append(post);
 				if (waitFOR(9, "data mode?")) {
 					p = replystr.rfind(resp);
-					if (p != string::npos) {
+					if (p != std::string::npos) {
 						if (replystr[p+6]) {
 							switch (md) {
 								case 0 : md = 8; break;
@@ -1102,15 +1106,15 @@ void RIG_IC756PRO3::set_modeB(int val)
 int RIG_IC756PRO3::get_modeB()
 {
 	int md = 0;
-	string cstr = "\x04";
-	string resp = pre_fm;
+	std::string cstr = "\x04";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get mode B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			md = replystr[p+5];
 			if (md == -1) { md = filB = 0; }
 			else {
@@ -1124,7 +1128,7 @@ int RIG_IC756PRO3::get_modeB()
 				cmd.append(post);
 				if (waitFOR(9, "data mode?")) {
 					p = replystr.rfind(resp);
-					if (p != string::npos) {
+					if (p != std::string::npos) {
 						if (replystr[p+6]) {
 							switch (md) {
 								case 0 : md = 8; break;
@@ -1154,15 +1158,15 @@ void RIG_IC756PRO3::set_auto_notch(int val)
 
 int RIG_IC756PRO3::get_auto_notch()
 {
-	string cstr = "\x16\x41";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x41";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get AN")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				auto_notch_label("AN", true);
 				return true;
@@ -1177,7 +1181,7 @@ int RIG_IC756PRO3::get_auto_notch()
 
 const char *RIG_IC756PRO3::FILT(int &val)
 {
-	if (useB) {
+	if (inuse == onB) {
 		val = filB;
 		return(szfilter[filB - 1]);
 	}
@@ -1189,7 +1193,7 @@ const char *RIG_IC756PRO3::FILT(int &val)
 
 const char *RIG_IC756PRO3::nextFILT()
 {
-	if (useB) {
+	if (inuse == onB) {
 		filB++;
 		if (filB > 3) filB = 1;
 		set_modeB(B.imode);
@@ -1237,7 +1241,7 @@ void RIG_IC756PRO3::get_band_selection(int v)
 	if (waitFOR(23, "get band stack")) {
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
@@ -1252,7 +1256,7 @@ void RIG_IC756PRO3::get_band_selection(int v)
 			for (index = 0; index < sizeof(PL_tones) / sizeof(*PL_tones); index++)
 				if (tone == PL_tones[index]) break;
 			rTONE = index;
-			if (useB) {
+			if (inuse == onB) {
 				set_vfoB(bandfreq);
 				set_modeB(bandmode);
 				set_FILT(bandfilter);
@@ -1268,9 +1272,9 @@ void RIG_IC756PRO3::get_band_selection(int v)
 
 void RIG_IC756PRO3::set_band_selection(int v)
 {
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int fil = (useB ? filB : filA);
-	int mode = (useB ? B.imode : A.imode);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int fil = (inuse == onB ? filB : filA);
+	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
