@@ -247,6 +247,7 @@ RIG_IC7610::RIG_IC7610() {
 	has_swr_control = true;
 	has_alc_control = true;
 	has_sql_control = true;
+	has_idd_control = true;
 	has_agc_control = true;
 
 	has_power_control = true;
@@ -1345,6 +1346,31 @@ int RIG_IC7610::get_smeter()
 	return mtr;
 }
 
+double RIG_IC7610::get_idd(void)
+{
+	get_trace(1, "get_idd()");
+	std::string cstr = "\x15\x16";
+	std::string resp = pre_fm;
+	resp.append(cstr);
+	cmd = pre_to;
+	cmd.append(cstr);
+	cmd.append( post );
+	double mtr= 0;
+
+	int ret = waitFOR(9, "get idd");
+	igett("");
+
+	if (ret) {
+		size_t p = replystr.rfind(resp);
+		if (p != std::string::npos) {
+			mtr = fm_bcd(replystr.substr(p+6), 3);
+			mtr = 25.0 * mtr / 241.0;
+			if (mtr > 25) mtr = 25;
+		}
+	}
+	return mtr;
+}
+
 double RIG_IC7610::get_voltmeter()
 {
 	std::string cstr = "\x15\x15";
