@@ -106,7 +106,7 @@ static GUI rig_widgets[]= {
 	{ (Fl_Widget *)NULL,          0,   0,   0 }
 };
 
-static string menu012 = "EX01200004";
+static std::string menu012 = "EX01200004";
 
 void RIG_TS480HX::initialize()
 {
@@ -231,7 +231,7 @@ void RIG_TS480HX::check_menu_45()
 	cmd = "EX0450000;";
 	if (wait_char(';', 11, 100, "Check menu item 45", ASC) >= 11) {
 		size_t p = replystr.rfind("EX045");
-		if (p != string::npos)
+		if (p != std::string::npos)
 			menu_45 = (replystr[p+9] == '1');
 	}
 
@@ -273,7 +273,7 @@ int RIG_TS480HX::get_smeter()
 	if (ret < 8) return 0;
 
 	size_t p = replystr.rfind("SM");
-	if (p != string::npos)
+	if (p != std::string::npos)
 		mtr = 5 * atoi(&replystr[p + 3]);
 	return mtr;
 }
@@ -299,7 +299,7 @@ int RIG_TS480HX::get_power_out()
 	if (ret < 8) return mtr;
 
 	size_t p = replystr.rfind("SM");
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		mtr = atoi(&replystr[p + 3]);
 
 		size_t i = 0;
@@ -332,10 +332,10 @@ int RIG_TS480HX::get_swr()
 	if (ret < 8) return (int)mtr;
 
 	size_t p = replystr.rfind("RM1");
-	if (p != string::npos)
+	if (p != std::string::npos)
 		mtr = 66 * atoi(&replystr[p + 3]) / 10;
 	p = replystr.rfind("RM3");
-	if (p != string::npos)
+	if (p != std::string::npos)
 		alc = 66 * atoi(&replystr[p+3]) / 10;
 	else
 		alc = 0;
@@ -453,7 +453,7 @@ int RIG_TS480HX::get_modeA()
 	if (ret < 4) return A.imode;
 
 	size_t p = replystr.rfind("MD");
-	if (p != string::npos && (p + 2 < replystr.length())) {
+	if (p != std::string::npos && (p + 2 < replystr.length())) {
 		int md = replystr[p+2];
 		md = md - '1';
 		if (md == 8) md = 7;
@@ -487,7 +487,7 @@ int RIG_TS480HX::get_modeB()
 	if (ret < 4) return B.imode;
 
 	size_t p = replystr.rfind("MD");
-	if (p != string::npos && (p + 2 < replystr.length())) {
+	if (p != std::string::npos && (p + 2 < replystr.length())) {
 		int md = replystr[p+2];
 		md = md - '1';
 		if (md == 8) md = 7;
@@ -551,13 +551,13 @@ int RIG_TS480HX::get_bwA()
 		gett("");
 		if (ret == 5) {
 			p = replystr.rfind("SL");
-			if (p != string::npos)
+			if (p != std::string::npos)
 				lo = fm_decimal(replystr.substr(p+2), 2);
 		}
 		cmd = "SH;";
 		if (wait_char(';', 5, 100, "get SH", ASC) == 5) {
 			p = replystr.rfind("SH");
-			if (p != string::npos)
+			if (p != std::string::npos)
 				hi = fm_decimal(replystr.substr(p+2), 2);
 			A.iBW = ((hi << 8) | (lo & 0xFF)) | 0x8000;
 		}
@@ -568,7 +568,7 @@ int RIG_TS480HX::get_bwA()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 11; i++)
 					if (replystr.find(TS480HX_CWbw[i]) == p)
 						break;
@@ -583,7 +583,7 @@ int RIG_TS480HX::get_bwA()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 4; i++)
 					if (replystr.find(TS480HX_FSKbw[i]) == p)
 						break;
@@ -641,7 +641,7 @@ int RIG_TS480HX::get_bwB()
 		gett("");
 		if (ret == 5) {
 			p = replystr.rfind("SL");
-			if (p != string::npos)
+			if (p != std::string::npos)
 				lo = fm_decimal(replystr.substr(p+2), 2);
 		}
 		cmd = "SH;";
@@ -650,7 +650,7 @@ int RIG_TS480HX::get_bwB()
 		gett("");
 		if (ret == 5) {
 			p = replystr.rfind("SH");
-			if (p != string::npos)
+			if (p != std::string::npos)
 				hi = fm_decimal(replystr.substr(p+2), 2);
 			B.iBW = ((hi << 8) | (lo & 0xFF)) | 0x8000;
 		}
@@ -661,7 +661,7 @@ int RIG_TS480HX::get_bwB()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 11; i++)
 					if (replystr.find(TS480HX_CWbw[i]) == p)
 						break;
@@ -676,7 +676,7 @@ int RIG_TS480HX::get_bwB()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 4; i++)
 					if (replystr.find(TS480HX_FSKbw[i]) == p)
 						break;
@@ -730,7 +730,7 @@ double RIG_TS480HX::get_power_control()
 	if (ret < 6) return val;
 
 	size_t p = replystr.rfind("PC");
-	if (p == string::npos) return val;
+	if (p == std::string::npos) return val;
 
 	val = atoi(&replystr[p + 2]);
 
@@ -782,7 +782,7 @@ int RIG_TS480HX::get_preamp()
 	if (ret < 5) return preamp_level;
 
 	size_t p = replystr.rfind("PA");
-	if (p != string::npos)
+	if (p != std::string::npos)
 		preamp_level = (replystr[p+2] == '1');
 	return preamp_level;
 }
@@ -804,7 +804,7 @@ bool RIG_TS480HX::get_if_shift(int &val)
 	gett("");
 	if (ret == 8) {
 		size_t p = replystr.rfind("IS");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = fm_decimal(replystr.substr(p+3), 4);
 			if (replystr[p+2] == '-') val *= -1;
 			return (val != 0);
@@ -852,7 +852,7 @@ int  RIG_TS480HX::get_noise_reduction()
 	gett("");
 	if (ret == 4) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) return _noise_reduction_level;
+		if (p == std::string::npos) return _noise_reduction_level;
 		_noise_reduction_level = replystr[p+2] - '0';
 	}
 
@@ -890,7 +890,7 @@ int  RIG_TS480HX::get_noise_reduction_val()
 	gett("");
 	if (ret == 5) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) {
+		if (p == std::string::npos) {
 			nrval = (_noise_reduction_level == 1 ? _nrval1 : _nrval2);
 			return nrval;
 		}
@@ -910,7 +910,7 @@ int  RIG_TS480HX::get_agc()
 	ret = wait_char(';', 6, 100, "GET agc val", ASC);
 	gett("");
 	size_t p = replystr.rfind("GT");
-	if (p == string::npos) return agcval;
+	if (p == std::string::npos) return agcval;
 	if (replystr[4] == ' ') return 0;
 	agcval = replystr[4] - '0' + 1; // '0' == off, '1' = fast, '2' = slow
 	return agcval;
@@ -961,7 +961,7 @@ int  RIG_TS480HX::get_auto_notch()
 	if (ret == 4) {
 		int anotch = 0;
 		size_t p = replystr.rfind("BC");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			anotch = (replystr[p+2] == '1');
 			return anotch;
 		}
@@ -988,7 +988,7 @@ int RIG_TS480HX::get_noise()
 	gett("");
 	if (ret == 4) {
 		size_t p = replystr.rfind("NB");
-		if (p == string::npos) return 0;
+		if (p == std::string::npos) return 0;
 		if (replystr[p+2] == '0') return 0;
 	}
 	return 1;
@@ -1036,7 +1036,7 @@ int  RIG_TS480HX::get_rf_gain()
 	if (ret < 6) return val;
 
 	size_t p = replystr.rfind("RG");
-	if (p != string::npos)
+	if (p != std::string::npos)
 		val = fm_decimal(replystr.substr(p+2), 3);
 	return val;
 }
@@ -1051,6 +1051,7 @@ void RIG_TS480HX::selectA()
 	cmd = "FR0;FT0;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "Rx on A, Tx on A", cmd, "");
+	inuse = onA;
 }
 
 void RIG_TS480HX::selectB()
@@ -1058,12 +1059,13 @@ void RIG_TS480HX::selectB()
 	cmd = "FR1;FT1;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "Rx on B, Tx on B", cmd, "");
+	inuse = onB;
 }
 
 void RIG_TS480HX::set_split(bool val) 
 {
 	split = val;
-	if (useB) {
+	if (inuse == onB) {
 		if (val) {
 			cmd = "FR1;FT0;";
 			sendCommand(cmd);
@@ -1101,7 +1103,7 @@ int RIG_TS480HX::get_split()
 	cmd.append(";");
 	if (wait_char(';', 4, 100, "get split tx vfo", ASC) == 4) {
 		p = replystr.rfind(rsp);
-		if (p == string::npos) return split;
+		if (p == std::string::npos) return split;
 		tx = replystr[p+2];
 	}
 // rx vfo
@@ -1109,7 +1111,7 @@ int RIG_TS480HX::get_split()
 	cmd.append(";");
 	if (wait_char(';', 4, 100, "get split rx vfo", ASC) == 4) {
 		p = replystr.rfind(rsp);
-		if (p == string::npos) return split;
+		if (p == std::string::npos) return split;
 		rx = replystr[p+2];
 	}
 
@@ -1127,7 +1129,7 @@ unsigned long int RIG_TS480HX::get_vfoA ()
 	if (wait_char(';', 14, 100, "get vfo A", ASC) < 14) return A.freq;
 
 	size_t p = replystr.rfind("FA");
-	if (p != string::npos && (p + 12 < replystr.length())) {
+	if (p != std::string::npos && (p + 12 < replystr.length())) {
 		int f = 0;
 		for (size_t n = 2; n < 13; n++)
 			f = f*10 + replystr[p+n] - '0';
@@ -1154,7 +1156,7 @@ unsigned long int RIG_TS480HX::get_vfoB ()
 	if (wait_char(';', 14, 100, "get vfo B", ASC) < 14) return B.freq;
 
 	size_t p = replystr.rfind("FB");
-	if (p != string::npos && (p + 12 < replystr.length())) {
+	if (p != std::string::npos && (p + 12 < replystr.length())) {
 		int f = 0;
 		for (size_t n = 2; n < 13; n++)
 			f = f*10 + replystr[p+n] - '0';
@@ -1190,7 +1192,7 @@ int  RIG_TS480HX::get_squelch()
 	cmd = "SQ0;";
 		if (wait_char(';', 7, 20, "get squelch", ASC) >= 7) {
 			size_t p = replystr.rfind("SQ0");
-			if (p == string::npos) return val;
+			if (p == std::string::npos) return val;
 			replystr[p + 6] = 0;
 			val = atoi(&replystr[p + 3]);
 	}
@@ -1217,7 +1219,7 @@ int  RIG_TS480HX::get_mic_gain()
 	if (wait_char(';', 6, 100, "get mic gain", ASC) < 6) return val;
 
 	size_t p = replystr.rfind("MG");
-	if (p != string::npos)
+	if (p != std::string::npos)
 		val = fm_decimal(replystr.substr(p+2), 3);
 	return val;
 }
@@ -1246,7 +1248,7 @@ int RIG_TS480HX::get_volume_control()
 	if (wait_char(';', 7, 100, "get vol", ASC) < 7) return val;
 
 	size_t p = replystr.rfind("AG");
-	if (p == string::npos) return val;
+	if (p == std::string::npos) return val;
 	replystr[p + 6] = 0;
 	val = atoi(&replystr[p + 3]);
 	val = val * 100 / 255;
