@@ -147,7 +147,7 @@ static GUI rig_widgets[]= {
 	{ (Fl_Widget *)NULL,          0,   0,   0 }
 };
 
-static string menu005;
+static std::string menu005;
 
 void RIG_TS590SG::initialize()
 {
@@ -289,7 +289,7 @@ int RIG_TS590SG::get_smeter()
 	if (ret < 8) return 0;
 
 	size_t p = replystr.find("SM0");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 
 	replystr[p + 7] = 0;
 	mtr = atoi(&replystr[p + 3]);
@@ -309,7 +309,7 @@ int RIG_TS590SG::get_power_out()
 	if (ret < 8) return mtr;
 
 	size_t p = replystr.rfind("SM0");
-	if (p == string::npos) return mtr;
+	if (p == std::string::npos) return mtr;
 
 	mtr = atoi(&replystr[p + 3]);
 	mtr *= 50;
@@ -340,7 +340,7 @@ double RIG_TS590SG::get_power_control()
 	if (ret < 6) return 0;
 
 	size_t p = replystr.rfind("PC");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	int mtr = 0;
 	replystr[p + 5] = 0;
 	mtr = atoi(&replystr[p + 2]);
@@ -364,7 +364,7 @@ int RIG_TS590SG::get_attenuator()
 	if (ret < 7) return 0;
 
 	size_t p = replystr.rfind("RA");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 
 	if (replystr[p + 2] == '0' && 
 		replystr[p + 3] == '0')
@@ -392,7 +392,7 @@ int RIG_TS590SG::get_preamp()
 	if (ret < 5) return 0;
 
 	size_t p = replystr.rfind("PA");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 
 	if (replystr[p  + 2] == '1') 
 		preamp_level = 1;
@@ -437,7 +437,7 @@ int RIG_TS590SG::get_modeA()
 	if (ret < 4) return A.imode;
 
 	size_t p = replystr.rfind("MD");
-	if (p == string::npos) return A.imode;
+	if (p == std::string::npos) return A.imode;
 
 	switch (replystr[p + 2]) {
 		case '1' : md = LSB; break;
@@ -459,7 +459,7 @@ int RIG_TS590SG::get_modeA()
 		if (ret < 4) return A.imode;
 
 		p = replystr.rfind("DA");
-		if (p == string::npos) return A.imode;
+		if (p == std::string::npos) return A.imode;
 		if (replystr[p + 2] == '1') {
 			data_mode = true;
 			if (md == LSB) md = LSBD;
@@ -505,7 +505,7 @@ int RIG_TS590SG::get_modeB()
 	if (ret < 4) return B.imode;
 
 	size_t p = replystr.rfind("MD");
-	if (p == string::npos) return B.imode;
+	if (p == std::string::npos) return B.imode;
 
 	switch (replystr[p + 2]) {
 		case '1' : md = LSB; break;
@@ -527,7 +527,7 @@ int RIG_TS590SG::get_modeB()
 		if (ret < 4) return B.imode;
 
 		p = replystr.rfind("DA");
-		if (p == string::npos) return B.imode;
+		if (p == std::string::npos) return B.imode;
 		if (replystr[p + 2] == '1') {
 			data_mode = true;
 			if (md == LSB) md = LSBD;
@@ -773,7 +773,7 @@ int RIG_TS590SG::get_bwA()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 14; i++)
 					if (replystr.find(TS590SG_CWbw[i]) == p)
 						break;
@@ -790,7 +790,7 @@ int RIG_TS590SG::get_bwA()
 		gett("");
 		if (ret == 7 ) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 4; i++)
 					if (replystr.find(TS590SG_FSKbw[i]) == p)
 						break;
@@ -809,7 +809,7 @@ int RIG_TS590SG::get_bwA()
 		gett("");
 		if (ret == 5) {
 			p = replystr.rfind("SL");
-			if (p == string::npos) break;
+			if (p == std::string::npos) break;
 			lo = fm_decimal(replystr.substr(2), 2);
 			cmd = "SH;";
 			get_trace(1, "get_bwA SSB SL");
@@ -817,7 +817,7 @@ int RIG_TS590SG::get_bwA()
 			gett("");
 			if (ret == 5) {
 				p = replystr.rfind("SH");
-				if (p == string::npos) break;
+				if (p == std::string::npos) break;
 				hi = fm_decimal(replystr.substr(2), 2);
 				A.iBW = ((hi << 8) | (lo & 0x7F)) | 0x8000;
 			}
@@ -833,7 +833,7 @@ int RIG_TS590SG::get_bwA()
 		gett("");
 		if (ret == 5) {
 			p = replystr.rfind("SL");
-			if (p == string::npos) break;
+			if (p == std::string::npos) break;
 			hi = fm_decimal(replystr.substr(2), 2);
 			cmd = "SH;";
 			get_trace(1, "get_bwA SSB SL");
@@ -841,7 +841,7 @@ int RIG_TS590SG::get_bwA()
 			gett("");
 			if (ret == 5) {
 				p = replystr.rfind("SH");
-				if (p == string::npos) break;
+				if (p == std::string::npos) break;
 				lo = fm_decimal(replystr.substr(2), 2);
 				A.iBW = ((hi << 8) | (lo & 0x7F)) | 0x8000;
 			}
@@ -864,7 +864,7 @@ int RIG_TS590SG::get_bwB()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 14; i++)
 					if (replystr.find(TS590SG_CWbw[i]) == p)
 						break;
@@ -881,7 +881,7 @@ int RIG_TS590SG::get_bwB()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 4; i++)
 					if (replystr.find(TS590SG_FSKbw[i]) == p)
 						break;
@@ -900,7 +900,7 @@ int RIG_TS590SG::get_bwB()
 		gett("");
 		if (ret == 5) {
 			p = replystr.rfind("SL");
-			if (p == string::npos) break;
+			if (p == std::string::npos) break;
 			lo = fm_decimal(replystr.substr(2), 2);
 			cmd = "SH;";
 			get_trace(1, "get_bwB SH");
@@ -908,7 +908,7 @@ int RIG_TS590SG::get_bwB()
 			gett("");
 			if (ret == 5) {
 				p = replystr.rfind("SH");
-				if (p == string::npos) break;
+				if (p == std::string::npos) break;
 				hi = fm_decimal(replystr.substr(2), 2);
 				B.iBW = ((hi << 8) | (lo & 0x7F)) | 0x8000;
 			}
@@ -924,7 +924,7 @@ int RIG_TS590SG::get_bwB()
 		gett("");
 		if (ret == 5) {
 			p = replystr.rfind("SL");
-			if (p == string::npos) break;
+			if (p == std::string::npos) break;
 			hi = fm_decimal(replystr.substr(2), 2);
 			cmd = "SH;";
 			get_trace(1, "get_bwB SH");
@@ -932,7 +932,7 @@ int RIG_TS590SG::get_bwB()
 			gett("");
 			if (ret == 5 ) {
 				p = replystr.rfind("SH");
-				if (p == string::npos) break;
+				if (p == std::string::npos) break;
 				lo = fm_decimal(replystr.substr(2), 2);
 				B.iBW = ((hi << 8) | (lo & 0xFF)) | 0x8000;
 			}
@@ -971,7 +971,7 @@ bool RIG_TS590SG::get_if_shift(int &val)
 		gett("");
 		if (ret == 8) {
 			size_t p = replystr.rfind("IS");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				val = fm_decimal(replystr.substr(p+3), 4);
 			} else
 				val = progStatus.shift_val;
@@ -1025,7 +1025,7 @@ int  RIG_TS590SG::get_noise_reduction()
 	gett("");
 	if (ret == 4 ) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) return noise_reduction_level;
+		if (p == std::string::npos) return noise_reduction_level;
 		noise_reduction_level = replystr[p+2] - '0';
 
 		if (noise_reduction_level == 1) {
@@ -1058,7 +1058,7 @@ int  RIG_TS590SG::get_noise_reduction_val()
 	gett("");
 	if (ret == 5) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) return progStatus.noise_reduction_val;
+		if (p == std::string::npos) return progStatus.noise_reduction_val;
 		val = atoi(&replystr[p+2]);
 	}
 	return val;
@@ -1079,7 +1079,7 @@ int  RIG_TS590SG::get_auto_notch()
 	gett("");
 	if (ret == 5) {
 		size_t p = replystr.rfind("NT");
-		if (p == string::npos) return 0;
+		if (p == std::string::npos) return 0;
 		if (replystr[p+2] == '1') return 1;
 	}
 	return 0;
@@ -1111,7 +1111,7 @@ bool  RIG_TS590SG::get_notch(int &val)
 	gett("");
 	if (ret == 5) {
 		size_t p = replystr.rfind("NT");
-		if (p == string::npos)
+		if (p == std::string::npos)
 			return 0;
 		if (replystr[p+2] == '2') {
 			cmd.assign("BP;");
@@ -1120,7 +1120,7 @@ bool  RIG_TS590SG::get_notch(int &val)
 			gett("");
 			if (ret == 6) {
 				size_t p = replystr.rfind("BP");
-				if (p != string::npos)
+				if (p != std::string::npos)
 					val = (int)((atoi(&replystr[p+2]) * 2700.0 / 128.0) + 300.0);
 				return 1;
 			}
@@ -1165,7 +1165,7 @@ int RIG_TS590SG::get_noise()
 	gett("");
 	if (ret == 4) {
 		size_t p = replystr.rfind("NB");
-		if (p == string::npos) return 0;
+		if (p == std::string::npos) return 0;
 		if (replystr[p+2] == '0') return 0;
 		nb_level = replystr[p+2] - '0';
 		if (nb_level == 0) {
@@ -1203,7 +1203,7 @@ int  RIG_TS590SG::get_rf_gain()
 	gett("");
 	if (ret == 6) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) return progStatus.rfgain;
+		if (p == std::string::npos) return progStatus.rfgain;
 		for (int i = 2; i < 5; i++) {
 			rfval *= 10;
 			rfval += replystr[p+i] - '0';
