@@ -147,7 +147,7 @@ static GUI rig_widgets[]= {
 	{ (Fl_Widget *)NULL,          0,   0,   0 }
 };
 
-static string menu005;
+static std::string menu005;
 
 void RIG_TS890S::initialize()
 {
@@ -284,7 +284,7 @@ int RIG_TS890S::get_smeter()
 	if (wait_char(';', 8, 100, "get", ASC) < 8) return 0;
 
 	size_t p = replystr.find("SM0");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 
 	replystr[p + 7] = 0;
 	mtr = atoi(&replystr[p + 3]);
@@ -301,7 +301,7 @@ int RIG_TS890S::get_power_out()
 	if (wait_char(';', 8, 100, "get power", ASC) < 8) return mtr;
 
 	size_t p = replystr.rfind("SM0");
-	if (p == string::npos) return mtr;
+	if (p == std::string::npos) return mtr;
 
 	mtr = atoi(&replystr[p + 3]);
 	mtr *= 50;
@@ -329,7 +329,7 @@ double RIG_TS890S::get_power_control()
 	if (wait_char(';', 6, 100, "get pwr ctrl", ASC) < 6) return 0;
 
 	size_t p = replystr.rfind("PC");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	int mtr = 0;
 	replystr[p + 5] = 0;
 	mtr = atoi(&replystr[p + 2]);
@@ -357,7 +357,7 @@ int RIG_TS890S::get_attenuator()
 	if (wait_char(';', 4, 100, "get att", ASC) < 4) return 0;
 
 	size_t p = replystr.rfind("RA");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 
 	att_level = replystr[p+2] - '0';
 
@@ -392,7 +392,7 @@ int RIG_TS890S::get_preamp()
 	if (wait_char(';', 5, 100, "get preamp", ASC) < 5) return 0;
 
 	size_t p = replystr.rfind("PA");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 
 	if (replystr[p  + 2] == '1') 
 		preamp_level = 1;
@@ -434,7 +434,7 @@ int RIG_TS890S::get_modeA()
 	if (wait_char(';', 4, 100, "get mode A", ASC) < 4) return A.imode;
 
 	size_t p = replystr.rfind("MD");
-	if (p == string::npos) return A.imode;
+	if (p == std::string::npos) return A.imode;
 
 	switch (replystr[p + 2]) {
 		case '1' : md = LSB; break;
@@ -453,7 +453,7 @@ int RIG_TS890S::get_modeA()
 		if (wait_char(';', 4, 100, "get data A", ASC) < 4) return A.imode;
 
 		p = replystr.rfind("DA");
-		if (p == string::npos) return A.imode;
+		if (p == std::string::npos) return A.imode;
 		if (replystr[p + 2] == '1') {
 			data_mode = true;
 			if (md == LSB) md = LSBD;
@@ -496,7 +496,7 @@ int RIG_TS890S::get_modeB()
 	if (wait_char(';', 4, 100, "get mode B", ASC) < 4) return B.imode;
 
 	size_t p = replystr.rfind("MD");
-	if (p == string::npos) return B.imode;
+	if (p == std::string::npos) return B.imode;
 
 	switch (replystr[p + 2]) {
 		case '1' : md = LSB; break;
@@ -515,7 +515,7 @@ int RIG_TS890S::get_modeB()
 		if (wait_char(';', 4, 100, "get dat B", ASC) < 4) return B.imode;
 
 		p = replystr.rfind("DA");
-		if (p == string::npos) return B.imode;
+		if (p == std::string::npos) return B.imode;
 		if (replystr[p + 2] == '1') {
 			data_mode = true;
 			if (md == LSB) md = LSBD;
@@ -758,7 +758,7 @@ int RIG_TS890S::get_bwA()
 		cmd = "FW;";
 		if (wait_char(';', 7, 100, "get CW width", ASC) == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 14; i++)
 					if (replystr.find(TS890S_CWbw[i]) == p)
 						break;
@@ -772,7 +772,7 @@ int RIG_TS890S::get_bwA()
 		cmd = "FW;";
 		if (wait_char(';', 7, 100, "get FSK width", ASC) == 7 ) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 4; i++)
 					if (replystr.find(TS890S_FSKbw[i]) == p)
 						break;
@@ -788,12 +788,12 @@ int RIG_TS890S::get_bwA()
 		cmd = "SL;";
 		if (wait_char(';', 5, 100, "get lower", ASC) == 5) {
 			p = replystr.rfind("SL");
-			if (p == string::npos) break;
+			if (p == std::string::npos) break;
 			lo = fm_decimal(replystr.substr(2), 2);
 			cmd = "SH;";
 			if (wait_char(';', 5, 100, "get upper", ASC) == 5) {
 				p = replystr.rfind("SH");
-				if (p == string::npos) break;
+				if (p == std::string::npos) break;
 				hi = fm_decimal(replystr.substr(2), 2);
 				A.iBW = ((hi << 8) | (lo & 0x7F)) | 0x8000;
 			}
@@ -806,12 +806,12 @@ int RIG_TS890S::get_bwA()
 		cmd = "SL;";
 		if (wait_char(';', 5, 100, "get width", ASC) == 5) {
 			p = replystr.rfind("SL");
-			if (p == string::npos) break;
+			if (p == std::string::npos) break;
 			hi = fm_decimal(replystr.substr(2), 2);
 			cmd = "SH;";
 			if (wait_char(';', 5, 100, "get shift", ASC) == 5) {
 				p = replystr.rfind("SH");
-				if (p == string::npos) break;
+				if (p == std::string::npos) break;
 				lo = fm_decimal(replystr.substr(2), 2);
 				A.iBW = ((hi << 8) | (lo & 0x7F)) | 0x8000;
 			}
@@ -831,7 +831,7 @@ int RIG_TS890S::get_bwB()
 		cmd = "FW;";
 		if (wait_char(';', 7, 100, "get CW width", ASC) == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 14; i++)
 					if (replystr.find(TS890S_CWbw[i]) == p)
 						break;
@@ -845,7 +845,7 @@ int RIG_TS890S::get_bwB()
 		cmd = "FW;";
 		if (wait_char(';', 7, 100, "get FSK width", ASC) == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < 4; i++)
 					if (replystr.find(TS890S_FSKbw[i]) == p)
 						break;
@@ -861,12 +861,12 @@ int RIG_TS890S::get_bwB()
 		cmd = "SL;";
 		if (wait_char(';', 5, 100, "get lower", ASC) == 5) {
 			p = replystr.rfind("SL");
-			if (p == string::npos) break;
+			if (p == std::string::npos) break;
 			lo = fm_decimal(replystr.substr(2), 2);
 			cmd = "SH;";
 			if (wait_char(';', 5, 100, "get upper", ASC) == 5) {
 				p = replystr.rfind("SH");
-				if (p == string::npos) break;
+				if (p == std::string::npos) break;
 				hi = fm_decimal(replystr.substr(2), 2);
 				B.iBW = ((hi << 8) | (lo & 0x7F)) | 0x8000;
 			}
@@ -879,12 +879,12 @@ int RIG_TS890S::get_bwB()
 		cmd = "SL;";
 		if (wait_char(';', 5, 100, "get width", ASC) == 5) {
 			p = replystr.rfind("SL");
-			if (p == string::npos) break;
+			if (p == std::string::npos) break;
 			hi = fm_decimal(replystr.substr(2), 2);
 			cmd = "SH;";
 			if (wait_char(';', 5, 100, "get shift", ASC) == 5 ) {
 				p = replystr.rfind("SH");
-				if (p == string::npos) break;
+				if (p == std::string::npos) break;
 				lo = fm_decimal(replystr.substr(2), 2);
 				B.iBW = ((hi << 8) | (lo & 0xFF)) | 0x8000;
 			}
@@ -920,7 +920,7 @@ bool RIG_TS890S::get_if_shift(int &val)
 		cmd = "IS;";
 		if (wait_char(';', 8, 100, "get IF shift", ASC) == 8) {
 			size_t p = replystr.rfind("IS");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				val = fm_decimal(replystr.substr(p+3), 4);
 			} else
 				val = progStatus.shift_val;
@@ -971,7 +971,7 @@ int  RIG_TS890S::get_noise_reduction()
 	cmd.append(";");
 	if (wait_char(';', 4, 100, "GET noise reduction", ASC) == 4 ) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) return noise_reduction_level;
+		if (p == std::string::npos) return noise_reduction_level;
 		noise_reduction_level = replystr[p+2] - '0';
 
 		if (noise_reduction_level == 1) {
@@ -1001,7 +1001,7 @@ int  RIG_TS890S::get_noise_reduction_val()
 	cmd.append(";");
 	if (wait_char(';', 5, 100, "GET noise reduction val", ASC) == 5) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) return progStatus.noise_reduction_val;
+		if (p == std::string::npos) return progStatus.noise_reduction_val;
 		val = atoi(&replystr[p+2]);
 	}
 	return val;
@@ -1019,7 +1019,7 @@ int  RIG_TS890S::get_auto_notch()
 	cmd = "NT;";
 	if (wait_char(';', 5, 100, "get auto notch", ASC) == 5) {
 		size_t p = replystr.rfind("NT");
-		if (p == string::npos) return 0;
+		if (p == std::string::npos) return 0;
 		if (replystr[p+2] == '1') return 1;
 	}
 	return 0;
@@ -1048,13 +1048,13 @@ bool  RIG_TS890S::get_notch(int &val)
 	cmd = "NT;";
 	if (wait_char(';', 5, 100, "get notch state", ASC) == 5) {
 		size_t p = replystr.rfind("NT");
-		if (p == string::npos)
+		if (p == std::string::npos)
 			return 0;
 		if (replystr[p+2] == '2') {
 			cmd.assign("BP;");
 			if (wait_char(';', 6, 100, "get notch freq", ASC) == 6) {
 				size_t p = replystr.rfind("BP");
-				if (p != string::npos)
+				if (p != std::string::npos)
 					val = (int)((atoi(&replystr[p+2]) * 2700.0 / 128.0) + 300.0);
 				return 1;
 			}
@@ -1096,7 +1096,7 @@ int RIG_TS890S::get_noise()
 	cmd = "NB;";
 	if (wait_char(';', 4, 100, "get Noise Blanker", ASC) == 4) {
 		size_t p = replystr.rfind("NB");
-		if (p == string::npos) return 0;
+		if (p == std::string::npos) return 0;
 		if (replystr[p+2] == '0') return 0;
 		nb_level = replystr[p+2] - '0';
 		if (nb_level == 0) {
@@ -1131,7 +1131,7 @@ int  RIG_TS890S::get_rf_gain()
 	cmd += ';';
 	if (wait_char(';', 6, 100, "get rfgain", ASC) == 6) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) return progStatus.rfgain;
+		if (p == std::string::npos) return progStatus.rfgain;
 		for (int i = 2; i < 5; i++) {
 			rfval *= 10;
 			rfval += replystr[p+i] - '0';
@@ -1183,7 +1183,7 @@ int RIG_TS890S::get_swr(void)
 	if (wait_char(';', 8, 100, "get swr/alc", ASC) < 8) return 0;
 
 	size_t p = replystr.find("RM2");
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		replystr[p + 7] = 0;
 		alc_val = atoi(&replystr[p + 3]);
 		alc_val *= 100;
@@ -1193,7 +1193,7 @@ int RIG_TS890S::get_swr(void)
 	}
 
 	p = replystr.find("RM1");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 
 	replystr[p + 7] = 0;
 	mtr = atoi(&replystr[p + 3]);
@@ -1214,7 +1214,7 @@ int RIG_TS890S::get_alc(void)
 	if (wait_char(';', 8, 100, "get alc", ASC) < 8) return 0;
 
 	size_t p = replystr.find("RM3");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 
 	replystr[p + 7] = 0;
 	alc_val = atoi(&replystr[p + 3]);
@@ -1234,6 +1234,7 @@ void RIG_TS890S::selectA()
 	sendCommand(cmd, 0);
 	showresp(WARN, ASC, "Tx A", cmd, "");
 	rxtxa = true;
+	inuse = onA;
 }
 
 void RIG_TS890S::selectB()
@@ -1245,12 +1246,13 @@ void RIG_TS890S::selectB()
 	sendCommand(cmd, 0);
 	showresp(WARN, ASC, "Tx B", cmd, "");
 	rxtxa = false;
+	inuse = onB;
 }
 
 void RIG_TS890S::set_split(bool val) 
 {
 	split = val;
-	if (useB) {
+	if (inuse == onB) {
 		if (val) {
 			cmd = "FR1;FT0;";
 			sendCommand(cmd);
@@ -1283,7 +1285,7 @@ int RIG_TS890S::get_split()
 	cmd.append(";");
 	if (wait_char(';', 4, 100, "get split tx vfo", ASC) == 4) {
 		p = replystr.rfind(rsp);
-		if (p == string::npos) return split;
+		if (p == std::string::npos) return split;
 		tx = replystr[p+2];
 	}
 // rx vfo
@@ -1291,7 +1293,7 @@ int RIG_TS890S::get_split()
 	cmd.append(";");
 	if (wait_char(';', 4, 100, "get split rx vfo", ASC) == 4) {
 		p = replystr.rfind(rsp);
-		if (p == string::npos) return split;
+		if (p == std::string::npos) return split;
 		rx = replystr[p+2];
 // split test
 		split = (tx == '1' ? 2 : 0) + (rx == '1' ? 1 : 0);
@@ -1306,7 +1308,7 @@ unsigned long int RIG_TS890S::get_vfoA ()
 	if (wait_char(';', 14, 100, "get vfoA", ASC) < 14) return A.freq;
 
 	size_t p = replystr.rfind("FA");
-	if (p == string::npos) return A.freq;
+	if (p == std::string::npos) return A.freq;
 
 	unsigned long int f = 0L;
 	unsigned long int mul = 1L;
@@ -1336,7 +1338,7 @@ unsigned long int RIG_TS890S::get_vfoB ()
 	if (wait_char(';', 14, 100, "get vfoB", ASC) < 14) return B.freq;
 
 	size_t p = replystr.rfind("FB");
-	if (p == string::npos) return B.freq;
+	if (p == std::string::npos) return B.freq;
 
 	unsigned long int f = 0L;
 	unsigned long int mul = 1L;
@@ -1368,7 +1370,7 @@ int RIG_TS890S::get_volume_control()
 	if (wait_char(';', 7, 100, "get vol ctrl", ASC) < 7) return 0;
 
 	size_t p = replystr.rfind("AG");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 
 	replystr[p + 6] = 0;
 	int val = atoi(&replystr[p + 3]);
@@ -1409,7 +1411,7 @@ int RIG_TS890S::get_mic_gain()
 	cmd = "MG;";
 	if (wait_char(';', 6, 100, "get mic ctrl", ASC) >= 6) {
 		size_t p = replystr.rfind("MG");
-		if (p == string::npos) return val;
+		if (p == std::string::npos) return val;
 		replystr[p + 5] = 0;
 		val = atoi(&replystr[p + 2]);
 	}
@@ -1437,7 +1439,7 @@ int  RIG_TS890S::get_squelch()
 	cmd = "SQ0;";
 	if (wait_char(';', 7, 100, "get squelch", ASC) >= 7) {
 		size_t p = replystr.rfind("SQ0");
-		if (p == string::npos) return val;
+		if (p == std::string::npos) return val;
 		replystr[p + 6] = 0;
 		val = atoi(&replystr[p + 3]);
 	}
