@@ -35,7 +35,7 @@ Factory response to request for list of supported CAT commands:
 ID;		identifier, response 019;
 AI;		auto information; default OFF
 RX;		receiver function status; NO RESPONSE
-IF;		information string; type response:
+IF;		information std::string; type response:
 		IF0000703437000000+000000000020000000;
 FA;		get/set frequency vfo A; FA00007034370;
 FB;		get/set frequency vfo B; FB00014070000;
@@ -182,12 +182,11 @@ void RIG_TX500::set_attenuator(int val)
 int RIG_TX500::get_attenuator()
 {
 	cmd = "RA;";
-	get_trace(1, "get_attenuator");
 	ret = wait_char(';', 7, 100, "get ATT", ASC);
-	gett("");
+	gett("get_attenuator");
 	if (ret >= 7) {
 		size_t p = replystr.rfind("RA");
-		if (p != string::npos && (p+3 < replystr.length())) {
+		if (p != std::string::npos && (p+3 < replystr.length())) {
 			if (replystr[p+2] == '0' && replystr[p+3] == '0')
 				atten_level = 0;
 			else
@@ -210,12 +209,11 @@ void RIG_TX500::set_preamp(int val)
 int RIG_TX500::get_preamp()
 {
 	cmd = "PA;";
-	get_trace(1, "get_preamp");
 	ret = wait_char(';', 5, 100, "get PRE", ASC);
-	gett("");
+	gett("get_preamp");
 	if (ret >= 5) {
 		size_t p = replystr.rfind("PA");
-		if (p != string::npos && (p+2 < replystr.length())) {
+		if (p != std::string::npos && (p+2 < replystr.length())) {
 			if (replystr[p+2] == '1')
 				preamp_level = 1;
 			else
@@ -240,12 +238,11 @@ void RIG_TX500::set_modeA(int val)
 int RIG_TX500::get_modeA()
 {
 	cmd = "MD;";
-	get_trace(1, "get_modeA");
 	ret = wait_char(';', 4, 100, "get mode A", ASC);
-	gett("");
+	gett("get_modeA");
 	if (ret == 4) {
 		size_t p = replystr.rfind("MD");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			int md = replystr[p+2];
 			md = md - '1';
 			if (md == 8) md = 7;
@@ -271,12 +268,11 @@ void RIG_TX500::set_modeB(int val)
 int RIG_TX500::get_modeB()
 {
 	cmd = "MD;";
-	get_trace(1, "get_modeB");
 	ret = wait_char(';', 4, 100, "get mode B", ASC);
-	gett("");
+	gett("get_modeB");
 	if (ret == 4) {
 		size_t p = replystr.rfind("MD");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			int md = replystr[p+2];
 			md = md - '1';
 			if (md == 8) md = 7;
@@ -293,19 +289,17 @@ bool RIG_TX500::check()
 {
 	MilliSleep(200);  // needed for restart.  TX500  has mechanical relays
 	cmd = "ID;";
-	gett("check ID");
 	if (wait_char(';', 6, 500, "get ID", ASC) < 6) {
 trace(1, "check ID FAILED");
 		return false;
 	}
-	gett("");
+	gett("check ID");
 	cmd = "FA;";
-	gett("check vfoA");
 	if (wait_char(';', 14, 500, "get vfo A", ASC) < 14) {
 trace(1, "check FA FAILED");
 		return false;
 	}
-	gett(""); 
+	gett("check vfoA");
 	return true;
 }
 
@@ -314,6 +308,7 @@ void RIG_TX500::selectA()
 	cmd = "FR0;FT0;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "Rx on A, Tx on A", cmd, "");
+	inuse = onA;
 }
 
 void RIG_TX500::selectB()
@@ -321,21 +316,18 @@ void RIG_TX500::selectB()
 	cmd = "FR1;FT1;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "Rx on B, Tx on B", cmd, "");
+	inuse = onB;
 }
 
 unsigned long int RIG_TX500::get_vfoA ()
 {
 	cmd = "FA;";
-	gett("get_vfoA");
 	if (wait_char(';', 14, 100, "get vfo A", ASC) < 14) return A.freq;
-	gett("");
+	gett("get_vfoA");
 
 	size_t p = replystr.rfind("FA");
-	if (p != string::npos && (p + 12 < replystr.length())) {
-		int f = 0;
-		for (size_t n = 2; n < 13; n++)
-			f = f*10 + replystr[p+n] - '0';
-		A.freq = f;
+	if (p != std::string::npos && (p + 12 < replystr.length())) {
+		A.freq = atol(&replystr[ p + 2]);
 	}
 	return A.freq;
 }
@@ -357,16 +349,12 @@ void RIG_TX500::set_vfoA (unsigned long int freq)
 unsigned long int RIG_TX500::get_vfoB ()
 {
 	cmd = "FB;";
-	gett("get_vfoB");
 	if (wait_char(';', 14, 100, "get vfo B", ASC) < 14) return B.freq;
-	gett("");
+	gett("get_vfoB");
 
 	size_t p = replystr.rfind("FB");
-	if (p != string::npos && (p + 12 < replystr.length())) {
-		int f = 0;
-		for (size_t n = 2; n < 13; n++)
-			f = f*10 + replystr[p+n] - '0';
-		B.freq = f;
+	if (p != std::string::npos && (p + 12 < replystr.length())) {
+		B.freq = atol(&replystr[ p + 2 ]);
 	}
 	return B.freq;
 }
@@ -388,7 +376,7 @@ void RIG_TX500::set_vfoB (unsigned long int freq)
 void RIG_TX500::set_split(bool val) 
 {
 	split = val;
-	if (useB) {
+	if (inuse == onB) {
 		if (val) {
 			cmd = "FR1;FT0;";
 			sendCommand(cmd);
@@ -434,20 +422,42 @@ int RIG_TX500::get_smeter()
 	int smtr = 0;
 	cmd = "SM0;";
 
-	get_trace(1, "get_smeter");
 	ret = wait_char(';', 8, 100, "get smeter", ASC);
-	gett("");
-
+	gett("get_smeter");
 	if (ret == 8) {
 		size_t p = replystr.rfind("SM");
-		if (p != string::npos) {
-			smtr = fm_decimal(replystr.substr(p+3),4);
+		if (p != std::string::npos) {
+			smtr = atol(&replystr[p + 4]);
 			smtr = (smtr * 100) / 30;
 		}
 	}
 	return smtr;
 }
 
+void RIG_TX500::set_PTT_control(int val)
+{
+	ptt_ = val;
+	if (val) cmd = "TX;";
+	else     cmd = "RX;";
+	sendCommand(cmd);
+	showresp(WARN, ASC, "PTT", cmd, "");
+}
+
+//IF0000702800000000+000000000130000000;
+//IF0000702800000000+000000000030000000;
+//01234567890123456789012345678
+int  RIG_TX500::get_PTT()
+{
+	cmd = "IF;";
+	ret = wait_char(';', 38, 100, "get PTT", ASC);
+	gett("get PTT");
+	if (ret >= 38) {
+		ptt_ = replystr[28] == '1';
+	}
+	return ptt_;
+}
+
+
 /*
 
 Kenwood CAT commands NOT IMPLEMENTED IN TX500
@@ -673,7 +683,7 @@ int RIG_TX500::get_bwA()
 		gett("");
 		if (ret == 5) {
 			p = replystr.rfind("SL");
-			if (p != string::npos)
+			if (p != std::string::npos)
 				lo = fm_decimal(replystr.substr(2), 2);
 		}
 		cmd = "SH;";
@@ -682,7 +692,7 @@ int RIG_TX500::get_bwA()
 		gett("");
 		if (ret == 5) {
 			p = replystr.rfind("SH");
-			if (p != string::npos)
+			if (p != std::string::npos)
 				hi = fm_decimal(replystr.substr(2), 2);
 			A.iBW = ((hi << 8) | (lo & 0xFF)) | 0x8000;
 		}
@@ -693,7 +703,7 @@ int RIG_TX500::get_bwA()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < sizeof(TX500_CWbw)/sizeof(*TX500_CWbw); i++)
 					if (replystr.find(TX500_CWbw[i]) == p)
 						break;
@@ -707,7 +717,7 @@ int RIG_TX500::get_bwA()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < sizeof(TX500_FSKbw)/sizeof(*TX500_FSKbw); i++)
 					if (replystr.find(TX500_FSKbw[i]) == p)
 						break;
@@ -772,7 +782,7 @@ int RIG_TX500::get_bwB()
 		gett("");
 		if (ret == 5) {
 			p = replystr.rfind("SL");
-			if (p != string::npos)
+			if (p != std::string::npos)
 				lo = fm_decimal(replystr.substr(2), 2);
 		}
 		cmd = "SH;";
@@ -781,7 +791,7 @@ int RIG_TX500::get_bwB()
 		gett("");
 		if (ret == 5) {
 			p = replystr.rfind("SH");
-			if (p != string::npos)
+			if (p != std::string::npos)
 				hi = fm_decimal(replystr.substr(2), 2);
 			B.iBW = ((hi << 8) | (lo & 0xFF)) | 0x8000;
 		}
@@ -792,7 +802,7 @@ int RIG_TX500::get_bwB()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < sizeof(TX500_CWbw)/sizeof(*TX500_CWbw); i++)
 					if (replystr.find(TX500_CWbw[i]) == p)
 						break;
@@ -806,7 +816,7 @@ int RIG_TX500::get_bwB()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("FW");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; i < sizeof(TX500_FSKbw)/sizeof(*TX500_FSKbw); i++)
 					if (replystr.find(TX500_FSKbw[i]) == p)
 						break;
@@ -858,7 +868,7 @@ bool  RIG_TX500::get_notch(int &val)
 
 	if (ret == 4) {
 		size_t p = replystr.rfind("BC");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+2] == '2') {
 				ison = true;
 				cmd = "BP;";
@@ -870,7 +880,7 @@ bool  RIG_TX500::get_notch(int &val)
 				if (ret == 6) {
 					gett("notch val");
 					p = replystr.rfind("BP");
-					if (p != string::npos)
+					if (p != std::string::npos)
 						val = 200 + 50 * fm_decimal(replystr.substr(p+2),3);
 				}
 			}
@@ -905,7 +915,7 @@ int  RIG_TX500::get_auto_notch()
 
 	if (ret == 4) {
 		size_t p = replystr.rfind("NT");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			anotch = (replystr[p+2] == '1');
 		}
 	}
@@ -944,7 +954,7 @@ int  RIG_TX500::get_noise_reduction()
 
 	if (ret == 4) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) return _noise_reduction_level;
+		if (p == std::string::npos) return _noise_reduction_level;
 		_noise_reduction_level = replystr[p+2] - '0';
 	}
 	if (replystr == "?;") {
@@ -988,7 +998,7 @@ int  RIG_TX500::get_noise_reduction_val()
 
 	if (ret == 5) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) {
+		if (p == std::string::npos) {
 			nrval = (_noise_reduction_level == 1 ? _nrval1 : _nrval2);
 			return nrval;
 		}
@@ -1010,7 +1020,7 @@ int RIG_TX500::get_power_out()
 	gett("");
 	if (ret == 8) {
 		size_t p = replystr.rfind("SM0");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			poutmtr = fm_decimal(replystr.substr(p+3),4);
 			if (poutmtr <= 6) poutmtr = poutmtr * 2;
 			else if (poutmtr <= 11) poutmtr = 11 + (poutmtr - 6)*(26 - 11)/(11 - 6);
@@ -1042,7 +1052,7 @@ double RIG_TX500::get_power_control()
 	gett("");
 	if (ret >= 6) {
 		size_t p = replystr.rfind("PC");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			pctrl = fm_decimal(replystr.substr(p+2), 3);
 		}
 	}
