@@ -108,7 +108,7 @@ static GUI rig_widgets[]= {
 };
 
 // mid range on loudness
-static string menu012 = "EX01200004";
+static std::string menu012 = "EX01200004";
 
 void RIG_PowerSDR::initialize()
 {
@@ -127,17 +127,17 @@ void RIG_PowerSDR::initialize()
 		strcpy(varwidths[i], PowerSDR_USBwidths[i]);
 
 // get current noise reduction values for NR1 and NR2
-	string current_nr;
+	std::string current_nr;
 	cmd = "ZZNR;";
 	wait_char(';', 6, 100, "read current NR", ASC);
 	gett("get ZZNR");
 	size_t p = replystr.rfind("RL");
-	if (p != string::npos)
+	if (p != std::string::npos)
 		_nrval1 = atoi(&replystr[p+2]);
 	cmd = "ZZNS;";
 	wait_char(';', 6, 100, "read current NR", ASC);
 	int nrval2=0;
-	if (p != string::npos)
+	if (p != std::string::npos)
 		nrval2 = atoi(&replystr[p+2]);
 	if (nrval2 == 1) _nrval1 = 2;
 }
@@ -201,7 +201,7 @@ RIG_PowerSDR::RIG_PowerSDR() {
 	has_mode_control =
 	has_bandwidth_control =
 	has_sql_control =
-	has_ptt_control = 
+	has_ptt_control =
 	has_extras = true;
 
 	rxona = true;
@@ -223,7 +223,7 @@ static int ret = 0;
 const char * RIG_PowerSDR::get_bwname_(int n, int md)
 {
 	static char bwname[20] = "unknown";
-	stringstream str;
+	std::stringstream str;
 	str << "n=" << n << ", md=" << md;
 	trace(2, __func__, str.str().c_str());
 	if (md == USB || md == LSB) {
@@ -260,7 +260,7 @@ int RIG_PowerSDR::get_smeter()
 	gett("");
 	if (ret == 9) {
 		size_t p = replystr.rfind("SM");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			smtr = fm_decimal(replystr.substr(p+3),3);
 			smtr = -54 + smtr/(256.0/100.0); // in S-Units
 			smtr = (smtr + 54);
@@ -282,17 +282,17 @@ void RIG_PowerSDR::set_power_control(double val)
 
 int RIG_PowerSDR::get_power_out()
 {
-	float mtr = 0.0;
+	int mtr = 0;
 
 	cmd = "ZZRM5;";
 	get_trace(1, "get_power_out");
 	ret = wait_char(';', 11, 100, "get power", ASC);
 	gett("");
-	if (ret < 11) return 0;
+	if (ret < 9) return 0;
 
-	sscanf(&replystr[0],"ZZRM5%f", &mtr);
+	sscanf(&replystr[0],"ZZRM5%d", &mtr);
 
-	return (int)(10 * mtr);
+	return mtr;
 }
 
 
@@ -305,7 +305,7 @@ double RIG_PowerSDR::get_power_control()
 	gett("");
 	if (ret == 6) {
 		size_t p = replystr.rfind("PC");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			pctrl = fm_decimal(replystr.substr(p+2), 3);
 		}
 	}
@@ -380,7 +380,7 @@ ZZPA7 does nothing
 */
 
 int  RIG_PowerSDR::next_preamp()
-{   
+{
 	// strange sequence for ANAN 7000DLE MKII
 	switch(preamp_level)
 	{
@@ -422,7 +422,7 @@ int RIG_PowerSDR::get_preamp()
 {
 	int preamp_level;
 	cmd = "ZZPA;";
-	stringstream str;
+	std::stringstream str;
 	sendCommand(cmd);
 	get_trace(1, "get_preamp");
 	ret = wait_char(';', 6, 100, "get PRE", ASC);
@@ -431,11 +431,11 @@ int RIG_PowerSDR::get_preamp()
 		size_t p = replystr.rfind("PA");
 		str << "ZZPA #2 replystr=" << replystr << ", p=" << p;
 		trace(2, "get_preamp", replystr.c_str());
-		if (p != string::npos && (p+2 < replystr.length())) {
+		if (p != std::string::npos && (p+2 < replystr.length())) {
 			preamp_level = fm_decimal(replystr.substr(p+2),1);
 			// need to map 7 to 2 to keep FLRig cbPreamp happy
 			// when ZZPA2; is sent ZZPA7; comes back
-			if (preamp_level == 7) preamp_level = 2; 
+			if (preamp_level == 7) preamp_level = 2;
 		}
 	}
 	else preamp_level = 0;
@@ -558,7 +558,7 @@ int RIG_PowerSDR::get_modeA()
 	gett("");
 	if (ret == 7) {
 		size_t p = replystr.rfind("MD");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			int md;
 			sscanf(&replystr[p+2],"%d",&md);
 			if (A.imode != md) {
@@ -596,7 +596,7 @@ int RIG_PowerSDR::get_modeB()
 	gett("");
 	if (ret == 7) {
 		size_t p = replystr.rfind("MD");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			int md=0;
 			sscanf(&replystr[p+2],"%d",&md);
 			if (B.imode != md) {
@@ -625,7 +625,7 @@ int RIG_PowerSDR::def_bandwidth(int val)
 
 void RIG_PowerSDR::set_bwA(int val)
 {
-	stringstream str;
+	std::stringstream str;
 	if (A.imode == FM || A.imode == DRM || A.imode == SPEC) return; // mode is fixed
 	else if (A.imode == LSB || A.imode == USB) {
 		A.iBW = val;
@@ -637,7 +637,7 @@ void RIG_PowerSDR::set_bwA(int val)
 	}
 	else if (A.imode == DIGU || A.imode == DIGL) {
 		A.iBW = val;
-	stringstream str;
+	std::stringstream str;
 	str << "val =" << val ;
 	trace(2, __func__, str.str().c_str());
 		if (val >= (int)(sizeof(PowerSDR_CAT_DIG)/sizeof(*PowerSDR_CAT_DIG))) return;
@@ -668,7 +668,7 @@ int RIG_PowerSDR::get_bwA()
 {
 	size_t i = 0;
 	size_t p;
-	stringstream str;
+	std::stringstream str;
 	str << "get_bwA" ;
 	A.iBW = 0;
 	trace(2, __func__, str.str().c_str());
@@ -676,14 +676,14 @@ int RIG_PowerSDR::get_bwA()
 		A.iBW = 0;
 		gett("get_bwA Wideband");
 	}
-	else if (A.imode == LSB || A.imode == USB) {  
+	else if (A.imode == LSB || A.imode == USB) {
 		cmd = "ZZFI;";
 		get_trace(1, "get_bw SSB");
 		ret = wait_char(';', 7, 100, "get ZZFI", ASC);
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("ZZFI");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; PowerSDR_CAT_USB[i] != NULL; i++)
 				{
 					if (replystr.find(PowerSDR_CAT_USB[i]) == p)
@@ -692,7 +692,7 @@ int RIG_PowerSDR::get_bwA()
 				A.iBW = i;
 			}
 		}
-	} 
+	}
 	else if (A.imode == CWL || A.imode == CWU) {
 		cmd = "ZZFI;";
 		get_trace(1, "get_bw CW");
@@ -700,14 +700,14 @@ int RIG_PowerSDR::get_bwA()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("ZZFI");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; PowerSDR_CAT_CW[i] != NULL; i++)
 					if (replystr.find(PowerSDR_CAT_CW[i]) == p)
 						break;
 				A.iBW = i;
 			}
 		}
-	} 
+	}
 	else if (A.imode == DIGU || A.imode == DIGL) {
 		cmd = "ZZFI;";
 		get_trace(1, "get_bw DIGI");
@@ -729,7 +729,7 @@ int RIG_PowerSDR::get_bwA()
 		gett("");
 		if (ret == 7) {
 			p = replystr.rfind("ZZFI");
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				for (i = 0; PowerSDR_CAT_AM[i] != NULL; i++)
 					if (replystr.find(PowerSDR_CAT_AM[i]) == p)
 						break;
@@ -746,7 +746,7 @@ void RIG_PowerSDR::set_bwB(int val)
 {
 	set_bwA(val);
 	B.iBW = val;
-	stringstream str;
+	std::stringstream str;
 	str << "B.iBW = " << B.iBW;
 	trace(2, __func__, str.str().c_str());
 	return;
@@ -755,7 +755,7 @@ void RIG_PowerSDR::set_bwB(int val)
 int RIG_PowerSDR::get_bwB() // same as A
 {
 	B.iBW =  get_bwA();
-	stringstream str;
+	std::stringstream str;
 	str << "B.iBW = " << B.iBW;
 	trace(2, __func__, str.str().c_str());
 	vfoB.iBW = B.iBW;
@@ -801,7 +801,7 @@ bool  RIG_PowerSDR::get_notch(int &val)
 	gett("");
 	if (ret == 4) {
 		size_t p = replystr.rfind("BC");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+2] == '2') {
 				ison = true;
 				cmd = "BP;";
@@ -810,7 +810,7 @@ bool  RIG_PowerSDR::get_notch(int &val)
 				gett("");
 				if (ret == 6) {
 					p = replystr.rfind("BP");
-					if (p != string::npos)
+					if (p != std::string::npos)
 						val = 200 + 50 * fm_decimal(replystr.substr(p+2),3);
 				}
 			}
@@ -843,13 +843,32 @@ int  RIG_PowerSDR::get_auto_notch()
 	gett("");
 	if (ret == 4) {
 		size_t p = replystr.rfind("NT");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			anotch = (replystr[p+2] == '1');
 		}
 	}
 	return anotch;
 }
 
+void RIG_PowerSDR::set_noise(bool on)
+{
+    if (on)
+       cmd = "ZZNA1;";
+    else
+       cmd = "ZZNA0;";
+    wait_char('\r', 1, 100, "set Noise Blanker", ASC);
+}
+
+int RIG_PowerSDR::get_noise()
+{
+    cmd = "ZZNA;";
+    int ret = wait_char(';', 6, 100, "get Noise Blanker", ASC);
+    if (ret < 6) return progStatus.noise;
+    size_t p = replystr.rfind("NA");
+    if (p == std::string::npos) return progStatus.noise;
+    return (replystr[p+2] == '1' ? 1 : 0);
+}
+
 void RIG_PowerSDR::set_noise_reduction(int val)
 {
 	if (val == -1) {
@@ -881,7 +900,7 @@ int  RIG_PowerSDR::get_noise_reduction()
 	gett("");
 	if (ret == 6) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) return _noise_reduction_level;
+		if (p == std::string::npos) return _noise_reduction_level;
 		_noise_reduction_level = replystr[p+4] - '0';
 	}
 
@@ -919,7 +938,7 @@ int  RIG_PowerSDR::get_noise_reduction_val()
 	gett("");
 	if (ret == 5) {
 		size_t p = replystr.rfind(rsp);
-		if (p == string::npos) {
+		if (p == std::string::npos) {
 			nrval = (_noise_reduction_level == 1 ? _nrval1 : _nrval2);
 			return nrval;
 		}
@@ -934,7 +953,7 @@ int  RIG_PowerSDR::get_noise_reduction_val()
 void RIG_PowerSDR::tune_rig(int val)
 {
 
-	stringstream str;
+	std::stringstream str;
 	str << "val=" << val;
 	trace(2, __func__, str.str().c_str());
 	switch (val) {
@@ -960,7 +979,7 @@ int RIG_PowerSDR::get_tune()
 	gett("");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	int val = replystr[p+4] - '0';
 	return val;
 }
@@ -986,7 +1005,7 @@ int  RIG_PowerSDR::get_rf_gain()
 	gett("");
 	if (ret == 9) {
 		size_t p = replystr.rfind("ZZAR");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			sscanf(replystr.c_str(),"ZZAR%c%d", &sign, &rfg);
 			if (sign == '-') rfg *= -1;
 		}
@@ -1021,7 +1040,7 @@ int RIG_PowerSDR::get_mic_gain()
 	gett("");
 	if (ret == 8) {
 		size_t p = replystr.rfind("MG");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			sscanf(replystr.c_str(),"ZZMG%d",&mgain);
 		}
 	}
@@ -1103,7 +1122,7 @@ int  RIG_PowerSDR::get_squelch()
 	gett("");
 	if (ret == 8) {
 		size_t p = replystr.rfind("ZZSQ");
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			sscanf(replystr.c_str(),"ZZSQ%d",&sq);
 		}
 	}
