@@ -55,6 +55,8 @@ rigbase::rigbase()
 	SH_label = szbtnlabel;
 	bw_vals_ = &ibw_val;
 
+	io_class = SERIAL;
+
 	widgets = basewidgets;
 
 	serloop_timing = 200; // msec, 5x / second
@@ -92,6 +94,7 @@ rigbase::rigbase()
 	has_tune_control =
 	has_swr_control =
 	has_alc_control =
+	has_idd_control =
 	has_agc_control =
 	has_rf_control =
 	has_sql_control =
@@ -526,6 +529,8 @@ int  rigbase::get_split()
 	return split;
 }
 
+std::string rigbase::read_menu(int m1, int m2) { return ""; }
+
 char bcdval[100] = {
 '\x00', '\x01', '\x02', '\x03', '\x04', '\x05', '\x06', '\x07', '\x08', '\x09',
 '\x10', '\x11', '\x12', '\x13', '\x14', '\x15', '\x16', '\x17', '\x18', '\x19',
