@@ -126,6 +126,9 @@ RIG_X6100		rig_X6100;
 RIG_PowerSDR	rig_PowerSDR;
 RIG_FLEX1500	rig_FLEX1500;
 RIG_TX500		rig_TX500;
+RIG_QCXP		rig_QCXP;
+RIG_SDR2_PRO	rig_sdr2;
+RIG_TCI_SDR		rig_tcisdr;
 
 rigbase *rigs[] = {
 	&rig_null,		// 0
@@ -226,6 +229,9 @@ rigbase *rigs[] = {
 	&rig_PowerSDR,	// 95
 	&rig_FLEX1500,	// 96
 	&rig_TX500,		// 97
+	&rig_QCXP,		// 98
+	&rig_sdr2,		// 99
+	&rig_tcisdr,	// 100
 
 	NULL
 };
