@@ -329,18 +329,22 @@ const std::string amsync[] = {
 
 3.500.00
 08 00 55 73 0E 00 00 01 00 00 11 B3 33
+
 7.000.00
 0B 00 AA E6 0C 00 00 02 B3 00 11 B3 33
+
 14.000.00
 11 01 55 CC 06 00 00 02 B3 00 11 B3 33
 
 const unsigned int testints[] = {\
 0x08,0x00,0x55,0x73,0x0E,0x00,0x00,0x01,0x00,0x00,0x11,0xB3,0x33,0x91,0x11,0x08,\
 0x08,0x01,0x55,0xCC,0x06,0x00,0x00,0x01,0x11,0x00,0x11,0x91,0x11,0x11,0x11,0x00 };
+
+11 01 5B E8 10 00 00 02 B3 00 11 B3 11 11 11 00 0B 00 AB 4E B0 00 00 02 B3 00 11 B3 11 91 11 00
+   -- -- -- -- frequency A = 
+
 */
 
-char testret[32];
- 
 bool RIG_FT1000MP::check()
 {
 	init_cmd();
@@ -355,8 +359,6 @@ bool RIG_FT1000MP::check()
 	return false;
 }
 
-int tmd = 0;
-
 inline int hex2freq(std::string hex)
 {
 	int freq = 0;
@@ -386,7 +388,7 @@ bool RIG_FT1000MP::get_info(void)
 	if (ret >= 32) {
 		size_t p = replystr.length() - 32;
 
-		// vfo A data string
+		// vfo A data std::string
 		A.freq = hex2freq(replystr.substr(p + 1, 4));
 
 		for (md = 0; md < 14; md++) {
