@@ -149,6 +149,7 @@ RIG_FT991::RIG_FT991() {
 	has_vox_on_dataport =
 
 	has_vfo_adj =
+	has_idd_control =
 	has_voltmeter =
 
 	has_cw_wpm =
@@ -466,18 +467,33 @@ double RIG_FT991::get_voltmeter()
 
 	get_trace(1, "get_voltmeter()");
 	wait_char(';',7, FL991_WAIT_TIME, "get vdd", ASC);
-	gett("get vdd");
+	gett("get_voltmeter");
 
 	size_t p = replystr.rfind(resp);
 	if (p != std::string::npos) {
 		mtr = atoi(&replystr[p+3]);
-		val = (7.0 * mtr / 98.0) + 0.14;
+		val = 13.8 * mtr / 190;
 		return val;
 	}
 
 	return -1;
 }
 
+double RIG_FT991::get_idd()
+{
+	cmd = rsp = "RM7";
+	cmd += ';';
+	wait_char(';',10, FL991_WAIT_TIME, "get alc", ASC);
+	gett("get_idd");
+
+	size_t p = replystr.rfind(rsp);
+	if (p == std::string::npos) return 0;
+	if (p + 9 >= replystr.length()) return 0;
+	replystr[6] = '\x00';
+	double mtr = atoi(&replystr[p+3]);
+	return mtr / 10.0;
+}
+
 int RIG_FT991::get_power_out()
 {
 	cmd = rsp = "RM5";
