@@ -166,6 +166,7 @@ RIG_FT991A::RIG_FT991A() {
 	has_alc_control =
 	has_swr_control =
 	has_agc_control =
+	has_idd_control =
 	has_voltmeter =
 	has_power_out =
 	has_power_control =
@@ -485,19 +486,34 @@ double RIG_FT991A::get_voltmeter()
 	double val = 0;
 
 	get_trace(1, "get_voltmeter()");
-	wait_char(';',7, FL991A_WAIT_TIME, "get vdd", ASC);
-	gett("get vdd");
+	wait_char(';',7, 100, "get vdd", ASC);
+	gett("get_voltmeter");
 
 	size_t p = replystr.rfind(resp);
 	if (p != std::string::npos) {
 		mtr = atoi(&replystr[p+3]);
-		val = (7.0 * mtr / 98.0) + 0.14;
+		val = 13.8 * mtr / 190;
 		return val;
 	}
 
 	return -1;
 }
 
+double RIG_FT991A::get_idd()
+{
+	cmd = rsp = "RM7";
+	cmd += ';';
+	wait_char(';',10, 100, "get alc", ASC);
+	gett("get_idd");
+
+	size_t p = replystr.rfind(rsp);
+	if (p == std::string::npos) return 0;
+	if (p + 9 >= replystr.length()) return 0;
+	replystr[6] = '\x00';
+	double mtr = atoi(&replystr[p+3]);
+	return mtr / 10.0;
+}
+
 int RIG_FT991A::get_power_out()
 {
 	cmd = rsp = "RM5";
@@ -823,12 +839,12 @@ int RIG_FT991A::get_modeA()
 void RIG_FT991A::set_modeB(int val)
 {
 	modeB = val;
-	cmd = "MD0";
+	// Need to swap the vfos for the MD command to work on VFO B
+	cmd = "SV;MD0";
 	cmd += FT991A_mode_chr[val];
-	cmd += ';';
+	cmd += ";SV;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET mode B", cmd, replystr);
-	adjust_bandwidth(modeB);
 	if (val == mCW || val == mCW_R) return;
 	if (progStatus.spot_onoff) {
 		progStatus.spot_onoff = false;
@@ -843,21 +859,23 @@ void RIG_FT991A::set_modeB(int val)
 
 int RIG_FT991A::get_modeB()
 {
-	cmd = rsp = "MD0";
+	// Use Opposite Information command to read VFO B mode
+	int n = 21;
+	cmd = rsp = "OI";
 	cmd += ';';
-	wait_char(';',5, FL991A_WAIT_TIME, "get mode B", ASC);
+	wait_char(';',28, FL991A_WAIT_TIME, "get mode B", ASC);
 	gett("get_modeB");
 
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos) {
-		if (p + 3 < replystr.length()) {
-			int md = replystr[p+3];
+		// JBA - n tells us where to start in the response
+		if (p + n < replystr.length()) {
+			int md = replystr[p+n];
 			if (md <= '9') md = md - '1';
 			else md = 9 + md - 'A';
 			modeB = md;
 		}
 	}
-	adjust_bandwidth(modeB);
 	return modeB;
 }
 
