@@ -523,12 +523,12 @@ int RIG_FTdx10::get_power_out()
 			break;
 	if (mtr < 0) mtr = 0;
 	if (mtr > 205) mtr = 205;
-	int pwr = (int)ceil(pwrtbl[i].pwr + 
+	double pwr = (int)ceil(pwrtbl[i].pwr + 
 			  (pwrtbl[i+1].pwr - pwrtbl[i].pwr)*(mtr - pwrtbl[i].mtr) / (pwrtbl[i+1].mtr - pwrtbl[i].mtr));
 
 	if (pwr > 100) pwr = 100;
 
-	return (int)pwr;
+	return pwr;
 }
 
 int RIG_FTdx10::get_alc()
@@ -1229,7 +1229,6 @@ int RIG_FTdx10::get_noise()
 void RIG_FTdx10::set_mic_gain(int val)
 {
 	cmd = "MG000;";
-	val = (int)(val * 255 / 100); // convert to 0 .. 255
 	for (int i = 3; i > 0; i--) {
 		cmd[1+i] += val % 10;
 		val /= 10;
@@ -1249,7 +1248,7 @@ int RIG_FTdx10::get_mic_gain()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
-	return val * 100 / 255;
+	return val;
 }
 
 void RIG_FTdx10::get_mic_min_max_step(int &min, int &max, int &step)
