@@ -200,7 +200,10 @@ RIG_FTdx101D::RIG_FTdx101D() {
 	has_smeter =
 	has_swr_control =
 	has_alc_control =
+
+	has_idd_control =
 	has_voltmeter =
+
 	has_power_out =
 	has_power_control =
 	has_volume_control =
@@ -1237,7 +1240,6 @@ int RIG_FTdx101D::get_noise()
 void RIG_FTdx101D::set_mic_gain(int val)
 {
 	cmd = "MG000;";
-	val = (int)(val * 255 / 100); // convert to 0 .. 255
 	for (int i = 3; i > 0; i--) {
 		cmd[1+i] += val % 10;
 		val /= 10;
@@ -1257,7 +1259,7 @@ int RIG_FTdx101D::get_mic_gain()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
-	return val * 100 / 255;
+	return val;
 }
 
 void RIG_FTdx101D::get_mic_min_max_step(int &min, int &max, int &step)
@@ -1447,6 +1449,45 @@ void RIG_FTdx101D::sync_clock(char *tm)
 	showresp(WARN, ASC, "sync_time", cmd, replystr);
 	sett("sync_time");
 }
+  
+double RIG_FTdx101D::get_voltmeter()
+{
+// RM8155000;
+	cmd = "RM8;";
+	std::string resp = "RM";
+
+	int mtr = 0;
+	double val = 0;
+
+	get_trace(1, "get_voltmeter()");
+	wait_char(';',10, 100, "get vdd", ASC);
+	gett("get_voltmeter");
+
+	size_t p = replystr.rfind(resp);
+	if (p != std::string::npos) {
+		replystr[6] = 0;
+		mtr = atoi(&replystr[p+3]);
+		val = 0.066 * mtr + 0.78;
+		return val;
+	}
+
+	return -1;
+}
+
+double RIG_FTdx101D::get_idd()
+{
+	cmd = rsp = "RM7";
+	cmd += ';';
+	wait_char(';',10, 100, "get alc", ASC);
+	gett("get_idd");
+
+	size_t p = replystr.rfind(rsp);
+	if (p == std::string::npos) return 0;
+	if (p + 9 >= replystr.length()) return 0;
+	replystr[6] = '\x00';
+	double mtr = atoi(&replystr[p+3]);
+	return mtr / 10.0;
+}
 
 //======================================================================
 // FTdx101MP
@@ -1528,7 +1569,7 @@ void RIG_FTdx101MP::set_power_control(double val)
 	showresp(WARN, ASC, "SET power", cmd, replystr);
 }
 
-double RIG_FTdx101D::get_voltmeter()
+double RIG_FTdx101MP::get_voltmeter()
 {
 // RM8155000;
 	cmd = "RM8;";
@@ -1545,7 +1586,9 @@ double RIG_FTdx101D::get_voltmeter()
 	if (p != std::string::npos) {
 		replystr[6] = 0;
 		mtr = atoi(&replystr[p+3]);
-		val = 0.066 * mtr + 0.78;
+		val = 50 * mtr / 196;
+		if (val < 47) val = 47;
+		if (val > 52) val = 52;
 		return val;
 	}
 
