@@ -1273,7 +1273,6 @@ int RIG_FTdx1200::get_noise()
 void RIG_FTdx1200::set_mic_gain(int val)
 {
 	cmd = "MG000;";
-	val = (int)(val * 2.50);
 	for (int i = 3; i > 0; i--) {
 		cmd[1+i] += val % 10;
 		val /= 10;
@@ -1294,9 +1293,8 @@ int RIG_FTdx1200::get_mic_gain()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
-	val = (int)(val / 2.50);
 	if (val > 100) val = 100;
-	return ceil(val);
+	return val;
 }
 
 void RIG_FTdx1200::get_mic_min_max_step(int &min, int &max, int &step)
