@@ -25,6 +25,9 @@
 #include "debug.h"
 #include "support.h"
 
+// Set this to enable my updates
+// These relate to how the rig behaves when in split mode.
+
 enum mFTdx3000 {
   mLSB, mUSB, mCW, mFM, mAM, mRTTY_L, mCW_R, mPKT_L, mRTTY_U, mPKT_FM, mFM_N, mPKT_U, mAM_N };
 // mLSB, mUSB, mCW, mFM, mAM, mRTTY_L, mCW_R, mPKT_L, mRTTY_U, mPKT_FM, mFM_N, mPKT_U, mAM_N
@@ -183,13 +186,16 @@ RIG_FTdx3000::RIG_FTdx3000() {
 	has_cw_qsk =
 	has_cw_weight =
 	has_cw_break_in =
-
-	has_split_AB =
-
+	has_split =
+	has_split_AB = 
 	can_change_alt_vfo =
 	has_smeter =
 	has_swr_control =
 	has_alc_control =
+
+	has_idd_control =
+	has_voltmeter =
+
 	has_power_out =
 	has_power_control =
 	has_volume_control =
@@ -790,12 +796,12 @@ int RIG_FTdx3000::get_modeA()
 void RIG_FTdx3000::set_modeB(int val)
 {
 	modeB = val;
-	cmd = "MD0";
+	// Need to swap the vfos for the MD command to work on VFO B
+	cmd = "SV;MD0";
 	cmd += FTdx3000_mode_chr[val];
-	cmd += ';';
+	cmd += ";SV;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET mode B", cmd, replystr);
-	adjust_bandwidth(modeA);
 	if (val == mCW || val == mCW_R) return;
 	if (progStatus.spot_onoff) {
 		progStatus.spot_onoff = false;
@@ -809,22 +815,23 @@ void RIG_FTdx3000::set_modeB(int val)
 
 int RIG_FTdx3000::get_modeB()
 {
-	cmd = rsp = "MD0";
+	// Use Opposite Information command to read VFO B mode
+	int n = 20;
+	cmd = rsp = "OI";
 	cmd += ';';
-	wait_char(';', 5, 100, "get mode B", ASC);
-
+	wait_char(';', 27, 100, "get mode B", ASC);
 	gett("get_modeB()");
 
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos) {
-		if (p + 3 < replystr.length()) {
-			int md = replystr[p+3];
+		// JBA - n tells us where to start in the response
+		if (p + n < replystr.length()) {
+			int md = replystr[p+n];
 			if (md <= '9') md = md - '1';
 			else md = 9 + md - 'A';
 			modeB = md;
 		}
 	}
-	adjust_bandwidth(modeB);
 	return modeB;
 }
 
@@ -1130,7 +1137,6 @@ int RIG_FTdx3000::get_noise()
 void RIG_FTdx3000::set_mic_gain(int val)
 {
 	cmd = "MG000;";
-	val = (int)(val * 255 / 100); // convert to 0 .. 255
 	for (int i = 3; i > 0; i--) {
 		cmd[1+i] += val % 10;
 		val /= 10;
@@ -1150,7 +1156,7 @@ int RIG_FTdx3000::get_mic_gain()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
-	return val * 100 / 255;
+	return val;
 }
 
 void RIG_FTdx3000::get_mic_min_max_step(int &min, int &max, int &step)
@@ -1315,6 +1321,44 @@ int RIG_FTdx3000::get_break_in()
 	return progStatus.break_in;
 }
 
+double RIG_FTdx3000::get_voltmeter()
+{
+	cmd = "RM8;";
+	std::string resp = "RM";
+
+	int mtr = 0;
+	double val = 0;
+
+	get_trace(1, "get_voltmeter()");
+	wait_char(';',7, 100, "get vdd", ASC);
+	gett("get_voltmeter");
+
+	size_t p = replystr.rfind(resp);
+	if (p != std::string::npos) {
+		mtr = atoi(&replystr[p+3]);
+		val = 13.8 * mtr / 190;
+		return val;
+	}
+
+	return -1;
+}
+
+double RIG_FTdx3000::get_idd()
+{
+	cmd = rsp = "RM7";
+	cmd += ';';
+	wait_char(';',10, 100, "get alc", ASC);
+	gett("get_idd");
+
+	size_t p = replystr.rfind(rsp);
+	if (p == std::string::npos) return 0;
+	if (p + 9 >= replystr.length()) return 0;
+	replystr[6] = '\x00';
+	double mtr = atoi(&replystr[p+3]);
+	return mtr / 10.0;
+}
+
+
 /*
 void RIG_FTdx3000::set_cw_spot_tone()
 {
