@@ -248,7 +248,7 @@ void RIG_FTdx9000::get_band_selection(int v)
 	set_trace(2, "get band", replystr.c_str());
 
 	size_t p = replystr.rfind("IF");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	if (replystr[p+21] != '0') {	// vfo 60M memory mode
 		inc_60m = true;
 	}
@@ -295,7 +295,7 @@ unsigned long int RIG_FTdx9000::get_vfoA ()
 	rig_trace(2, "get_vfoA()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqA;
+	if (p == std::string::npos) return freqA;
 	int f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -324,7 +324,7 @@ unsigned long int RIG_FTdx9000::get_vfoB ()
 	rig_trace(2, "get_vfoB()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqB;
+	if (p == std::string::npos) return freqB;
 	int f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -356,6 +356,7 @@ void RIG_FTdx9000::selectA()
 	cmd = "FR0;FT2;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select A", cmd, replystr);
+	inuse = onA;
 }
 
 void RIG_FTdx9000::selectB()
@@ -363,6 +364,7 @@ void RIG_FTdx9000::selectB()
 	cmd = "FR3;FT3;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select B", cmd, replystr);
+	inuse = onB;
 }
 
 void RIG_FTdx9000::A2B()
@@ -381,7 +383,6 @@ void RIG_FTdx9000::set_split(bool val)
 {
 	split = val;
 	if (val) {
-		useB = false;
 		cmd = "FR0;";
 		sendCommand(cmd);
 		showresp(WARN, ASC, "Rx on A", cmd, replystr);
@@ -414,7 +415,7 @@ int RIG_FTdx9000::get_smeter()
 	rig_trace(2, "get_smeter()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	mtr = mtr * 100.0 / 256.0;
@@ -430,7 +431,7 @@ int RIG_FTdx9000::get_swr()
 	rig_trace(2, "get_swr()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	return mtr / 2.56;
@@ -461,7 +462,7 @@ int RIG_FTdx9000::get_power_out()
 	gett("get_power_out()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	size_t i = 0;
@@ -487,7 +488,7 @@ double RIG_FTdx9000::get_power_control()
 	gett("get_power_control()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.power_level;
+	if (p == std::string::npos) return progStatus.power_level;
 	if (p + 5 >= replystr.length()) return progStatus.power_level;
 
 	int mtr = atoi(&replystr[p+2]);
@@ -516,7 +517,7 @@ int RIG_FTdx9000::get_volume_control()
 	rig_trace(2, "get_volume_control()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.volume;
+	if (p == std::string::npos) return progStatus.volume;
 	if (p + 6 >= replystr.length()) return progStatus.volume;
 	int val = atoi(&replystr[p+3]) * 100 / 250;
 	if (val > 100) val = 100;
@@ -553,7 +554,7 @@ int RIG_FTdx9000::get_PTT()
 	rig_trace(2, "get_PTT()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ptt_;
+	if (p == std::string::npos) return ptt_;
 	ptt_ =  (replystr[p+2] != '0' ? 1 : 0);
 	return ptt_;
 }
@@ -587,7 +588,7 @@ int RIG_FTdx9000::get_tune()
 	rig_trace(2, "get_tuner status()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	int val = replystr[p+4] - '0';
 	return !(val < 2);
 }
@@ -631,7 +632,7 @@ int RIG_FTdx9000::get_attenuator()
 	rig_trace(2, "get_attenuator()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.attenuator;
+	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
 	atten_level = replystr[p+3] - '0';
 	if (atten_level == 1) {
@@ -682,7 +683,7 @@ int RIG_FTdx9000::get_preamp()
 	rig_trace(2, "get_preamp()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos)
+	if (p != std::string::npos)
 		preamp_level = replystr[p+3] - '0';
 	if (preamp_level == 1) {
 		preamp_label("Amp 1", true);
@@ -725,7 +726,7 @@ int RIG_FTdx9000::adjust_bandwidth(int val)
 int RIG_FTdx9000::def_bandwidth(int m)
 {
 	int bw = adjust_bandwidth(m);
-	if (useB) {
+	if (inuse == onB) {
 		if (mode_bwB[m] == -1)
 			mode_bwB[m] = bw;
 		return mode_bwB[m];
@@ -780,7 +781,7 @@ int RIG_FTdx9000::get_modeA()
 	rig_trace(2, "get_modeA()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			if (md <= '9') md = md - '1';
@@ -821,7 +822,7 @@ int RIG_FTdx9000::get_modeB()
 	rig_trace(2, "get_modeB()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			if (md <= '9') md = md - '1';
@@ -870,7 +871,7 @@ int RIG_FTdx9000::get_bwA()
 	rig_trace(2, "get_bwA()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return bwA;
+	if (p == std::string::npos) return bwA;
 	if (p + 5 >= replystr.length()) return bwA;
 
 	replystr[p+5] = 0;
@@ -926,7 +927,7 @@ int RIG_FTdx9000::get_bwB()
 	rig_trace(2, "get_bwB()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return bwB;
+	if (p == std::string::npos) return bwB;
 	if (p + 5 >= replystr.length()) return bwB;
 	
 	replystr[p+5] = 0;
@@ -946,7 +947,7 @@ int RIG_FTdx9000::get_bwB()
 
 std::string RIG_FTdx9000::get_BANDWIDTHS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_bwA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -956,7 +957,7 @@ std::string RIG_FTdx9000::get_BANDWIDTHS()
 
 void RIG_FTdx9000::set_BANDWIDTHS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_bwA[i];
@@ -986,7 +987,7 @@ void RIG_FTdx9000::set_if_shift(int val)
 
 bool RIG_FTdx9000::get_if_shift(int &val)
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = rsp = "IS1";
 	else
 		cmd = rsp = "IS0";
@@ -997,7 +998,7 @@ bool RIG_FTdx9000::get_if_shift(int &val)
 
 	size_t p = replystr.rfind(rsp);
 	val = progStatus.shift_val;
-	if (p == string::npos) return progStatus.shift;
+	if (p == std::string::npos) return progStatus.shift;
 	val = atoi(&replystr[p+4]);
 	if (replystr[p+3] == '-') val = -val;
 	return (val != 0);
@@ -1040,7 +1041,7 @@ bool  RIG_FTdx9000::get_notch(int &val)
 	cmd += ';';
 	wait_char(';', 8, 100, "get notch on/off", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ison;
+	if (p == std::string::npos) return ison;
 
 	rig_trace(2, "get_notch()", replystr.c_str());
 
@@ -1055,7 +1056,7 @@ bool  RIG_FTdx9000::get_notch(int &val)
 	rig_trace(2, "get_notch_val()", replystr.c_str());
 
 	p = replystr.rfind(rsp);
-	if (p == string::npos)
+	if (p == std::string::npos)
 		val = 10;
 	else
 		val = fm_decimal(replystr.substr(p+4), 3) * 10;
@@ -1086,7 +1087,7 @@ int  RIG_FTdx9000::get_auto_notch()
 	rig_trace(2, "get_auto_notch()", replystr.c_str());
 
 	size_t p = replystr.rfind("BC0");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (replystr[p+3] == '1') return 1;
 	return 0;
 }
@@ -1120,7 +1121,7 @@ int RIG_FTdx9000::get_noise()
 	rig_trace(2, "get_noise()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return FTdx9000_blanker_level;
+	if (p == std::string::npos) return FTdx9000_blanker_level;
 
 	FTdx9000_blanker_level = replystr[p+3] - '0';
 	if (FTdx9000_blanker_level == 1) {
@@ -1156,7 +1157,7 @@ int RIG_FTdx9000::get_mic_gain()
 	rig_trace(2, "get_mic_gain()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.mic_gain;
+	if (p == std::string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
 	return val * 100 / 255;
 }
@@ -1190,7 +1191,7 @@ int  RIG_FTdx9000::get_rf_gain()
 	rig_trace(2, "get_rf_gain()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.rfgain;
+	if (p == std::string::npos) return progStatus.rfgain;
 	for (int i = 3; i < 6; i++) {
 		rfval *= 10;
 		rfval += replystr[p+i] - '0';
