@@ -27,11 +27,11 @@ void TRACED(update_UI_PTT, void *d)
 
 	btnPTT->value(PTT);
 	if (!PTT) {
-		btnALC_SWR->hide();
+		btnALC_IDD_SWR->hide();
 		scaleSmeter->show();
 		sldrRcvSignal->clear();
 	} else {
-		btnALC_SWR->show();
+		btnALC_IDD_SWR->show();
 		scaleSmeter->hide();
 		sldrFwdPwr->clear();
 		sldrALC->clear();
@@ -1213,6 +1213,19 @@ void TRACED(init_dsp_controls)
 		opDSP_hi->hide();
 		btnFILT->hide();
 		opBW->show();
+		if (selrig->name_ == rig_tcisdr.name_) {
+			opCENTER->clear();
+			for (int i = 0; i < tci_nbr_centers; i++)
+				opCENTER->add(TCI_centers[i]);
+			opCENTER->show();
+			opCENTER->index(progStatus.tci_center);
+		}
+//		switch (progStatus.UIsize) {
+//			case small_ui :
+//				opCENTER->resize(opBW->x(), opBW->y() + opBW->h() + 2, opCENTER->w(), opCENTER->h());
+//				break;
+//			case wide_ui : case touch_ui : default : break;
+//		}
 	}
 }
 
@@ -2003,9 +2016,9 @@ void TRACED(set_init_auto_notch)
 void TRACED(init_swr_control)
 
 	if (selrig->has_swr_control)
-		btnALC_SWR->activate();
+		btnALC_IDD_SWR->activate();
 	else {
-		btnALC_SWR->deactivate();
+		btnALC_IDD_SWR->deactivate();
 	}
 }
 
@@ -2111,6 +2124,8 @@ void TRACED(init_K3_KX3_special)
 	}
 }
 
+extern void read_menus();
+
 void TRACED(initRig)
 
 	xcvr_online = false;
@@ -2135,6 +2150,8 @@ void TRACED(initRig)
 	sldrSWR->avg(progStatus.pwr_avg);
 	sldrALC->aging(progStatus.pwr_peak);
 	sldrALC->avg(progStatus.pwr_avg);
+	sldrIDD->aging(progStatus.pwr_peak);
+	sldrIDD->avg(progStatus.pwr_avg);
 
 	sldrVoltage->aging(1);
 	sldrVoltage->avg(1);
@@ -2147,6 +2164,8 @@ void TRACED(initRig)
 	sigbar_SWR->avg(progStatus.pwr_avg);
 	sigbar_ALC->aging(progStatus.pwr_peak);
 	sigbar_ALC->avg(progStatus.pwr_avg);
+	sigbar_IDD->aging(progStatus.pwr_peak);
+	sigbar_IDD->avg(progStatus.pwr_avg);
 
 	sigbar_VOLTS->aging(1);
 	sigbar_VOLTS->avg(1);
@@ -2216,6 +2235,8 @@ void TRACED(initRig)
 trace(1, "selrig->initialize()");
 		selrig->initialize();
 
+		if (selrig->name_ == rig_QCXP.name_) read_menus();
+
 if (!testmode) {
 	trace(1, "selrig->check()");
 		if (!selrig->check()) {
@@ -2313,6 +2334,26 @@ Press 'Init' button."));
 	box_xcvr_connect->color(FL_GREEN);
 	box_xcvr_connect->redraw();
 
+	if (selrig->name_ == rig_FTdx101MP.name_ ||
+		selrig->name_ == rig_IC7851.name_ ) {
+		sldrVoltage->minimum (47); sldrVoltage->maximum (52);
+		sigbar_VOLTS->minimum (47); sigbar_VOLTS->maximum (52);
+		scaleVoltage->image(image_volts50);
+		mtr_VOLTS->image(image_volts50);
+	} else {
+		sldrVoltage->minimum (6); sldrVoltage->maximum (16);
+		sigbar_VOLTS->minimum (6); sigbar_VOLTS->maximum (16);
+		scaleVoltage->image(image_voltmeter);
+		mtr_VOLTS->image(image_voltmeter);
+	}
+	scaleVoltage->redraw_label();
+	mtr_VOLTS->redraw_label();
+
+	sldrIDD->maximum(25);
+	sldrIDD->minimum(0);
+	sigbar_IDD->maximum(25);
+	sigbar_IDD->minimum(0);
+
 	start_commands();
 
 	return;
@@ -2334,7 +2375,6 @@ void TRACED(initConfigDialog)
 	xcvr_name = srig->name_;
 
 	if (!progStatus.loadXcvrState(xcvr_name) ) {
-
 		selectCommPort->index(0);
 		mnuBaudrate->index( srig->comm_baudrate );
 		btnOneStopBit->value( srig->stopbits == 1 );
@@ -2378,6 +2418,7 @@ void TRACED(initConfigDialog)
 			btnUSBaudio->value(false);
 			btnUSBaudio->deactivate();
 		}
+
 	} else {
 		initStatusConfigDialog();
 		trace(1, progStatus.info().c_str());
@@ -2477,8 +2518,10 @@ void TRACED(initRigCombo)
 
 	selectRig->clear();
 	int i = 0;
-	while (rigs[i] != NULL)
-		selectRig->add(rigs[i++]->name_.c_str());
+	while (rigs[i] != NULL) {
+		selectRig->add(rigs[i]->name_.c_str());
+		i++;
+	}
 
 	selectRig->index(0);
 }
