@@ -74,8 +74,8 @@ status progStatus = {
 	false,		// bool comm_rtscts;
 	false,		// bool comm_rtsplus;
 	false,		// bool comm_dtrplus;
-	200,		// int  serloop_timing;
-	0,			// int  byte_interval;
+	500,		// int  serloop_timing;
+	1,			// int  byte_interval;
 
 	"NONE",		// std::string aux_serial_port;
 	false,		// bool aux_SCU_17;
@@ -149,7 +149,9 @@ status progStatus = {
 
 	false,		// bool spkr_on;
 	20,			// int  volume;
-	0,			// int  power_level;
+	0,			// double  power_level;
+	100,		// double power_limit;
+	false,		// bool enable_power_limit
 	10,			// int  mic_gain;
 	false,		// bool notch;
 	0,			// int  notch_val;
@@ -469,9 +471,12 @@ status progStatus = {
 	50,			// int tcpip_ping_delay
 	10,			// int tcpip_reconnect_after in seconds
 	10,			// int tcpip_drops_allowed;
-
 	false,		// bool use_tcpip
 
+	"40001",	// std::string tci_port
+	"127.0.0.1",// std::string tci address
+	10,			// int  tci_center;
+
 	false,		// bool xcvr auto on
 	false,		// bool xcvr auto off
 
@@ -485,6 +490,7 @@ status progStatus = {
 	false,		// bool	xmltrace;
 	false,		// bool	rpctrace;
 	false,		// bool	serialtrace;
+	false,		// bool tcitrace;
 	false,		// bool	start_stop_trace;
 	0,			// int	rpc_level;
 
@@ -551,12 +557,27 @@ status progStatus = {
 	0,			// int		FSK_CONNECTED; 1 - connected state; 0 - unconnected state
 	0,			// int		FSK_INVERTED; reverse keying; 
 	1,			// int		FSK_STOPBITS; 1 - 1.5; 0 - 2
+	8,			// int		fsk_idles
 	"",			// std::string	FSK_PORT;
 
 	"","","","","","",
 	"","","","","","",					// std::string	FSK_msgs[12];
 	"m2","m2","m3","m4","m4","m6",
-	"m7","m8","m9","m10","m11","m12"	// std::string	FSK_labels[12];
+	"m7","m8","m9","m10","m11","m12",	// std::string	FSK_labels[12];
+
+// CW logbook parameters
+	"",			// std::string cw_log_name;
+	0,			// int cw_log_cut_numbers;
+	0,			// int cw_log_leading_zeros;
+	1,			// int cw_log_dupcheck;
+	0,			// int cw_log_nbr;
+
+// RTTY logbook parameters
+	"",			// std::string fsk_log_name;
+	0,			// int fsk_log_cut_numbers;
+	0,			// int fsk_log_leading_zeros;
+	1,			// int fsk_log_dupcheck;
+	0,			// int fsk_log_nbr
 
 };
 
@@ -724,6 +745,8 @@ void status::saveLastState()
 	spref.set("bool_spkr_on", spkr_on);
 	spref.set("int_volume", volume);
 	spref.set("dbl_power", power_level);
+	spref.set("power_limit", power_limit);
+	spref.set("enable_power_limit", enable_power_limit);
 	spref.set("int_mic", mic_gain);
 	spref.set("bool_notch", notch);
 	spref.set("int_notch", notch_val);
@@ -740,7 +763,7 @@ void status::saveLastState()
 
 	spref.set("schema", schema);
 	spref.set("embed_tabs", embed_tabs);
-	if (!embed_tabs)
+	if (!embed_tabs && tabs_dialog)
 		show_tabs = tabs_dialog->visible();
 	spref.set("show_tabs", show_tabs);
 	spref.set("visible_tab", visible_tab.c_str());
@@ -1051,6 +1074,10 @@ void status::saveLastState()
 	spref.set("tcpip_drops_allowed", tcpip_drops_allowed);
 	spref.set("use_tcpip", use_tcpip);
 
+	spref.set("tci_port", tci_port.c_str());
+	spref.set("tci_addr", tci_addr.c_str());
+	spref.set("tci_center", tci_center);
+
 	spref.set("xcvr_auto_on", xcvr_auto_on);
 	spref.set("xcvr_auto_off", xcvr_auto_off);
 
@@ -1065,6 +1092,8 @@ void status::saveLastState()
 	spref.set("rpctrace", rpctrace);
 	spref.set("serialtrace", serialtrace);
 	spref.set("startstoptrace", start_stop_trace);
+	spref.set("tcitrace", tcitrace);
+
 	spref.set("rpc_level", rpc_level);
 
 	spref.set("f160", f160); spref.set("m160", m160);
@@ -1170,6 +1199,7 @@ void status::saveLastState()
 	spref.set("FSK_CONNECTED", FSK_CONNECTED);
 	spref.set("FSK_INVERTED", FSK_INVERTED);
 	spref.set("FSK_STOPBITS", FSK_STOPBITS);
+	spref.set("FSK_IDLES", fsk_idles);
 	spref.set("FSK_PORT", FSK_PORT.c_str());
 
 	for (int n = 0; n < 12; n++) {
@@ -1179,6 +1209,21 @@ void status::saveLastState()
 		spref.set(setbuff, FSK_msgs[n].c_str());
 	}
 
+// CW logbook parameters
+	spref.set("CW_LOG_NAME", cw_log_name.c_str());
+	spref.set("CW_CUT_NUMBERS", cw_log_cut_numbers);
+	spref.set("CW_LEADING_ZEROS", cw_log_leading_zeros);
+	spref.set("CW_DUPCHECK", cw_log_dupcheck);
+	spref.set("CW_LOG_NBR", cw_log_nbr);
+
+
+// FSK logbook parameters
+	spref.set("FSK_LOG_NAME", fsk_log_name.c_str());
+	spref.set("FSK_CUT_NUMBERS", fsk_log_cut_numbers);
+	spref.set("FSK_LEADING_ZEROS", fsk_log_leading_zeros);
+	spref.set("FSK_DUPCHECK", fsk_log_dupcheck);
+	spref.set("FSK_LOG_NBR", fsk_log_nbr);
+
 }
 
 bool status::loadXcvrState(std::string xcvr)
@@ -1362,6 +1407,8 @@ bool status::loadXcvrState(std::string xcvr)
 		if (spref.get("bool_spkr_on", i, i)) spkr_on = i;
 		spref.get("int_volume", volume, volume);
 		spref.get("dbl_power", power_level, power_level);
+		spref.get("power_limit", power_limit, power_limit);
+		if (spref.get("enable_power_limit", i, i)) enable_power_limit = i;
 		spref.get("int_mic", mic_gain, mic_gain);
 		if (spref.get("bool_notch", i, i)) notch = i;
 		spref.get("int_notch", notch_val, notch_val);
@@ -1784,6 +1831,12 @@ bool status::loadXcvrState(std::string xcvr)
 		spref.get("tcpip_drops_allowed", tcpip_drops_allowed, tcpip_drops_allowed);
 		if (spref.get("use_tcpip", i, i)) use_tcpip = i;
 
+		spref.get("tci_port", defbuffer, "40001", 499);
+		tci_port = defbuffer;
+		spref.get("tci_addr", defbuffer, "127.0.0.1", 499);
+		tci_addr = defbuffer;
+		spref.get("tci_center", tci_center, tci_center);
+
 		if (spref.get("xcvr_auto_on", i, i)) xcvr_auto_on = i;
 		if (spref.get("xcvr_auto_off", i, i)) xcvr_auto_off = i;
 
@@ -1798,6 +1851,19 @@ bool status::loadXcvrState(std::string xcvr)
 		if (spref.get("serialtrace", i, serialtrace)) serialtrace = i;
 		if (spref.get("startstoptrace", i, start_stop_trace)) start_stop_trace = i;
 		if (spref.get("rpctrace", i, rpctrace)) rpctrace = i;
+		if (spref.get("tcitrace", i, tcitrace)) tcitrace = i;
+
+#ifndef NDEBUG
+		trace =
+		rigtrace =
+		settrace =
+		debugtrace =
+		xmltrace =
+		rpctrace =
+		serialtrace =
+		gettrace = 
+		tcitrace = true;
+#endif
 
 		spref.get("rpc_level", rpc_level, rpc_level);
 
@@ -1915,9 +1981,26 @@ bool status::loadXcvrState(std::string xcvr)
 		spref.get("FSK_CONNECTED", FSK_CONNECTED, FSK_CONNECTED);
 		spref.get("FSK_INVERTED", FSK_INVERTED, FSK_INVERTED);
 		spref.get("FSK_STOPBITS", FSK_STOPBITS, FSK_STOPBITS);
+		spref.get("FSK_IDLES", fsk_idles, fsk_idles);
 		spref.get("FSK_PORT", defbuffer, "NONE", 499);
 		FSK_PORT = defbuffer;
 
+// CW logbook parameters
+		spref.get("CW_LOG_NAME", defbuffer, "", 499);
+			cw_log_name = defbuffer;
+		spref.get("CW_CUT_NUMBERS", cw_log_cut_numbers, cw_log_cut_numbers);
+		spref.get("CW_LEADING_ZEROS", cw_log_leading_zeros, cw_log_leading_zeros);
+		spref.get("CW_DUPCHECK", cw_log_dupcheck, cw_log_dupcheck);
+		spref.get("CW_LOG_NBR", cw_log_nbr, cw_log_nbr);
+
+// FSK logbook parameters
+		spref.get("FSK_LOG_NAME", defbuffer, "", 499);
+			fsk_log_name = defbuffer;
+		spref.get("FSK_CUT_NUMBERS",fsk_log_cut_numbers, fsk_log_cut_numbers);
+		spref.get("FSK_LEADING_ZEROS", fsk_log_leading_zeros, fsk_log_leading_zeros);
+		spref.get("FSK_DUPCHECK", fsk_log_dupcheck, fsk_log_dupcheck);
+		spref.get("FSK_LOG_NBR", fsk_log_nbr, fsk_log_nbr);
+
 		for (int n = 0; n < 12; n++) {
 			snprintf(getbuff, sizeof(getbuff), "fskiolabel[%d]", n);
 			spref.get(getbuff, defbuffer, "", 499);
@@ -1968,8 +2051,8 @@ void status::UI_laststate()
 	scaleSmeter->labelcolor(fgclr);
 	scalePower->color(bgclr);
 	scalePower->labelcolor(fgclr);
-	btnALC_SWR->color(bgclr);
-	btnALC_SWR->labelcolor(fgclr);
+	btnALC_IDD_SWR->color(bgclr);
+	btnALC_IDD_SWR->labelcolor(fgclr);
 
 	sldrFwdPwr->color(fl_rgb_color (pwrRed, pwrGreen, pwrBlue), bgclr);
 	sldrFwdPwr->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
@@ -1983,6 +2066,9 @@ void status::UI_laststate()
 	sldrSWR->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
 	sldrSWR->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
 
+	sldrIDD->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
+	sldrIDD->PeakColor(fl_rgb_color (peakRed, peakGreen, peakBlue));
+
 	sldrVoltage->color(fl_rgb_color (voltRed, voltGreen, voltBlue), bgclr);
 	sldrVoltage->PeakColor(bgclr);
 
@@ -2212,6 +2298,8 @@ std::string status::info()
 	info << "bool_spkr_on       : " << spkr_on << "\n";
 	info << "int_volume         : " << volume << "\n";
 	info << "dbl_power          : " << power_level << "\n";
+	info << "dbl_power_limit %  : " << power_limit << "\n";
+	info << "enable power limit:  " << enable_power_limit << "\n";
 	info << "int_mic            : " << mic_gain << "\n";
 	info << "bool_notch         : " << notch << "\n";
 	info << "int_notch          : " << notch_val << "\n";
@@ -2315,6 +2403,8 @@ static bool strace;
 static bool srigtrace;
 static bool ssettrace;
 static bool sgettrace;
+static bool sstrace;
+static bool stcitrace;
 
 void ss_trace(bool on)
 {
@@ -2323,16 +2413,22 @@ void ss_trace(bool on)
 		srigtrace = progStatus.rigtrace;
 		ssettrace = progStatus.settrace;
 		sgettrace = progStatus.gettrace;
+		sstrace   = progStatus.serialtrace;
+		stcitrace = progStatus.tcitrace;
 
 		progStatus.trace =
 		progStatus.rigtrace =
 		progStatus.settrace =
-		progStatus.gettrace = true;
+		progStatus.serialtrace =
+		progStatus.gettrace = 
+		progStatus.tcitrace = true;
 	} else {
 		progStatus.trace = strace;
 		progStatus.rigtrace = srigtrace;
 		progStatus.settrace = ssettrace;
 		progStatus.gettrace = sgettrace;
+		progStatus.serialtrace = sstrace;
+		progStatus.tcitrace = stcitrace;
 	}
 }
 
